Description: <short summary of the patch>
 TODO: Put a short summary on the line above and replace this paragraph
 with a longer explanation of this change. Complete the meta-information
 with other relevant fields (see below for details). To make it easier, the
 information below has been extracted from the changelog. Adjust it or drop
 it.
 .
 maxima (5.33.0-4) unstable; urgency=medium
 .
   * build dep latest gcl
Author: Camm Maguire <camm@debian.org>

---
The information above should follow the Patch Tagging Guidelines, please
checkout http://dep.debian.net/deps/dep3/ to learn about the format. Here
are templates for supplementary fields that you might want to add:

Origin: <vendor|upstream|other>, <url of original patch>
Bug: <url in upstream bugtracker>
Bug-Debian: http://bugs.debian.org/<bugnumber>
Bug-Ubuntu: https://launchpad.net/bugs/<bugnumber>
Forwarded: <no|not-needed|url proving that it has been forwarded>
Reviewed-By: <name and email of someone who approved the patch>
Last-Update: <YYYY-MM-DD>

--- maxima-5.33.0.orig/src/sys-proclaim.lisp
+++ maxima-5.33.0/src/sys-proclaim.lisp
@@ -1,6745 +1,982 @@
-;; This file is generated via 'make sys-proclaim'.
+
 (IN-PACKAGE "COMMON-LISP-USER") 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) BIGFLOAT-IMPL:*)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) BIGFLOAT-IMPL:+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) BIGFLOAT-IMPL:-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) BIGFLOAT-IMPL:/)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) BIGFLOAT-IMPL:/=)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT-IMPL:1+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT-IMPL:1-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) BIGFLOAT-IMPL:=)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) BIGFLOAT-IMPL:ATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) BIGFLOAT-IMPL:BIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT-IMPL:COERCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) BIGFLOAT-IMPL:COMPLEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) BIGFLOAT-IMPL:LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) BIGFLOAT-IMPL:MAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) BIGFLOAT-IMPL:MAYBE-TO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) BIGFLOAT-IMPL:MIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) BIGFLOAT-IMPL:TO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) BIGFLOAT::%TO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) BIGFLOAT::AGM-SCALE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::ASCENDING-TRANSFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::BF-ELLIPTIC-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-ELLIPTIC-EC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::BF-ELLIPTIC-F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-ELLIPTIC-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) BIGFLOAT::BF-ELLIPTIC-PI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-ERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-ERFI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-FRESNEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-FRESNEL-C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-FRESNEL-S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-INVERSE-ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::BF-INVERSE-ERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::BF-INVERSE-JACOBI-DN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::BF-INVERSE-JACOBI-SN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) BIGFLOAT::BF-NEWTON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::BF-RC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) BIGFLOAT::BF-RD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) BIGFLOAT::BF-RF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) BIGFLOAT::BF-RG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) BIGFLOAT::BF-RJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) BIGFLOAT::BF-RJ1)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) BIGFLOAT::BFERRTOL)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) *) BIGFLOAT::BFLOAT-INIT-LAMBERT-W-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) BIGFLOAT::CHECK-LAMBERT-W-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::CN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::DESCENDING-TRANSFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::DN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::ELLIPTIC-SN-DESCENDING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) BIGFLOAT::EXPT-EXTRA-BITS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) *) BIGFLOAT::FIND-ROOT-SUBR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) BIGFLOAT::FP2SINGLE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T T) T) BIGFLOAT::INTERPOLATE-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) BIGFLOAT::INTOFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::JACOBI-AGM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) BIGFLOAT::LAMBERT-BRANCH-APPROX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) BIGFLOAT::LAMBERT-W-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT::SN)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %E (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %E (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %E (LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %E (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %E (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %PI (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %PI (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %PI (LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %PI (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD %PI (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ABS (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ABS (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ACOS (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ACOSH (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ADD1 (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ADD1 (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD ADD1 (NUMBER))|)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ASIN (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ASINH (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ATANH (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD CEILING (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD CIS (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD CIS (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD CIS (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD COMPLEXP (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD COMPLEXP (LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD COMPLEXP (T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD CONJUGATE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD CONJUGATE (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD COS (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD COSH (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD DECODE-FLOAT (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) (VALUES T T T))
-            BIGFLOAT::|(PCL::FAST-METHOD DECODE-FLOAT (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD DESCRIBE-OBJECT (BIGFLOAT T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD DESCRIBE-OBJECT (COMPLEX-BIGFLOAT T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EXP (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EXPT (BIGFLOAT INTEGER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMBER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMBER NUMERIC))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMERIC NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMERIC NUMERIC))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FCEILING (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FFLOOR (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:FLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:RATIONAL LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-DIGITS (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) FIXNUM)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-DIGITS (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-SIGN (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-SIGN (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FLOOR (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FROUND (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD FTRUNCATE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD IMAG-VALUE (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD IMAGPART (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD IMAGPART (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD INIT-LAMBERT-W-K (INTEGER BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD INIT-LAMBERT-W-K (INTEGER COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD INIT-LAMBERT-W-K (INTEGER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD INTEGER-DECODE-FLOAT (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) (VALUES T T T))
-            BIGFLOAT::|(PCL::FAST-METHOD INTEGER-DECODE-FLOAT (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAKE-LOAD-FORM (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAKE-LOAD-FORM (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD MINUSP (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-ATAN (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-ATAN (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-ATAN (NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-COMPLEX (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-COMPLEX (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-COMPLEX (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-LOG (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-LOG (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-LOG (NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD PHASE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD PHASE (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD PLUSP (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD PRINT-OBJECT (BIGFLOAT T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD PRINT-OBJECT (COMPLEX-BIGFLOAT T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD RANDOM (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD RANDOM (INTEGER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD RANDOM (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD RATIONAL (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD RATIONAL (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD RATIONAL (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD RATIONALIZE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD RATIONALIZE (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD RATIONALIZE (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD REAL-VALUE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD REAL-VALUE (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD REALP (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD REALP (LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD REALP (LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD REALP (T))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD REALPART (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD REALPART (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ROUND (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SCALE-FLOAT (BIGFLOAT INTEGER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD SCALE-FLOAT (LISP:FLOAT INTEGER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SIGNUM (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SIGNUM (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD SIGNUM (NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SIN (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SINH (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SQRT (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SQRT (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SUB1 (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD SUB1 (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD SUB1 (NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TAN (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TANH (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TRUNCATE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (COMPLEX-BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (COMPLEX-BIGFLOAT NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (NUMBER BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (NUMBER COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (NUMBER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (COMPLEX-BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (COMPLEX-BIGFLOAT NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (NUMBER BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (NUMBER COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (NUMBER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (COMPLEX-BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (COMPLEX-BIGFLOAT NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (LISP:COMPLEX BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (NUMBER COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (NUMBER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT LISP:COMPLEX))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (COMPLEX-BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (COMPLEX-BIGFLOAT NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (LISP:COMPLEX BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (NUMBER COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (NUMBER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (BIGFLOAT NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (COMPLEX-BIGFLOAT NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (NUMBER BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (NUMBER COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (NUMBER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (BIGFLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (BIGFLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:FLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:FLOAT LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:FLOAT LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:RATIONAL BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:RATIONAL LISP:FLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:RATIONAL LISP:RATIONAL))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (BIGFLOAT BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (BIGFLOAT LISP:FLOAT))|)) 
+    '(FTYPE (FUNCTION (FIXNUM (ARRAY FIXNUM) (ARRAY FIXNUM)) T)
+            MAXIMA::PERMUTATION-LEX-SUCCESSOR)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (BIGFLOAT LISP:RATIONAL))|)) 
+    '(FTYPE (FUNCTION (T (VECTOR T) FIXNUM) T)
+            MAXIMA::MAKE-BREAK-POINT)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:FLOAT BIGFLOAT))|)) 
+    '(FTYPE (FUNCTION (T) (SIMPLE-ARRAY (UNSIGNED-BYTE 32) (627)))
+            MT19937::RANDOM-STATE-STATE)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:FLOAT LISP:FLOAT))|)) 
+    '(FTYPE (FUNCTION (T FIXNUM T) T) MAXIMA::GF-XECTIMES
+            MAXIMA::COLROW0)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:FLOAT LISP:RATIONAL))|)) 
+    '(FTYPE (FUNCTION (T FIXNUM FIXNUM T) T) MAXIMA::MTOA
+            MAXIMA::RITEDIV)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:RATIONAL BIGFLOAT))|)) 
+    '(FTYPE (FUNCTION (T T T) FIXNUM)
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-DIGITS (LISP:FLOAT))|
+            MAXIMA::BEHAVIOR-NUMDEN MAXIMA::DETERMINE-LIFTING-FACTOR)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:RATIONAL LISP:FLOAT))|)) 
+    '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) MAXIMA::ECHELON2
+            MAXIMA::TRIANG2 MAXIMA::NEWINV)) 
+(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM FIXNUM) T) MAXIMA::ZROW)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:RATIONAL LISP:RATIONAL))|)) 
+    '(FTYPE (FUNCTION (T FIXNUM FIXNUM FIXNUM FIXNUM) T)
+            MAXIMA::OBMTRX)) 
+(PROCLAIM '(FTYPE (FUNCTION (FIXNUM T FIXNUM) T) MAXIMA::CPTOMF)) 
+(PROCLAIM '(FTYPE (FUNCTION (T T T T) FIXNUM) MAXIMA::*F-DEG)) 
+(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T T) T) MAXIMA::MINORL)) 
+(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T FIXNUM) T) MAXIMA::STORA)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (T T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMBER NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMBER NUMERIC))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMERIC NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMERIC NUMERIC))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-CEILING (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-DIVIDE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-DIVIDE (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-DIVIDE (NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FCEILING (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FFLOOR (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FLOOR (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FTRUNCATE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-MINUS (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-MINUS (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-MINUS (NUMBER))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD UNARY-TRUNCATE (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            BIGFLOAT::|(PCL::FAST-METHOD ZEROP (BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD ZEROP (COMPLEX-BIGFLOAT))|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            BIGFLOAT::|(PCL::FAST-METHOD ZEROP (NUMBER))|)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) BIGFLOAT:LENTZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) BIGFLOAT:SUM-POWER-SERIES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::DISPLAY-ITEMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::ENSURE-INFO-TABLES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::EXACT-TOPIC-MATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::EXACT-TOPIC-MATCH-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::FIND-REGEX-MATCHES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::FLATTEN-MATCHES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) CL-INFO::GCL-READ-SEQUENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::INEXACT-TOPIC-MATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::INEXACT-TOPIC-MATCH-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::INFO-EXACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::INFO-INEXACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) CL-INFO::LOAD-INFO-HASHTABLES)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) CL-INFO::LOAD-PRIMARY-INDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::PARSE-USER-CHOICE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) CL-INFO::PRINT-PROMPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::READ-INFO-TEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::REARRANGE-MATCHES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) CL-INFO::REGEX-SANITIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::SELECT-INFO-ITEMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::SOME-EXACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) CL-INFO::SOME-INEXACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) COMMAND-LINE::CL-OPTION-ACTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) COMMAND-LINE::CL-OPTION-ARGUMENT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) COMMAND-LINE::CL-OPTION-DESCRIPTION)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) COMMAND-LINE::CL-OPTION-HELP-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) COMMAND-LINE::CL-OPTION-NAMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) COMMAND-LINE::CL-OPTION-P)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) COMMAND-LINE:GET-APPLICATION-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) COMMAND-LINE:LIST-CL-OPTIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) COMMAND-LINE:MAKE-CL-OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) COMMAND-LINE:PROCESS-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) GETOPT::ANALYZE-ARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) GETOPT::DECOMPOSE-ARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) GETOPT::FIND-OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) GETOPT::IS-LONG-OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) GETOPT::IS-OPTION-TERMINATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) GETOPT::IS-SHORT-OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) GETOPT::MATCH-OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) GETOPT:GETOPT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T *) T) GETOPT:MATCH-UNIQUE-ABBREVIATION)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) SIMPLE-STRING) INTL::DOMAIN-ENTRY-DOMAIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) INTL::DOMAIN-ENTRY-ENCODING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) PATHNAME) INTL::DOMAIN-ENTRY-FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) HASH-TABLE) INTL::DOMAIN-ENTRY-HASH)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) SIMPLE-STRING) INTL::DOMAIN-ENTRY-LOCALE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) INTL::DOMAIN-ENTRY-P)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) (OR NULL FUNCTION))
-            INTL::DOMAIN-ENTRY-PLURALS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FUNCTION) INTL::DOMAIN-ENTRY-READFN)) 
-(PROCLAIM '(FTYPE (FUNCTION (STRING T) T) INTL::DOMAIN-LOOKUP)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (STRING STRING T) T) INTL::DOMAIN-LOOKUP-PLURAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) INTL::FIND-DOMAIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) INTL::FIND-ENCODING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) INTL::GETENV)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) INTL::INSTALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) INTL::LOAD-DOMAIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) INTL::LOCATE-DOMAIN-FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) INTL::MAKE-DOMAIN-ENTRY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) INTL::NOTE-TRANSLATABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) INTL::OCTETS-TO-STRING)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION ((VECTOR UNSIGNED-CHAR) (VECTOR UNSIGNED-CHAR) *)
-                T)
-            INTL::OCTETS=)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) INTL::PARSE-EXPR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) INTL::PARSE-PLURALS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) INTL::READ-BELONG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) INTL::READ-COMMENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) INTL::READ-LELONG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) INTL::READ-NESTED-COMMENT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION ((VECTOR UNSIGNED-CHAR) T T) *)
-            INTL::SEARCH-DOMAIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) INTL::STRING-TO-OCTETS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) INTL:DGETTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T INTEGER) T) INTL:DNGETTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) INTL:READ-TRANSLATABLE-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) INTL:SETLOCALE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA-NREGEX::REGEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA-NREGEX::REGEX-QUOTED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA-NREGEX:REGEX-COMPILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$%TH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$-READ-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$@-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$ACTIVATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$ADDCOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$ADDROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ADJOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ADJOINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$AIRY_AI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$AIRY_BI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$AIRY_DAI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$AIRY_DBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$ALGFAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$ALGNORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ALGSYS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$ALGTRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$ALLBUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ALLROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$APPEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$APPENDFILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$APPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ARRAYAPPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ARRAYMAKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$ARRAYSETAPPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) FIXNUM) MAXIMA::$ARRAY_DIMENSION_N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ASKEQUAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$ASKINTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ASKSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$ASSOC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$AT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$ATVALUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$AUGCOEFMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$BACKTRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$BASHINDICES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$BATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$BATCHLOAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$BDISCR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$BERN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$BERNPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$BESSEL_I)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$BESSEL_J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$BESSEL_K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$BESSEL_Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::$BETA_INCOMPLETE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            MAXIMA::$BETA_INCOMPLETE_GENERALIZED)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::$BETA_INCOMPLETE_REGULARIZED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$BEZOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$BFALLROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$BFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$BFLOATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$BFLOAT_APPROX_EQUAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$BF_FIND_ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$BINOMIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$BOTHCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$BOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$BREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$BT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$BUG_REPORT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$BUILD_INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$CABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$CARDINALITY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$CARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$CARLSON_RC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::$CARLSON_RD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::$CARLSON_RF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::$CARLSON_RJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$CARTESIAN_PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$CFDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$CFEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::$CHANGEVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$CHARPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$CHINESE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$CLEAR_RULES)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$CLOSEFILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$COEFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$COEFMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$COL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$COLLAPSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$COMBINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$COMPARE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$COMPILE_FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$CONCAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$CONCAT_POLYGONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$CONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$CONSTANTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$CONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$CONTOUR_PLOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$COPY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$COPYLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$COPYMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM) T) MAXIMA::$COPY_PTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$CSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$DEACTIVATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$DEBUGMODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::$DEFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$DEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$DELETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$DEMO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$DEMOIVRE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$DENOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$DEPENDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$DESOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$DETERMINANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$DIAGMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$DIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$DIRECTORY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$DISJOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$DISJOINTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$DISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$DISPFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$DISPTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$DISTRIB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$DIVIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$DIVSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$DOUBLE_FACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$DPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ECHELON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ED)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_ADD)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_ADD_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$EF_AT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_CARDINALITY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_COMPOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::$EF_DEGREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EF_DETERMINANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_DIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EF_EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL FIXNUM) MAXIMA::$EF_EXPONENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EF_FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_GCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_GCDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_GET_DATA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_INDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_INFOLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_INV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EF_INVERT_BY_LU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_IRREDUCIBLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_IRREDUCIBLE_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_JACOBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_L2N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_L2P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$EF_LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_MATADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_MATMULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EF_MATNEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EF_MINIMAL_POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_MINIMAL_SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_MULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_MULT_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER *) T) MAXIMA::$EF_N2L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_N2P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_NEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_NORM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_NORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_NORMAL_BASIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_NORMAL_BASIS_REP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_NORMAL_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_NTH_ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$EF_P2L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_P2N)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_POWER_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_PRIMITIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_PRIMITIVE_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_PRIMITIVE_POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_PRIMITIVE_POLY_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_RANDOM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_RANDOM_NORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$EF_REDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_REDUCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_SET_AGAIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_SET_DATA)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$EF_SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_TRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EF_UNIT_P)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$EF_UNSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ELEMENTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ELIMINATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ELLIPTIC_E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ELLIPTIC_EC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ELLIPTIC_EU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ELLIPTIC_F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ELLIPTIC_KC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::$ELLIPTIC_PI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::$EMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EMPTYP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ENDCONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ENTERMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ENTIER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$EQUIV_CLASSES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ERFI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ERF_GENERALIZED)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$ERRORMSG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EULER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$EULERPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EVENP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$EVERY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EXP-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$EXPINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPINTEGRAL_CHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPINTEGRAL_CI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$EXPINTEGRAL_E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPINTEGRAL_E1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPINTEGRAL_EI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPINTEGRAL_LI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPINTEGRAL_SHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPINTEGRAL_SI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$EXPONENTIALIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$EXTREMAL_SUBSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$EZGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$FACOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FACTCOMB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$FACTOROUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FACTORSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$FACTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$FASTTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$FEATUREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FIB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$FIBTOPHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$FILENAME_MERGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$FILE_SEARCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$FILE_SEARCH1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FILE_TYPE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$FILLARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$FIND_ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FIRST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$FIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FLATTEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FLOATNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$FLOAT_APPROX_EQUAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$FORTMX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$FREEOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$FRESNEL_C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$FRESNEL_S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$FULLRATSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$FULLSETIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$FULL_LISTIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$FUNMAKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$GAMMA_INCOMPLETE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::$GAMMA_INCOMPLETE_GENERALIZED)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) *) MAXIMA::$GAMMA_INCOMPLETE_REGULARIZED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$GCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GCFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$GENERALIZED_LAMBERT_W)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GENFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$GENMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GENSYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GET)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GET_PLOT_OPTION)) 
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:FLOAT LISP:RATIONAL))|
+            MAXIMA::DISCONTINUITIES-IN-INTERVAL
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (BIGFLOAT LISP:FLOAT))|
+            MAXIMA::*F-PRIM-P-1 MAXIMA::LEGEN
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:FLOAT LISP:FLOAT))|
+            MAXIMA::MATOUT MAXIMA::CXERFARG
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (BIGFLOAT BIGFLOAT))|
+            MAXIMA::DEN1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (BIGFLOAT LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (NUMBER NUMBER))|
+            MAXIMA::Z2 MAXIMA::ONE-STEP
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (NUMBER NUMBER))|
+            MAXIMA::ZN_ORDER
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::MONICGCD MAXIMA::POLFOO MAXIMA::DECLARE1
+            MAXIMA::MDATA MAXIMA::MSIZE-FUNCTION
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:FLOAT LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD RANDOM (LISP:FLOAT))|
+            MAXIMA::ENPROG MAXIMA::PSTIMES*2 MAXIMA::ATOMAT
+            MAXIMA::CASE1 MAXIMA::EXTEND MAXIMA::PSFLOAT1
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:RATIONAL LISP:FLOAT))|
+            MAXIMA::GF-NRT MAXIMA::SOLCOEF MAXIMA::GF-ORD
+            MAXIMA::$TMLIN MAXIMA::CFFUN MAXIMA::PWTAYLOR
+            MAXIMA::PTCSUB MAXIMA::GF-XYECPLUS
+            MAXIMA::GF-DLOG-RHO-BRENT MAXIMA::LAGRANGE3
+            BIGFLOAT::|(PCL::FAST-METHOD PRINT-OBJECT (BIGFLOAT T))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (BIGFLOAT BIGFLOAT))|
+            MAXIMA::ECM-POWER
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (BIGFLOAT LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (NUMBER NUMBER))|
+            MAXIMA::ZQ-NRT MAXIMA::LOGNX2 MAXIMA::MEVALSUMARG
+            MAXIMA::MAKE-PARSER-FUN-DEF
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:FLOAT LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:FLOAT LISP:FLOAT))|
+            MAXIMA::MRV-REWRITE MAXIMA::FORMX MAXIMA::CDIVID-SL
+            MAXIMA::COEFFTT MAXIMA::CPTOMEXP MAXIMA::MERGE-SOL-LIN-Z
+            MAXIMA::SUBARGCHECK MAXIMA::CASE0 MAXIMA::TMLIN
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (NUMBER NUMBER))|
+            MAXIMA::GF-NORMAL-BASIS-REP MAXIMA::INITIAL-ANALYSIS
+            BIGFLOAT::|(PCL::FAST-METHOD MAKE-LOAD-FORM (COMPLEX-BIGFLOAT))|
+            MAXIMA::QUAD_ARGUMENT_CHECK MAXIMA::COMPATVARL
+            MAXIMA::RESPROG0 MAXIMA::CPTOM MAXIMA::SP1SINCOS1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:RATIONAL LISP:RATIONAL))|
+            MAXIMA::MATCH-SIGN
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:RATIONAL LISP:RATIONAL))|
+            MAXIMA::PJACTF
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (BIGFLOAT LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMBER NUMBER))|
+            MAXIMA::PSMONSUBST MAXIMA::DSKSTORE
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (BIGFLOAT LISP:RATIONAL))|
+            MAXIMA::DLOG-BABY-GIANT MAXIMA::COMPLEXITY/COL
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:RATIONAL LISP:FLOAT))|
+            MAXIMA::CONF1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:FLOAT LISP:RATIONAL))|
+            MAXIMA::D-MATRIX MAXIMA::F19COND MAXIMA::SIN-COS-INTSUBS
+            MAXIMA::KILL2
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:RATIONAL LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (BIGFLOAT LISP:FLOAT))|
+            MAXIMA::RES
+            BIGFLOAT::|(PCL::FAST-METHOD SCALE-FLOAT (LISP:FLOAT INTEGER))|
+            MAXIMA::FACT2Z MAXIMA::PSDERIV1 MAXIMA::TIMER-MLIST
+            MAXIMA::PROP1 MAXIMA::PINTERPOLATE5 MAXIMA::OTRACEMOD
+            MAXIMA::SIMPSUM2 MAXIMA::REFINE
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:RATIONAL LISP:FLOAT))|
+            MAXIMA::SOLVE-A*F<X>^N+B1 MAXIMA::ZQ-AMM
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (BIGFLOAT LISP:FLOAT))|
+            MAXIMA::RISPLIT-EXPT-GENERAL-FORM
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::DINTBYPART
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:RATIONAL LISP:FLOAT))|
+            MAXIMA::LIMCP MAXIMA::MAYBE-BREAK MAXIMA::PART1
+            MAXIMA::GF-DLOG-BABY-GIANT MAXIMA::SIMPPROD1
+            MAXIMA::EVERYPTERMS
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:RATIONAL LISP:RATIONAL))|
+            MAXIMA::METHOD-RADICAL-POLY
+            BIGFLOAT::|(PCL::FAST-METHOD DESCRIBE-OBJECT (BIGFLOAT T))|
+            MAXIMA::SUBSTPART-TRANSLATION MAXIMA::SIGNDIS3
+            MAXIMA::SUMSUM MAXIMA::LIMIT-POLE MAXIMA::FSGEO
+            MAXIMA::FBINO MAXIMA::SP1ADDBUC
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:FLOAT LISP:FLOAT))|
+            MAXIMA::TRIVIAL1 MAXIMA::INTERHERMPOL MAXIMA::ZFACT
+            MAXIMA::ECM-PRODUCT MAXIMA::COMDENOM1 MAXIMA::KILL3
+            MAXIMA::EVERYPTERMS1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMBER NUMBER))|
+            MAXIMA::PSDP2
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:FLOAT LISP:RATIONAL))|
+            MAXIMA::BF-CDIVID-SL MAXIMA::SIMPSUM1 MAXIMA::COEFFPORT
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:RATIONAL LISP:FLOAT))|
+            MAXIMA::MYDEFINT
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (BIGFLOAT LISP:RATIONAL))|
+            MAXIMA::ONEN
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:FLOAT LISP:RATIONAL))|
+            MAXIMA::MDEFCHK MAXIMA::TEX-LIST MAXIMA::DEFINT
+            BIGFLOAT::|(PCL::FAST-METHOD PRINT-OBJECT (COMPLEX-BIGFLOAT T))|
+            MAXIMA::REMOV2 MAXIMA::FANCYPOIS1S MAXIMA::GF-AMM
+            MAXIMA::GF-MULT-TABLE MAXIMA::GCTIMES MAXIMA::TEX-FUNCTION
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::POLES-IN-INTERVAL
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:RATIONAL LISP:RATIONAL))|
+            MAXIMA::COMPATVARLIST MAXIMA::TRY-DEFINT MAXIMA::FINITE-SUM
+            MAXIMA::COEFFRET MAXIMA::MPROPSCHK MAXIMA::COMPLEXITY/ROW
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:RATIONAL LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::*F-DLOGB MAXIMA::MEVALP2 MAXIMA::FLOAT-NEWTON
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:RATIONAL LISP:FLOAT))|
+            MAXIMA::FANCYPOIS1C MAXIMA::GF-NXYECPLUS MAXIMA::WHITTEST
+            MAXIMA::PJAC
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:RATIONAL BIGFLOAT))|
+            MAXIMA::TMLATTICE
+            BIGFLOAT::|(PCL::FAST-METHOD RANDOM (INTEGER))|
+            BIGFLOAT::|(PCL::FAST-METHOD MAKE-LOAD-FORM (BIGFLOAT))|
+            MAXIMA::PTPT-SUBTRACT-POWERED-PRODUCT MAXIMA::REMOV1
+            MAXIMA::SPDERIVATIVE1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG->= (LISP:RATIONAL BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:FLOAT LISP:FLOAT))|
+            MAXIMA::SRINTEGEXPD
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:FLOAT LISP:FLOAT))|
+            MAXIMA::NEWMAT
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:FLOAT LISP:FLOAT))|
+            MAXIMA::IPOLY2
+            BIGFLOAT::|(PCL::FAST-METHOD RANDOM (BIGFLOAT))|
+            MAXIMA::LAGRANGE33
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (BIGFLOAT LISP:FLOAT))|
+            MAXIMA::BFLOAT-NEWTON MAXIMA::DSKARY MAXIMA::TAKE-PRINCIPAL
+            MAXIMA::MARRAYSET-GENSUB MAXIMA::$SETELMX
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-> (LISP:RATIONAL BIGFLOAT))|
+            MAXIMA::DEFA1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:RATIONAL LISP:FLOAT))|
+            MAXIMA::POWEROFX MAXIMA::COMPLETEVECTOR MAXIMA::ORDLIST
+            MAXIMA::MSZNARY
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (NUMBER NUMBER))|
+            MAXIMA::PARSE-INTEGRAND MAXIMA::DLOG-RHO MAXIMA::ZEROP/ROW
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-< (LISP:FLOAT LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-<= (LISP:RATIONAL BIGFLOAT))|
+            MAXIMA::ZN-PRIMROOT-P)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MATCHFIX
+            MAXIMA::ALLSUBST00 MAXIMA::GF-DATA-SHORT-PRINT
+            MAXIMA::WTPTIMES1 MAXIMA::AVLINSERT MAXIMA::MEMSIMILAR
+            MAXIMA::$EXTREMAL_SUBSET MAXIMA::PART* MAXIMA::DIAGMATRIX
+            MAXIMA::GCD-DEGREE-VECTOR MAXIMA::COEFFP
+            MAXIMA::CHECKDERIV1
+            BIGFLOAT::|(PCL::FAST-METHOD EXP (NUMBER))| MAXIMA::LOGX1
+            MAXIMA::FINDBASE MAXIMA::TRACE-ERROR-BREAK
+            MAXIMA::INTERVAL-LIST MAXIMA::SOLVENTH3 MAXIMA::DSTRB
+            MAXIMA::GF-TRACE-POLY-F2
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-CEILING (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD ZEROP (NUMBER))|
+            MAXIMA::$RATSUBST BIGFLOAT::|(PCL::FAST-METHOD REALP (T))|
+            MAXIMA::NEWDET BIGFLOAT::|(PCL::FAST-METHOD SINH (NUMBER))|
+            MAXIMA::NISARGSCHECKER
+            BIGFLOAT::|(PCL::FAST-METHOD REAL-VALUE (BIGFLOAT))|
+            MAXIMA::SUBSTFORSUM MAXIMA::GF-NORMAL MAXIMA::PGCDU1
+            BIGFLOAT::|(PCL::FAST-METHOD PLUSP (BIGFLOAT))|
+            MAXIMA::POISMERGECX
+            BIGFLOAT::|(PCL::FAST-METHOD %E (LISP:RATIONAL))|
+            MAXIMA::DRAW2D-PARAMETRIC-ADAPTIVE MAXIMA::SIMPLAMBDA
+            MAXIMA::SP1SINCOS2 MAXIMA::GETLABELS MAXIMA::TEX-SUM
+            MAXIMA::CHECK-CALL-TO-$SPECINT MAXIMA::COEFFT
+            MAXIMA::DEG-LESSP MAXIMA::BIG-PRIME-VAR MAXIMA::TEX-LSUM
+            MAXIMA::COLLISION-LOOKUP MAXIMA::IN-INTERVAL
+            MAXIMA::EPROGRATD
+            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (T))|
+            BIGFLOAT::|(PCL::FAST-METHOD ASINH (NUMBER))|
+            MAXIMA::FACTPLUS1 MAXIMA::MRV-LEADTERM
+            MAXIMA::LITTLESLOMMEL MAXIMA::MBIND-DOIT
+            MAXIMA::OUTPUT-POINTS-TCL MAXIMA::DPREMQUO MAXIMA::$BEZOUT
+            MAXIMA::INSRT
+            BIGFLOAT::|(PCL::FAST-METHOD SIGNUM (NUMBER))|
+            MAXIMA::NEWVARMEXPT MAXIMA::PELSO1 MAXIMA::META-PUTPROP
+            MAXIMA::LT1YREF MAXIMA::DLOG-NAIVE MAXIMA::INHERIT-PROPL
+            MAXIMA::MSZ-MDEF MAXIMA::SPC5 MAXIMA::$POWER_MOD
+            MAXIMA::SIMP-%SINH MAXIMA::SUBST1 MAXIMA::POISMERGEC
+            MAXIMA::MTF BIGFLOAT::|(PCL::FAST-METHOD %PI (BIGFLOAT))|
+            MAXIMA::RATTI MAXIMA::POISMERGESX MAXIMA::ISGEO1
+            MAXIMA::FACTPOWERSELECT MAXIMA::GETEXP-FUN MAXIMA::PTF
+            MAXIMA::CDINF MAXIMA::SIMPLIM%FRESNEL_C MAXIMA::VAR-EXPAND
+            MAXIMA::$ILT MAXIMA::KSUBSET-LEX-SUCCESSOR
+            MAXIMA::DEFAULT-FORMAT-PROMPT MAXIMA::SIMPTIMES
+            MAXIMA::TESTA* MAXIMA::TEX-ATOM MAXIMA::TEX-MATRIX
+            MAXIMA::SIMP-%SIN MAXIMA::ADD2CSTR MAXIMA::MONOMGCDCO
+            MAXIMA::PRESULTANT
+            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (COMPLEX-BIGFLOAT))|
+            MAXIMA::NISSEARCH MAXIMA::MINOR MAXIMA::PTTS1 MAXIMA::WTM
+            MAXIMA::GET-LEXP MAXIMA::MLISTCAN-$ALL MAXIMA::PSP2FORM
+            MAXIMA::GAM-CONST MAXIMA::NROOT1 MAXIMA::FACTPLUS0
+            MAXIMA::MSZ-MTIMES MAXIMA::M2-LTEP MAXIMA::CPBGZASS
+            MAXIMA::PSCDIFF MAXIMA::LHSIMP MAXIMA::PSCSUBST
+            BIGFLOAT::|(PCL::FAST-METHOD MINUSP (BIGFLOAT))|
+            MAXIMA::PSDISREP2 MAXIMA::MSZ-MQAPPLY MAXIMA::GF-TRACE
+            MAXIMA::SIMP-%TANH MAXIMA::DBUNIVAR MAXIMA::MARK+0
+            MAXIMA::POISSUBSTA MAXIMA::ASSSO MAXIMA::SIMP-SET
+            MAXIMA::PREFIXCONC MAXIMA::TEX-MEXPT MAXIMA::TR-MPROG-BODY
+            MAXIMA::TEX-MDO MAXIMA::DECLVALUE MAXIMA::ATFIND
+            BIGFLOAT::|(PCL::FAST-METHOD MINUSP (LISP:RATIONAL))|
+            MAXIMA::SIMP-LIMIT MAXIMA::SIMP-CHARFUN MAXIMA::DVCOE
+            MAXIMA::FREE2 MAXIMA::TRACEMOD1
+            MAXIMA::NUMERIC-BETA-INCOMPLETE
+            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD %E (LISP:COMPLEX))|
+            BIGFLOAT::|(PCL::FAST-METHOD RATIONAL (BIGFLOAT))|
+            MAXIMA::PSCOEF MAXIMA::LOBJ->POLY MAXIMA::TEX-MTEXT
+            BIGFLOAT::|(PCL::FAST-METHOD CONJUGATE (NUMBER))|
+            MAXIMA::INTERVAL-ERROR MAXIMA::POLELIST
+            MAXIMA::TEX-BIGFLOAT MAXIMA::GF-PRIMPOLY-P-EXIT
+            MAXIMA::SIMP-$IS MAXIMA::MSIZE-MTEXT MAXIMA::DGQF
+            MAXIMA::DSUBSTA MAXIMA::$ARRAYSETAPPLY
+            MAXIMA::M2-D*X^M*%E^A*X MAXIMA::CF MAXIMA::WTPTIMES
+            MAXIMA::MSZ-MEXPT MAXIMA::TSDIFF MAXIMA::SP1PUTBUC1
+            MAXIMA::UNI MAXIMA::GF-EQUAL-DEGREE-FACTORS
+            MAXIMA::SIGNDISCR MAXIMA::REMFACTOR MAXIMA::MSZ-MDO
+            MAXIMA::EVAL-PRED MAXIMA::SIMPPROD
+            BIGFLOAT::|(PCL::FAST-METHOD ATANH (COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD CIS (LISP:RATIONAL))|
+            MAXIMA::POWER-MOD MAXIMA::MSIZE-LIST MAXIMA::MSZ-MCOND
+            MAXIMA::PALGSIMP
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-DIVIDE (NUMBER))|
+            MAXIMA::ARRSTORE-EXTEND MAXIMA::HGFSIMP-EXEC
+            MAXIMA::*F-NP2SMOD MAXIMA::MSIZE-TEXT-STRING MAXIMA::TMS
+            MAXIMA::EXPPLYGAM-FUNS
+            BIGFLOAT::|(PCL::FAST-METHOD PHASE (NUMBER))|
+            MAXIMA::TMEXCHANGE INTL::LOCATE-DOMAIN-FILE
+            BIGFLOAT::|(PCL::FAST-METHOD MINUSP (LISP:FLOAT))|
+            MAXIMA::GFACT MAXIMA::EVAL-DERIV MAXIMA::SIMP-MOR
+            BIGFLOAT::|(PCL::FAST-METHOD %PI (LISP:COMPLEX))|
+            BIGFLOAT::|(PCL::FAST-METHOD ACOS (NUMBER))| MAXIMA::TESTA
+            MAXIMA::PERIOD MAXIMA::TRACE-EXIT-BREAK MAXIMA::LTY
+            MAXIMA::MULTIPLE-%PI
+            BIGFLOAT::|(PCL::FAST-METHOD SUB1 (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD COSH (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD ABS (NUMBER))|
+            MAXIMA::DRAW-LINEAR
+            BIGFLOAT::|(PCL::FAST-METHOD PLUSP (LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (T))|
+            BIGFLOAT::|(PCL::FAST-METHOD ASINH (COMPLEX-BIGFLOAT))|
+            MAXIMA::MWHIT MAXIMA::*F-PRIM MAXIMA::GF-DEGREE-ERRCHK
+            MAXIMA::PSCOEFF1 MAXIMA::NEW-FILE-SEARCH1
+            BIGFLOAT::|(PCL::FAST-METHOD ACOSH (COMPLEX-BIGFLOAT))|
+            MAXIMA::PUTPROP MAXIMA::SP1PUTBUC MAXIMA::PSQUOREM1
+            MAXIMA::ISOLAT MAXIMA::SP2DIFF2 MAXIMA::PSHIFT
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-ATAN (NUMBER))|
+            MAXIMA::QUAD-SL
+            BIGFLOAT::|(PCL::FAST-METHOD %E (BIGFLOAT))| MAXIMA::GEREDF
+            MAXIMA::DIMCHECK MAXIMA::QTF MAXIMA::DRAW2D
+            MAXIMA::SIMPMDEFMACRO MAXIMA::BAKALEVEL MAXIMA::CSEMIUP
+            MAXIMA::TEX-KRON-DELTA MAXIMA::PIVOT
+            BIGFLOAT::|(PCL::FAST-METHOD IMAG-VALUE (COMPLEX-BIGFLOAT))|
+            MAXIMA::GF-MATADD1 MAXIMA::SIGNDIS1 MAXIMA::COLOUT
+            MAXIMA::PINTERP MAXIMA::RESOLVENT MAXIMA::DSKSETUP
+            MAXIMA::PUTPROP1 MAXIMA::BAKALEVEL1 MAXIMA::GERED2
+            MAXIMA::DIONARGHYP
+            BIGFLOAT::|(PCL::FAST-METHOD SINH (COMPLEX-BIGFLOAT))|
+            MAXIMA::SQFRNORM MAXIMA::$HGFPOLY
+            MAXIMA::SIMP-DOUBLE-FACTORIAL MAXIMA::MSIZE-NARY
+            MAXIMA::$ALGNORM MAXIMA::MTORAT MAXIMA::TEX-SPACEOUT
+            MAXIMA::IS-MOR_TR MAXIMA::COLLISION-CHECK
+            MAXIMA::SUBST-EXCEPT-SECOND-ARG MAXIMA::TCONS3
+            MAXIMA::SIMP-MAND MAXIMA::PARTITION MAXIMA::MULTBK
+            MAXIMA::RESIDUE MAXIMA::NEWGCD MAXIMA::SIMPGFACT
+            MAXIMA::NISTREEBUILDER MAXIMA::MSIZE-SPACEOUT
+            MAXIMA::MEASURE MAXIMA::*F-PRECOMP MAXIMA::PUT-TRACE-INFO
+            MAXIMA::AL1 MAXIMA::PGATHERCOEF MAXIMA::TEX-NARY
+            MAXIMA::KILL
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FLOOR (BIGFLOAT))|
+            MAXIMA::INTERP-POLYS MAXIMA::GF-NORM MAXIMA::MSIZE-MATCHFIX
+            MAXIMA::IS-MAND_TR MAXIMA::PGSUBST MAXIMA::$PUT
+            BIGFLOAT::|(PCL::FAST-METHOD COS (COMPLEX-BIGFLOAT))|
+            MAXIMA::X**Q MAXIMA::PADE MAXIMA::NOUNLIMIT
+            MAXIMA::LTERMVEC MAXIMA::TEX-LIMIT MAXIMA::KERNSUBST
+            MAXIMA::TEX-MCOND MAXIMA::SIMP-%AT MAXIMA::BEHAVIOR-BY-DIFF
+            MAXIMA::EVERYSUBST1 MAXIMA::INSURE-ARRAY-PROPS
+            BIGFLOAT::|(PCL::FAST-METHOD TAN (COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD %E (COMPLEX-BIGFLOAT))|
+            MAXIMA::PASIMP1 MAXIMA::DSKDEFPROP MAXIMA::EXPASIN-FUNS
+            MAXIMA::SIMPBUILDQ MAXIMA::NPROD
+            BIGFLOAT::|(PCL::FAST-METHOD ADD1 (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (LISP:COMPLEX))|
+            MAXIMA::LINEARIZE3 MAXIMA::PTORAT MAXIMA::LINHACKCONTENT
+            MAXIMA::STEP4 MAXIMA::DIFFINT1 MAXIMA::FIXVL0
+            MAXIMA::DIONARGHYP-Y MAXIMA::FACT20 MAXIMA::ATDECODE
+            MAXIMA::MONICIZE-ROW MAXIMA::MSZ-MDOIN
+            BIGFLOAT::|(PCL::FAST-METHOD PLUSP (LISP:FLOAT))|
+            MAXIMA::TFGELI1 MAXIMA::MSIZE-ARRAY-OBJECT MAXIMA::ILT1
+            MAXIMA::DEFS1
+            BIGFLOAT::|(PCL::FAST-METHOD ZEROP (COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD %E (LISP:FLOAT))|
+            MAXIMA::GF-GCDEX
+            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (LISP:COMPLEX))|
+            MAXIMA::SIMP-ROUND
+            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (LISP:RATIONAL))|
+            MAXIMA::SETARG1 MAXIMA::TRY-INTSC MAXIMA::EXPTAN-FUNS
+            MAXIMA::POISMERGES MAXIMA::LIFTING-FACTORS-IMAGE
+            MAXIMA::MAKE-OPERATION MAXIMA::PLYGAM-CONST MAXIMA::TFGELI
+            MAXIMA::PCSUBST MAXIMA::MINVARLIST-MRAT
+            MAXIMA::FIXED-LENGTH-PARTITIONS
+            BIGFLOAT::|(PCL::FAST-METHOD ASIN (NUMBER))|
+            MAXIMA::SIMP-%JACOBI_AM MAXIMA::RATSIMP MAXIMA::NISARGMATCH
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-MINUS (NUMBER))|
+            MAXIMA::GF-TIMES MAXIMA::J2TF MAXIMA::TEX-AT MAXIMA::EXECFY
+            MAXIMA::PRSNARY MAXIMA::RGSUBST
+            BIGFLOAT::|(PCL::FAST-METHOD ATANH (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD EXP (COMPLEX-BIGFLOAT))|
+            MAXIMA::MPUTPROP MAXIMA::EZGCD MAXIMA::TEX-MDOIN
+            MAXIMA::MRV-COMPARE MAXIMA::FACT MAXIMA::MEMBERROOT
+            MAXIMA::POWERSET-SUBSET MAXIMA::GF-JACOBI MAXIMA::LAPSHIFT
+            BIGFLOAT::|(PCL::FAST-METHOD SQRT (NUMBER))|
+            MAXIMA::SIMP-EXPINTEGRAL-CHI MAXIMA::LIMIT-CONTEXT
+            BIGFLOAT::|(PCL::FAST-METHOD ACOSH (NUMBER))|
+            MAXIMA::DECLMODE MAXIMA::DISP1 MAXIMA::RATDP2
+            MAXIMA::CREATE-ANY-POLY
+            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (NUMBER))|
+            CL-INFO::LOAD-INFO-HASHTABLES MAXIMA::BOOL-CHECKED-MFUNCALL
+            MAXIMA::$PFACTORALG MAXIMA::EF-DATA-SHORT-PRINT
+            BIGFLOAT::|(PCL::FAST-METHOD REAL-VALUE (COMPLEX-BIGFLOAT))|
+            MAXIMA::PCSUBSTY MAXIMA::MSIZE-ATOM MAXIMA::PRED-$READ
+            MAXIMA::TEX-MQUOTIENT MAXIMA::SIMP-%AIRY_DAI
+            MAXIMA::INTEGRATE-USE-ROOTSOF MAXIMA::REF MAXIMA::$ALGTRACE
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-COMPLEX (LISP:FLOAT))|
+            MAXIMA::PART+ MAXIMA::ZASSG MAXIMA::FILTER-SUM
+            MAXIMA::TFGELI0 MAXIMA::MACSYMA-UNTRACE-SUB
+            MAXIMA::SIMPARGS1 MAXIMA::$HGFRED MAXIMA::REF-FPQ
+            MAXIMA::STEP4-A MAXIMA::PCOEFADD MAXIMA::NISLET
+            BIGFLOAT::|(PCL::FAST-METHOD %PI (LISP:RATIONAL))|
+            MAXIMA::TRY-INTSUBS MAXIMA::INTERVAL2 MAXIMA::TEX-MQAPPLY
+            MAXIMA::PSDISEXCNT
+            BIGFLOAT::|(PCL::FAST-METHOD RATIONAL (LISP:RATIONAL))|
+            MAXIMA::BOOLEAN-CONVERT
+            BIGFLOAT::|(PCL::FAST-METHOD IMAGPART (NUMBER))|
+            MAXIMA::TEX-MLABOX
+            BIGFLOAT::|(PCL::FAST-METHOD COMPLEXP (LISP:COMPLEX))|
+            MAXIMA::MERGE11 MAXIMA::GF-NCX MAXIMA::GF-POW$
+            MAXIMA::META-MPUTPROP
+            BIGFLOAT::|(PCL::FAST-METHOD %PI (LISP:FLOAT))|
+            MAXIMA::SIMP-%AIRY_AI MAXIMA::SMINMAX MAXIMA::VMAKE
+            MAXIMA::GEREDNO2
+            MAXIMA::BETA-INCOMPLETE-EXPAND-NEGATIVE-INTEGER
+            MAXIMA::MABS-SUBST MAXIMA::PARTIAL-DIAG
+            MAXIMA::GF-DLOG-NAIVE MAXIMA::PINTERPOLATE6
+            MAXIMA::PRIMELMT MAXIMA::REPLACEROW
+            BIGFLOAT::|(PCL::FAST-METHOD %PI (COMPLEX-BIGFLOAT))|
+            MAXIMA::F2P105V2COND MAXIMA::EVERYSUBST00 MAXIMA::SPLITPFQ
+            MAXIMA::LOG-TRANSFORM MAXIMA::DGRF MAXIMA::DISPFUN1
+            MAXIMA::DPDIF1 MAXIMA::CONSFUNDEF
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-COMPLEX (LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-SIGN (LISP:FLOAT))|
+            MAXIMA::MEVALP_TR MAXIMA::KANSEL MAXIMA::LIN-VAR-FIND
+            MAXIMA::EXPSEC-FUNS MAXIMA::MAKE-LIMIT-ASSUMPTIONS
+            MAXIMA::SUBFUNMAKES MAXIMA::GF-MATMULT1 MAXIMA::BF-QUAD-SL
+            MAXIMA::PGCDA MAXIMA::SIMP-REALPART MAXIMA::CSEMIDOWN
+            MAXIMA::ADDVARDEG
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-DIGITS (BIGFLOAT))|
+            MAXIMA::SIMPLIM%FRESNEL_S MAXIMA::FINDFUN MAXIMA::SIMPMDEF
+            BIGFLOAT::|(PCL::FAST-METHOD REALPART (NUMBER))|
+            MAXIMA::SIMP-KRON-DELTA MAXIMA::EVERYSUBST0
+            MAXIMA::ASS-EQ-SET
+            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (LISP:FLOAT))|
+            MAXIMA::$POISMAP MAXIMA::SWAP-ROWS MAXIMA::PVSUBST
+            MAXIMA::RISCHEXPVAR MAXIMA::PEXPTMOD MAXIMA::FIND-CF1
+            MAXIMA::X$-CL-MACRO-READ MAXIMA::GERED1
+            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD REALP (BIGFLOAT))|
+            MAXIMA::SIGNAL-MODE-ERROR MAXIMA::TODD-COXETER
+            MAXIMA::SYMBOLIC-EXPAND MAXIMA::PSISIMP MAXIMA::TSPRSUM
+            MAXIMA::LET-MACRO-HAIR MAXIMA::$RESULTANT MAXIMA::GAMMAC
+            MAXIMA::$MINOR MAXIMA::MSIZE-INFIX MAXIMA::SIMPSUM
+            MAXIMA::ALT-FORMAT-PROMPT MAXIMA::SIMPLUS
+            BIGFLOAT::|(PCL::FAST-METHOD COS (NUMBER))|
+            MAXIMA::POWERCOEFLIST MAXIMA::SYNTACTIC-SUBSTITUTE
+            MAXIMA::GF-MATADD2 MAXIMA::CD1 MAXIMA::ATAN-POLE1
+            MAXIMA::ZFF MAXIMA::RE-SOLVE
+            BIGFLOAT::|(PCL::FAST-METHOD SIN (COMPLEX-BIGFLOAT))|
+            MAXIMA::TEX-INT MAXIMA::ASK-PROP
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-TRUNCATE (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (COMPLEX-BIGFLOAT))|
+            MAXIMA::ZEPOW MAXIMA::MSUM MAXIMA::MSZ-BIGFLOAT
+            MAXIMA::DNQF MAXIMA::MARK+1 MAXIMA::$ATVALUE
+            BIGFLOAT::|(PCL::FAST-METHOD TANH (COMPLEX-BIGFLOAT))|
+            MAXIMA::PEXPON*// MAXIMA::Z1 MAXIMA::STEP4-INT
+            MAXIMA::MULTIPLY-MATRIX-ELEMENTS BIGFLOAT::AGM-SCALE
+            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (COMPLEX-BIGFLOAT))|
+            MAXIMA::MARK-0 MAXIMA::ZN-P-ERRCHK MAXIMA::SMONOGEN
+            BIGFLOAT::|(PCL::FAST-METHOD ASIN (COMPLEX-BIGFLOAT))|
+            MAXIMA::PFACTORALG1 MAXIMA::MSZ MAXIMA::PRESULT
+            MAXIMA::SIMP-%AIRY_DBI MAXIMA::RES1 MAXIMA::SUBFUNMAKE
+            MAXIMA::MFACT MAXIMA::NISMATCH MAXIMA::MKILL
+            MAXIMA::PLYGAM-POLE MAXIMA::SP2INTEG12 MAXIMA::DSKRAT-SUBST
+            MAXIMA::TEX-RAT MAXIMA::ROOTADDUP MAXIMA::DLSF
+            MAXIMA::TEX-ARRAY MAXIMA::NISEXPOCHECK MAXIMA::BEHAVIOR
+            MAXIMA::COERCE-REL MAXIMA::FPQFORM MAXIMA::SIMP-%TAN
+            MAXIMA::WWHIT MAXIMA::TR-MASET
+            BIGFLOAT::|(PCL::FAST-METHOD CIS (LISP:FLOAT))|
+            MAXIMA::ECM-SQUARE MAXIMA::DRAW2D-PARAMETRIC
+            MAXIMA::GET-NEWEXP&FACTORS MAXIMA::SUBST-IF-NOT-FREEOF
+            MAXIMA::MAKE-TRACE-HOOK MAXIMA::PUT-MODE
+            MAXIMA::PTCSUB-ARGS MAXIMA::LCHK MAXIMA::SET-UP
+            MAXIMA::MEQP-BY-CSIGN MAXIMA::RATTIMES
+            BIGFLOAT::|(PCL::FAST-METHOD TANH (NUMBER))|
+            MAXIMA::STRICTLY-IN-INTERVAL MAXIMA::DEQF
+            MAXIMA::SLOMMELTJANDY MAXIMA::EVERYSUBST
+            BIGFLOAT::|(PCL::FAST-METHOD COSH (COMPLEX-BIGFLOAT))|
+            MAXIMA::COMMONROOTS MAXIMA::PSCHECK
+            MAXIMA::RISPLIT-EXPT-SQRT-POW MAXIMA::CPUT MAXIMA::STF
+            MAXIMA::PCETIMES1 MAXIMA::DIV-DEG-CHK MAXIMA::SET-LINEINFO
+            MAXIMA::ANNOUNCE-RULE-FIRING
+            BIGFLOAT::|(PCL::FAST-METHOD MAX-EXPONENT (BIGFLOAT))|
+            MAXIMA::LOADFILE MAXIMA::FINDEXPON MAXIMA::COEFFPT
+            BIGFLOAT::|(PCL::FAST-METHOD ACOS (COMPLEX-BIGFLOAT))|
+            MAXIMA::SUBSTITUTEL MAXIMA::MARK-1 MAXIMA::EASY-CASES
+            MAXIMA::ATAN-POLES MAXIMA::FACRTIMES MAXIMA::RATGSUBST
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-LOG (NUMBER))|
+            MAXIMA::EXPLIST MAXIMA::MARRAYSET1$ MAXIMA::DEF-BREAK
+            MAXIMA::TEX-MBOX MAXIMA::GF-LOG-ERRCHK2 MAXIMA::STURMAPC
+            MAXIMA::LUCAS-SEQUENCE MAXIMA::$SET_TEX_ENVIRONMENT
+            MAXIMA::TS-FORMULA MAXIMA::DSKATOM MAXIMA::SIMPLIM$MIN
+            MAXIMA::SIMP-%AIRY_BI MAXIMA::LISIMP MAXIMA::DIAGLIZE1
+            MAXIMA::ATOMCHK
+            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (LISP:FLOAT))|
+            MAXIMA::CPA MAXIMA::SET-LBP-AND-RBP MAXIMA::DLQF
+            MAXIMA::PGCDP MAXIMA::SIMP-$ELLIPTIC_EU MAXIMA::PDIAG-ALL
+            MAXIMA::LI-ASYMPTOTIC-EXPANSION
+            BIGFLOAT::|(PCL::FAST-METHOD NUMBERP (BIGFLOAT))|
+            MAXIMA::SIMP-CARG MAXIMA::MBIND MAXIMA::SP1ADDTO
+            MAXIMA::CALL-AND-SIMP MAXIMA::DEGVECTOR MAXIMA::RESULT1
+            MAXIMA::PCSUB
+            BIGFLOAT::|(PCL::FAST-METHOD REALP (LISP:FLOAT))|
+            MAXIMA::KEYHOLE MAXIMA::POISMERGE
+            BIGFLOAT::|(PCL::FAST-METHOD RATIONAL (LISP:FLOAT))|
+            MAXIMA::TMRATCONV
+            BIGFLOAT::|(PCL::FAST-METHOD TAN (NUMBER))|
+            MAXIMA::MSIZE-ARRAY MAXIMA::SPC5B MAXIMA::PROPSCHK
+            BIGFLOAT::|(PCL::FAST-METHOD COMPLEXP (COMPLEX-BIGFLOAT))|
+            MAXIMA::COEFVEC MAXIMA::LAMBDA-WRAP1 MAXIMA::RETFACTOR
+            MAXIMA::COEFMATRIX MAXIMA::$PADE MAXIMA::SIMPLIM$MAX
+            MAXIMA::ZN-PRIMROOT MAXIMA::TMNOMOREUSE MAXIMA::CONF2
+            MAXIMA::LAPEXPT MAXIMA::TRACE-ENTER-BREAK MAXIMA::FPSCAN
+            MAXIMA::REVEAL MAXIMA::TEX-CHOOSE MAXIMA::WTPCTIMES1
+            MAXIMA::TRIG-LOG-1-NEG MAXIMA::ESTCHECK2 MAXIMA::GF-COMPOSE
+            MAXIMA::NROOTS MAXIMA::EXP$LI-FUN
+            BIGFLOAT::|(PCL::FAST-METHOD REALP (LISP:RATIONAL))|
+            MAXIMA::BADFUNCHK MAXIMA::GENNEGS
+            BIGFLOAT::CHECK-LAMBERT-W-K MAXIMA::WHITFUN
+            MAXIMA::MEMSIMILARL MAXIMA::MRV-MAX
+            BIGFLOAT::|(PCL::FAST-METHOD COMPLEXP (T))|
+            MAXIMA::FPINTEXPT MAXIMA::SOLVE MAXIMA::REARRAY-AUX
+            MAXIMA::PDECRED BIGFLOAT::|(PCL::FAST-METHOD SIN (NUMBER))|
+            MAXIMA::TR-MACSYMA-USER-FUNCTION-CALL
+            MAXIMA::MACSYMA-TRACE-SUB MAXIMA::DISREP-MONOM)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::MOSTPART MAXIMA::INFOSTORE
+            MAXIMA::GF-POWER-TABLE MAXIMA::SLOW-OSCILLATION-P
+            MAXIMA::DEN1NUMN MAXIMA::PSDP1 MAXIMA::FRACTEST2
+            MAXIMA::TMUNPIVOT MAXIMA::PFRNUM MAXIMA::ZN-DLOG
+            MAXIMA::EZ1CALL MAXIMA::SIGNDIS2 MAXIMA::EXPPOLYCONTROL
+            MAXIMA::MOVEROW MAXIMA::EXPLOG-FUNS MAXIMA::MDEFARRAY
+            MAXIMA::DISPATCHPOLTRANS MAXIMA::NONCONSTQUADENUM
+            MAXIMA::RL-REDUCE MAXIMA::REMOVE1 MAXIMA::DECOMP-TRACE
+            MAXIMA::D-BOX BIGFLOAT::BF-NEWTON MAXIMA::TEST-INVERSE
+            MAXIMA::EXPEXP-FUNS MAXIMA::MLAMBDA MAXIMA::FANCYPOISSUBST
+            MAXIMA::DECOMP-CHAIN MAXIMA::LINHACK MAXIMA::EXPCOT-FUNS
+            MAXIMA::MOVECOL MAXIMA::INTEGERTEST MAXIMA::ZGCD-LIFT*
+            MAXIMA::XRUTOUT MAXIMA::ECM-FACTOR-WITH-CURVE
+            MAXIMA::$EMATRIX MAXIMA::DENN MAXIMA::*F-DLOG
+            MAXIMA::LTSCALE MAXIMA::CASEGEN MAXIMA::PSDERIV2
+            MAXIMA::PRINCIPAL-VALUE-INTEGRAL MAXIMA::MPART
+            MAXIMA::RISCHEXPLOG MAXIMA::SPARSE-LIFT MAXIMA::TRUFAC
+            MAXIMA::NOCONSTQUAD MAXIMA::CPA-INDETERM MAXIMA::TMINOR
+            MAXIMA::GET-SERIES MAXIMA::NUMN)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T *) T) MAXIMA::MASET1 MAXIMA::LIST-REF
+            MAXIMA::GAMMA-INCOMPLETE MAXIMA::$DELETE MAXIMA::SOLVABLE
+            MAXIMA::$RREDUCE MAXIMA::$GENMATRIX MAXIMA::D-HBAR
+            CL-INFO::GCL-READ-SEQUENCE MAXIMA::$FORTMX
+            MAXIMA::$ZN_ORDER
+            MAXIMA::COERCE-LISP-FUNCTION-OR-LISP-LAMBDA
+            MAXIMA::%COERCE-FLOAT-FUN MAXIMA::MARRAYSET
+            MAXIMA::$ZN_PRIMROOT_P BIGFLOAT::LAMBERT-W-K
+            MAXIMA::ASS-EQ-REF MAXIMA::$TREE_REDUCE MAXIMA::$TCL_OUTPUT
+            MAXIMA::$LREDUCE MAXIMA::$ASSOC MAXIMA::$MATCHFIX
+            MAXIMA::PARTFRAC MAXIMA::DISPLAY-FOR-TR
+            GETOPT:MATCH-UNIQUE-ABBREVIATION MAXIMA::TRANSLATE-FILE
+            GETOPT::FIND-OPTION MAXIMA::$TEXPUT MAXIMA::$GF_GCD
+            INTL::NOTE-TRANSLATABLE
+            MAXIMA::COERCE-MAXIMA-FUNCTION-OR-MAXIMA-LAMBDA
+            MAXIMA::*ARRAY MAXIMA::CHEKVALUE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T *) T) MAXIMA::$GRUNTZ MAXIMA::$ZN_LOG
+            MAXIMA::$POISSUBST MAXIMA::$ZN_NTH_ROOT MAXIMA::BOTH-SIDE
+            MAXIMA::CHECK-OPTION-B MAXIMA::ZN-NRT MAXIMA::CHECK-OPTION
+            MAXIMA::GRUNTZ1 MAXIMA::D-VBAR MAXIMA::GET-LIMIT)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T *) T) MAXIMA::QUAD-QAWC
+            MAXIMA::QUAD-QAGP MAXIMA::QUAD-QAWF MAXIMA::DOSUM
+            MAXIMA::QUAD-QAG)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::PSDIFF2 MAXIMA::DSUMPROD
+            MAXIMA::SMOOTH-ENOUGH-P MAXIMA::NUMMDENN MAXIMA::PSPLUS2
+            MAXIMA::*F-PRIM-P-2 MAXIMA::FILL-ROW
+            BIGFLOAT::INTERPOLATE-CHECK MAXIMA::ZGCD-LIFT
+            MAXIMA::DENMNUMN MAXIMA::DENMDENN MAXIMA::MPC1)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T FIXNUM T FIXNUM T T) T)
+            MAXIMA::GF-PRIMPOLY-P2)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T T T) T) MAXIMA::BMHK MAXIMA::DRAW3D
+            MAXIMA::MPC MAXIMA::NUMMNUMN MAXIMA::FRACTEST1)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T T T T) T) MAXIMA::TMMOVE
+            MAXIMA::NS-INTIR3 MAXIMA::FRACTEST MAXIMA::PNS-INTIR3
+            MAXIMA::PSMONSUBST1 MAXIMA::TMPERMUTE)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION ((VECTOR LONG-FLOAT) T) T) MAXIMA::$GET_RANGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GET_TEX_ENVIRONMENT)) 
+    '(FTYPE (FUNCTION (T T FIXNUM) T) MAXIMA::TB2 MAXIMA::$COPY_PTS
+            MAXIMA::GF-PRIMPOLY-P MAXIMA::CPBG MAXIMA::PGCD2)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION NIL T) MAXIMA::$GET_TEX_ENVIRONMENT_DEFAULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$GFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GFACTORSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_ADD)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_ADD_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$GF_AT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_CARDINALITY)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_CHARACTERISTIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_COMPOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::$GF_DEGREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$GF_DETERMINANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_DIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$GF_EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL FIXNUM) MAXIMA::$GF_EXPONENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$GF_GCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_GCDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_GET_DATA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_INDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_INFOLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_INV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$GF_INVERT_BY_LU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_IRREDUCIBLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_IRREDUCIBLE_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_JACOBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_L2N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_L2P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_MAKE_ARRAYS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_MAKE_LOGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_MATADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$GF_MATINV)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_MATMULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$GF_MATNEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$GF_MINIMAL_POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_MINIMAL_SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_MULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_MULT_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER *) T) MAXIMA::$GF_N2L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_N2P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_NEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_NORM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_NORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_NORMAL_BASIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_NORMAL_BASIS_REP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_NORMAL_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_NTH_ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_P2L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_P2N)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_POWER_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_PRIMITIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_PRIMITIVE_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_PRIMITIVE_POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_PRIMITIVE_POLY_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_RANDOM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_RANDOM_NORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$GF_REDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_REDUCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_SET_AGAIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$GF_SET_DATA)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GF_SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_TRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$GF_UNIT_P)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GF_UNSET)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GNUPLOT_CLOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$GNUPLOT_REPLOT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GNUPLOT_RESET)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GNUPLOT_RESTART)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$GNUPLOT_START)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::$GRUNTZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$HANKEL_1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$HANKEL_2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$HGFPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$HGFRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$HORNER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$IDENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$IDENTITY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$IFACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$ILT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$IMAGPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$INFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$INPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$INRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$INTEGERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$INTEGER_PARTITIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$INTEGRATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$INTERSECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$INTERSECTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$INTERVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$INTOPOIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$INTOSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$INVERSE_ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$INVERSE_ERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_CD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_CN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_CS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_DC)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_DN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_DS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_NC)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_ND)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_NS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_SC)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_SD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$INVERSE_JACOBI_SN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$INVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$INV_MOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$IN_EXACTLY_ONE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ISOLATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ISQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$JACOBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$JACOBI_AM)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_CD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_CN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_CS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_DC)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_DN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_DS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_NC)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_ND)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_NS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_SC)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_SD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_SN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$JOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$KILLCONTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$KRON_DELTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LABELS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$LAMBERT_W)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::$LAPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LAST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::$LDEFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$LDISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LENGTH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$LFREEOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$LIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$LINSOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LISTARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LISTIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LISTOFVARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LISTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LIST_MATRIX_ENTRIES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$LMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$LMIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$LOAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$LOGARC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$LOGCONTRACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$LOG_GAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$LPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$LREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$LUCAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$MAKEFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$MAKEGAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$MAKE_ARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$MAKE_ELLIPTIC_E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$MAKE_ELLIPTIC_F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$MAKE_RANDOM_STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::$MAKE_TRANSFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$MAPATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$MATCHFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$MATRIXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$MEMBER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$MINFACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$MINOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::$MKEY)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$MULTINOMIAL_COEFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$MULTTHRU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$NARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NEWCONTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NEWDET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NEXT_PRIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$NICEINDICES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$NOFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NONSCALARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NOUNIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$NROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$NTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$NTHROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$NUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NUMBERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NUMFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$NUM_DISTINCT_PARTITIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$NUM_PARTITIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$NZETA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NZETAI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$NZETAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ODDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$OP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$OPERATORP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$OPTIMIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ORDERGREATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ORDERLESSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ORDERMAGNITUDEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$OUTERMAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$OUTOFPOIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$PADE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$PART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$PARTFRAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$PARTITION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$PARTITION_SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PATHNAME_DIRECTORY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PATHNAME_NAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PATHNAME_TYPE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PERMANENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PERMUTATIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$PFACTORALG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$PFET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$PICKAPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$PLOT2D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$PLOT3D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POISCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POISDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POISEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POISINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$POISMAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POISPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$POISSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$POISSQUARE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::$POISSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POISTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$POLARFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION ((ARRAY T)) T) MAXIMA::$POLAR_TO_XY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POLYDECOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$POLYMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::$POLYSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$POLY_DISCRIMINANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$POSTFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::$POWERSERIES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$POWERSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$POWER_MOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$PREFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PREV_PRIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PRIMEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$PRIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PRINTFILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$PRINTPOIS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$PRINTVARLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$PSUBSTITUTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$PUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$QUAD_CONTROL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::$QUIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$QUNIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$QUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$RADCAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RANDOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RANDOM_PERMUTATION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RANK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$RATCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RATDENOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$RATDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RATDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$RATEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$RATIONALIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RATNUMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RATNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$RATSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$RATSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$RATVARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$RATWEIGHT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$READ)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$READONLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$REALPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$REALROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$RECTFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$REM)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$REMAINDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$REMBOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$REMOVE_PLOT_OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$REMRULE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::$RESIDUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$REST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$RESULTANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$REVEAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$REVERSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$RISCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$ROOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ROOTSCONTRACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ROTATE_LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ROTATE_PTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ROTATION1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$RREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$RUN_TESTSUITE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SCALARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SCALED_BESSEL_I)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$SCALED_BESSEL_I0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$SCALED_BESSEL_I1)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$SCONCAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$SCSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SETDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::$SETELMX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SETEQUALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$SETIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SETP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$SETUP_AUTOLOAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$SET_PARTITIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$SET_PLOT_OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SET_RANDOM_STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::$SET_TEX_ENVIRONMENT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::$SET_TEX_ENVIRONMENT_DEFAULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SHOWRATVARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SHOW_HASH_ARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$SOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$SOME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$SORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SPECINT)) 
-(PROCLAIM '(FTYPE (FUNCTION ((ARRAY T)) T) MAXIMA::$SPHERICAL_TO_XYZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SPLITFIELD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SQFR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$SQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SSTATUS-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$STRUVE_H)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$STRUVE_L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SUBLIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SUBLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SUBLIST_INDICES)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$SUBMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$SUBSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$SUBSETP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$SUBSTITUTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SUBVARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$SUMCONTRACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$SYMBOLP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$SYMMDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::$SYSTEM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$TAYLOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TAYLORINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TAYLORP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TAYTORAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$TCL_OUTPUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$TELLRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TEX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TEXEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TEXINIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$TEXPUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$THROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$TIMEDATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::$TLDEFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$TLIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TMINVERSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::$TMLIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$TMLINSOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$TMNEWDET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$TODD_COXETER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$TOTALDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TRACE_IT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$TRANSLATE_FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TRANSPOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$TREE_REDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$TRIANGULARIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$TRIGEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::$TRIGREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$TRUNC)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$TR_WARNINGS_GET)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$UNION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$UNIQUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$UNKNOWN)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::$UNORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$UNTELLRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$UNTRACE_IT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$VERBIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$WRITEFILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::$XREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$XTHRU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ZEROEQUIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ZEROMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ZERO_FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::$ZETA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ZN_ADD_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::$ZN_CHARACTERISTIC_FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::$ZN_DETERMINANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::$ZN_INVERT_BY_LU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::$ZN_LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$ZN_MULT_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::$ZN_NTH_ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$ZN_ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::$ZN_POWER_TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::$ZN_PRIMROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::$ZN_PRIMROOT_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::%$ETEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::%COERCE-FLOAT-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%E-INTEGER-COEFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%E-RIGHT-PLACEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%EINVOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%EINVOLVE01)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%ESPECIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%ETOLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::%FIND-ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::%GAMMA-INCOMPLETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%I-OUT-OF-DENOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%ITOPOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::%MAKE-POLYGON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::%PIARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::%PIARGS-CSC/SEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%PIARGS-OFFSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::%PIARGS-SIN/COS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::%PIARGS-TAN/COT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::%TO$)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::*ARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::*BREAK-POINTS*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::*DEFINE-INITIAL-SYMBOLS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) FIXNUM) MAXIMA::*F-DEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::*F-DETERMINANT-BY-LU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::*F-DLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::*F-DLOGB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::*F-INVERT-BY-LU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::*F-IRR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::*F-LU-FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::*F-MATMULT)) 
+    '(FTYPE (FUNCTION (T T FIXNUM FIXNUM FIXNUM) T)
+            MAXIMA::COPY-ARRAY-PORTION)) 
+(PROCLAIM '(FTYPE (FUNCTION (T T T FIXNUM FIXNUM) T) MAXIMA::PRODHK)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T) MAXIMA::*F-MAYBE-NORMAL-BASIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::*F-NP2SMOD)) 
+    '(FTYPE (FUNCTION (T T T T *) T) MAXIMA::QUAD-QAGI
+            MAXIMA::QUAD-QAGS)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T INTEGER T INTEGER INTEGER T) T)
-            MAXIMA::*F-POW$)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::*F-PRECOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::*F-PRIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::*F-PRIM-P-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::*F-PRIM-P-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::*FPATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::*FPEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::*FPSIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::*KAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::*MMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::*MREAD-PROMPT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::*RED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::*RED1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::*RULECHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::*UNION-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::+MSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::1F1POLYS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::1P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::2F0POLYS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::2F1POLYS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::2PIREC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::2PISTRIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ABEQ1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ABLESS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ABS-INTEGRAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::ABSARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ABSARG-MABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ABSARG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::ACTIVATE)) 
+    '(FTYPE (FUNCTION (T T T T FIXNUM T T) T) MAXIMA::PSEXPT-FN1
+            MAXIMA::PSLOG1)) 
+(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM FIXNUM) T) MAXIMA::SINGP)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (T T T T T T T T T T T T T) T)
             MAXIMA::ADAPTIVE-PARAMETRIC-PLOT)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T T T T T) T) MAXIMA::ADAPTIVE-PLOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::ADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::ADD*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADD-INVERSEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADD-LINEINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADD-POINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADD-UP-DEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADD2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ADD2*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ADD2CSTR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADD2CSTR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADD2LNC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDARGLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ADDBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ADDITIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ADDK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADDLABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDMATRIX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADDMLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ADDMX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDPARAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADDROWS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ADDVARDEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ADFACTL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADISPLINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADJOIN-DATUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADJOIN-PVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADJOIN-SING-DATUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADJOIN-TVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ADUSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::AFIXSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::AFORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::AIRY-AI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AIRY-AI-COMPLEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT) *) MAXIMA::AIRY-AI-REAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::AIRY-BI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AIRY-BI-COMPLEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT) *) MAXIMA::AIRY-BI-REAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AIRY-DAI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AIRY-DAI-COMPLEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT) T) MAXIMA::AIRY-DAI-REAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AIRY-DBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AIRY-DBI-COMPLEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT) T) MAXIMA::AIRY-DBI-REAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::AL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ALBK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGII)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::ALGIII)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGNORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGNORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGORDSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGPCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGPGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGSYS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGSYS0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALGSYS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGTESTD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGTRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGTRACE*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALGTRACE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALIAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALIASLOOKUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALIKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALIKE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALLATOMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALLPRODS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ALLSUBST00)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ALPHABETP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ALPHALESSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ALT-FORMAT-PROMPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::ALTER-PATHNAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::AMONG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::AMONGL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AMPERCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ANDMAPCAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ANNOUNCE-RULE-FIRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ANTIDERIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ANTISYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::AP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::APDL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::APPARENTLY-INTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::APPEARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::APPEARS-IN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::APPEARS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::APPLICATION-OPERATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::APPLY-REFLECTION-SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::APPLY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::APPLY1HACK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::APPLY2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::APPLY2HACK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::APPROX-ALIKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::APPROX-ALIKE-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::APPRSYS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::APROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARCFUNCP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ARCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARCLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARCP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ARGNUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ARGSFREEOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARGSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ARRAY-MEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARRAY-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARRAY-MODE-@)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARRAYDIMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARRAYFUN-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ARRAYINFO-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ARRAYSIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARRFIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ARRFUNCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ARRFUNP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ARRSTORE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ARRSTORE-EXTEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.6)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.7)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.8)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::AS-15.2.9)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::ASCII)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASCII-NUMBERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASET-BY-CURSOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASINTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::ASK-CHOICEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASK-DECLARE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASK-EVOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASK-GREATEQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASK-INTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASK-INTEGERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ASK-PROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASKINVER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASKSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASKSIGN-P-OR-N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASKSIGN01)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ASKSIGN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::ASS-EQ-REF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ASS-EQ-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASSCONTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ASSIGN-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASSIGN-MODE-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASSOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASSOLIKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASSOO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ASSSO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ASSUME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ASY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ASYMREDU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AT-SUBSTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ATAN-POLE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ATAN-POLES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ATANBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ATANTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ATDECODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ATFIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ATOMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ATOMCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ATOMGRAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ATOMSON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ATOMVARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ATRANSPOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ATRIG-TRANS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ATRIGH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ATSCAN)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T)
-            MAXIMA::ATTEMPT-TRANSLATE-RANDOM-MACRO-OP)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T)
-            MAXIMA::ATTEMPT-TRANSLATE-RANDOM-SPECIAL-OP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ATVARSCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AUGMULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::AUTOLDCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::AVLINIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::AVLINSERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::AXESOPTIONP)) 
+    '(FTYPE (FUNCTION (T T T T T T FIXNUM T T T T) T) MAXIMA::PSEXPT1)) 
+(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T *) T) MAXIMA::QUAD-QAWS)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T FIXNUM FIXNUM) *) MAXIMA::B-SEARCH-EXPR)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BACKWARD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BAD-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BAD-VAR-WARN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BADFUNCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BAKALEVEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BAKALEVEL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BAKSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BAKSUBST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::BARFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BASELIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::BATA0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::BATAP-INF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::BATAP-NEW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::BATAPP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BATCH-EQUAL-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BATCH-INTERNAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BBSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BBSORT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BBSORTEQNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BCONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BDISCR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BEG-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BEHAVIOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BEHAVIOR-BY-DIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BEHAVIOR-EXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) FIXNUM) MAXIMA::BEHAVIOR-NUMDEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BERN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-I)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-I-HALF-ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-I-HYPERGEOMETRIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-I-INTEGRAL-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-J-HALF-ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-J-HYPERGEOMETRIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-J-INTEGRAL-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-K-HALF-ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-K-HYPERGEOMETRIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-K-INTEGRAL-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-NUMERICAL-EVAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-Y-HALF-ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BESSEL-Y-HYPERGEOMETRIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESSEL-Y-INTEGRAL-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BESTRIG)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::BETA-EXPAND-ADD-INTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BETA-EXPAND-INTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::BETA-INCOMPLETE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T)
-            MAXIMA::BETA-INCOMPLETE-EXPAND-NEGATIVE-INTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::BETWEENP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BEYOND-EXTREME-VALUES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BEZOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-CALCSC-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-CALCT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-CAUCHY-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::BF-CDIVID-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BF-CMOD-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BF-CPOLY-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BF-CPOLY-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BF-ERREV-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BF-FXSHFR-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BF-FXSHFT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-NEWEST-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-NEXTH-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-NEXTK-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BF-NOSHFT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-POLYEV-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BF-QUAD-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-QUADIT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-QUADSD-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL FIXNUM) MAXIMA::BF-REALIT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BF-RPOLY-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BF-SCALE-FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::BF-SCALE-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BF-VRSHFT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-DOUBLE-FACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-EXPINTEGRAL-CHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-EXPINTEGRAL-CI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BFLOAT-EXPINTEGRAL-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-EXPINTEGRAL-EI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-EXPINTEGRAL-LI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-EXPINTEGRAL-SHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BFLOAT-EXPINTEGRAL-SI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BFLOAT-GAMMA-INCOMPLETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::BFLOAT-LOG-GAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::BFLOAT-NEWTON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::BIG-FLOAT-ACOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::BIG-FLOAT-ASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BIG-FLOAT-ASINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BIG-FLOAT-ATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BIG-FLOAT-EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BIG-FLOAT-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BIG-FLOAT-SINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BIG-FLOAT-SQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BIG-FLOAT-TANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BIG-PRIME-VAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::BIGFLOAT-NUMERICAL-EVAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BIGFLOAT-OR-NUMBER-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BIGFLOAT2RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::BIGFLOATM*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BIGFLOATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BIGLSH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BIGNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BINCOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BINCOMP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BINOCOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BIQUADP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BIQUADRATICP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BKPT-FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BKPT-FILE-LINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BKPT-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BKPT-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) T) MAXIMA::BMHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BOOL-CHECKED-MFUNCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::BOOLEAN-CONVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::BOTH-SIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BOTHPRODCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BOX-LABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BRANCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BRANCH1)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::BREAK-CURRENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::BREAK-DBM-LOOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::BREAK-FRAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BREAK-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::BREAK-HELP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::BREAK-PROMPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::BREAK-QUIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BREAK-STEP-INTO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::BREAK-STEP-NEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BROKEN-FREEOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BX**N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::BX**N+A)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::BXM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::BYDIF)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::BYE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BYGAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::BYLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::C*LOGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::C-$PN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::C-$POS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::C-$PZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::C-$ZERO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CABS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CALCSC-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CALCT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CALCULATE-SERIES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CALL-AND-SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CALL-BATCH1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CALLAPPRS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CALLSOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CANCEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CAR>)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CAREFULFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CASE0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CASE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::CASEGEN)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CAUCHY-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CDINF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CDIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CDIVID-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CDRAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CEIL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CEILING-INTEGRAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CF-BACK-RECURRENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::CF-CONVERGENTS-P-Q)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFACTORW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CFDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFDISREP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CFEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CFFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFMAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFMIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFNROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CFPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CFQUOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFRATSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CFSQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CFTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::CGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CGCDLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::CHAINRULE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHANGESIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CHANGEVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CHEBY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CHEBY-PRIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::CHEBYF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHEBYLI2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHEBYLI3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHEBYS12)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CHECK-CALL-TO-$SPECINT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CHECK-GNUPLOT-PROCESS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-INF-SING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::CHECK-INTEGER-FACTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-LIST-PLOT3D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-NONINTEGER-FACTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::CHECK-OPTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::CHECK-OPTION-B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-OPTION-BOOLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-OPTION-FORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-OPTION-LABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-OPTION-PALETTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-OPTION-STYLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-OPTION-TRANSFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK-RANGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECK1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CHECKBREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKDERIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CHECKDERIV1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKED-AND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKED-OR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKENCODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKFIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKFLAGANDACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKLABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHECKSIGNTM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::CHEKVALUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CHINESE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHOOZP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CHRCT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CHUDNOVSKY-SERIES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CL-RAT-TO-MAXIMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CLEAN-LIMIT-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CLEAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CLEAR-LOBJS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CLEARSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CLOSE-CLIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CMARK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CMNULL)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) T) MAXIMA::CMNULLF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CMOD-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CMUL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CNTHROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CNTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CNTXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CNV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COEF-SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::COEFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COEFF-CONTAINS-POWERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::COEFFICIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COEFFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COEFFPORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COEFFPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COEFFRET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COEFFT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COEFFTT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COEFL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COEFMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::COEFSOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COEFVEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::COERCE-BFLOAT-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::COERCE-FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::COERCE-FLOAT-FUN)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T *) T)
-            MAXIMA::COERCE-LISP-FUNCTION-OR-LISP-LAMBDA)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T *) T)
-            MAXIMA::COERCE-MAXIMA-FUNCTION-OR-MAXIMA-LAMBDA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COERCE-REL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::COLEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COLLAPSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COLLISION-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COLLISION-LOOKUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COLOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T) T) MAXIMA::COLROW0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMBIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MAXIMA::COMBINATION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMBINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMBINEY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMBINEY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMDENOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COMDENOM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::COMMONROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMMUTATIVE-PRODUCTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMMUTATIVE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMP-BF%GAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::COMP-LOG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPATTLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COMPATVARL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COMPATVARLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPILE-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMPILEATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMPILEEACH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMPILEMATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMPILEPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMPILETIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COMPLETEVECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-ACOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-ASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-ASINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-ATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPLEX-BFLOAT-ERF)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-BFLOAT-GAMMA-INCOMPLETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::COMPLEX-BFLOAT-LOG-GAMMA)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (*) T) MAXIMA::COMPLEX-BIGFLOAT-NUMERICAL-EVAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPLEX-ERF)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::COMPLEX-ERF-UPPER-HALF-PLANE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (*) T) MAXIMA::COMPLEX-FLOAT-NUMERICAL-EVAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::COMPLEX-NUMBER-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-SQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COMPLEX-TANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPLEXIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPLEXITY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COMPLEXITY/COL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::COMPLEXITY/ROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPLEXNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COMPLICATED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::COMPLM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::COMPOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::COMPPI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::COMPSPLT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::COMPSPLT-EQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::COMPSPLT-GENERAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::COMPSPLT-SINGLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COMPUMD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) (VALUES T T)) MAXIMA::CONCAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONDENSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONDENSESOLNL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONDENSESUBLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONDENSEY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CONF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CONF2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONF4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONF5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONF6)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONF7)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::CONFL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-ACOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-ASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-ATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-ATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-BESSEL-I)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-BESSEL-J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-BESSEL-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-BESSEL-Y)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) *)
-            MAXIMA::CONJUGATE-BETA-INCOMPLETE-GENERALIZED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-EXPINTEGRAL-CHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-EXPINTEGRAL-CI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-EXPINTEGRAL-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-EXPINTEGRAL-E1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-EXPINTEGRAL-LI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-GAMMA-INCOMPLETE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) *)
-            MAXIMA::CONJUGATE-GAMMA-INCOMPLETE-GENERALIZED)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) *)
-            MAXIMA::CONJUGATE-GAMMA-INCOMPLETE-REGULARIZED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONJUGATE-MEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONJUGATE-SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CONSFUNDEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSRULE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSSIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTACL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONSTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTLAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::CONSTMX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONSTTERMP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CONTEXTMARK)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::CONTINUE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::CONTINUEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONTODR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CONTSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CONVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CONVERT-LIST)) 
+    '(FTYPE (FUNCTION (T T FIXNUM T) T) MAXIMA::POLYIZE MAXIMA::X**Q1
+            MAXIMA::*F-MAYBE-NORMAL-BASIS)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T FIXNUM FIXNUM FIXNUM) T)
-            MAXIMA::COPY-ARRAY-PORTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COS%)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COSBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COSDIF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COSH^N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COSINT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COSNX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::COS^N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::COT-PLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::COT-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COUNT-ATOMS-MATCHING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COUNT-GENERAL-INF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::COVERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::COVERSINEMYFOOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CPA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::CPA-INDETERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPA1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CPBER1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPBER3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CPBERL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM) T) MAXIMA::CPBG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPBG0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CPBGZASS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::CPBQ1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPOL2P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CPOLY-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CPOLY-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPOWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPRES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CPTIMESX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CPTIMESXA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CPTOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CPTOMEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM T FIXNUM) T) MAXIMA::CPTOMF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CPUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CREATE-ANY-POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::CREATE-LIST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CREATE-LOBJS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::CREATE-POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) (VALUES T T)) MAXIMA::CREATENAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CREATSYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CRECIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CRECIP-GENERAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CROSS-PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::CSC/SEC-PLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::CSC/SEC-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CSEMIDOWN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::CSEMIUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CSF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CSTRSETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CTIMEMT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CTIMESX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::CTPJAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CUNMRK)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::CURRENT-STEP-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::CV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::CXERFARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CYCLIC-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::CYCLOTOMIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::CYCLP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::D-BOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::D-HBAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::D-INTEGRALSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::D-MATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::D-PRODSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::D-SUMSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::D-VBAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DADDEQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DADDGQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DADDGR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DADDNQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DATUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DATUM-LIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DB-MNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DBA)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::DBM-READ)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) *) MAXIMA::DBM-UP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DBNODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DBUNIVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DBV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DBVARP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::DBZ-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DBZ-ERR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DBZS-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::DCHECK-TABLES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DCOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DCOMPARE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DCON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DCONV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DCONV-$CRE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DCONV-$FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DCONVX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DDIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::DEACTIVATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEBUGMODE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DECIMALSIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DECL-COMPLEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DECL-REALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DECLARE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DECLAREKIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DECLARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DECLFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DECLMODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DECLSETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DECLVALUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DECMODE-ARRAYFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DECODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::DECOMP-CHAIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::DECOMP-TRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DECREMENT-TRUNCS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DEF-BREAK)) 
+    '(FTYPE (FUNCTION (LONG-FLOAT) *) SLATEC::DEI MAXIMA::ELLIPTIC-EC)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (T T T T T T T T T T T T) T)
             MAXIMA::DEF-OPERATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEFA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DEFA1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DEFAULT-FORMAT-PROMPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEFC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEFEXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEFINE-MACRO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEFINE-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::DEFINE-SYMBOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEFINITELY-SO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DEFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::DEFINT-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::DEFINT-LOG-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEFINTEGRATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEFMATCH1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEFS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DEFS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEFSTRUCT-TRANSLATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEFSTRUCT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DEG-LESSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEGODR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DEGVECDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DEGVECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEL)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::DELETE-WITH-SIDE-EFFECTS-IF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DELETECOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DELETEROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DELETMULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DELIM-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DELSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DEMOIVRE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DEN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::DEN1DEN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::DEN1DENN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::DEN1NUMN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::DENMDENN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::DENMNUMN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::DENN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DENOM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DENOMFIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEPENDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEPENDS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEPENDSALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEPENDSL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DEQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DEQF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DERIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::DERIVAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::DERIVINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::DESJY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::DESMJY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DET1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DETERMINANT1)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) FIXNUM) MAXIMA::DETERMINE-LIFTING-FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DETPIVOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DGQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DGQF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DGR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DGRF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIAGINV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DIAGLIZE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DIAGMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::DIAGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::DIFAP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::DIFAPPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DIFF%DERIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIFF-%AT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIFF-EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIFFDIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIFFERENCE-VAR-SETS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIFFEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::DIFFHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIFFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DIFFINT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIFFLAPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIFFNCEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIFFSUMPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DILOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-$MATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-%AT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-%DERIVATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-%INTEGRATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-%LIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-%LSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-%PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-%SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIM-BIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MBOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MCOND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MDEFINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MDO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MDOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MLABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MLABOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MNCEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-MQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIM-MTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIM-RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DIMCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::DIMENSION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-ARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIMENSION-ARRAY-OBJECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIMENSION-ATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-BUILD-INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-DEFSTRUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-INFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-MATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-NARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-NOFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-PAREN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-POSTFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-PREFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIMENSION-SUPERSCRIPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::DIMNARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::DIMNARY-BOOLEAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::DIMNARY-MTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DINTBYPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::DINTEGRATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DINTERN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DINTERNP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DINTEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DINTLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DINTNUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DINTRAD0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DIONARGHYP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DIONARGHYP-Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DISCONTINUITIES-DENOM)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DISCONTINUITIES-IN-INTERVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DISP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DISPATCH-SPEC-SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::DISPATCHPOLTRANS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISPATOMGRADS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISPATVALUES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DISPFUN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISPGRADEFS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DISPLA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DISPLAF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::DISPLAY-FOR-TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISPLINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISPMATCHDECLARES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISPRULE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DISREP-MONOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISREPLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISREPLIST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISTINCT-NONZERO-ROOTS-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISTRDEFEXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISTRDEFEXECINIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISTREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISTRESTOREX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISTREXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISTREXECINIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DISTREXPANDROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISTRFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DISTRIBUTE-OVER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISTRINPLUSPREV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISTRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DISTRINTIMESPREV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DIV*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DIV-DEG-CHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIVCARCDR)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::DIVERG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DIVISORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIVL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DIVSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DLF-MUMBLIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DLOG-BABY-GIANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::DLOG-F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DLOG-NAIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DLOG-RHO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DLQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DLQF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DLS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DLSF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DMARK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DMDERIVABBREV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DMDERIVLONG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DNQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DNQF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DO%SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DOING-ROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DOLLARIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DOMAIN-ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DONTFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DOPGCDCOFACTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T *) T) MAXIMA::DOSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DOT--RI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DOT-SP-RI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DOT2L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DOUBLE-FACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DOUTERN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DOWN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DOWNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DPDERIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DPDIF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DPDIF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DPDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DPGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DPMODQUO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DPMODREM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DPREMQUO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DPREP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::DPRINT-STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DPSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DPSQFR)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::DQ+)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::DQ-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T T) T) MAXIMA::DRATIO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DRAW-LINEAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DRAW2D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DRAW2D-DISCRETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DRAW2D-PARAMETRIC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::DRAW2D-PARAMETRIC-ADAPTIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) T) MAXIMA::DRAW3D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DROPTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DSFUNC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DSKARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DSKATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DSKDEFPROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DSKRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DSKRAT-SUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::DSKSETQ-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DSKSETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::DSKSTORE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DSRL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DSTRB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DSUBSTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::DSUMPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DTFORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::DTRANSLATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::DTW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::DVCOE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::DYPHEYED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::E*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::E+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::E1+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::E1-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::E3PROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::E=)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::E>)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EACHP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EASY-CASES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::EASY-SUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EBAKSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ECHELON1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) MAXIMA::ECHELON2)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::ECM-FACTOR-WITH-CURVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ECM-POWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ECM-PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ECM-SQUARE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::EEZZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER) *) MAXIMA::EF-CINV)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) T) MAXIMA::EF-CINV-BY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::EF-CMINUS-B)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) T) MAXIMA::EF-CMINUS-BY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER) *) MAXIMA::EF-CMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EF-CPLUS-B)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MAXIMA::EF-CPLUS-BY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EF-CPOW)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MAXIMA::EF-CPOW-BY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EF-CTIMES)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MAXIMA::EF-CTIMES-BY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-CARD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-FS-ORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-FSX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-FSX-BASE-Q)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-ORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-PRIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-RED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EF-DATA-SHORT-PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA-X^Q-POWERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DATA?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-DLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EF-DLOGB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-FIELD?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-GF-FIELD?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-IRR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-MAYBE-NORMAL-BASIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-NORMAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::EF-PRECOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::EF-PRIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-PRIM-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-PTH-CROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::EF-RANDOM-NORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EF-RED?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ELABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ELEM)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT) T) MAXIMA::ELLIPTIC-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT) *) MAXIMA::ELLIPTIC-EC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ELLIPTIC-EU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ELLIPTIC-F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ELLIPTIC-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ELLIPTIC-PI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ELLIPTQUAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EMIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::END)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::END-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ENPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::ENSURE-SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ENSURE-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::EPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EPROGRATD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EPS-COEF-SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EPS-SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EQTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EQUAL-DIV-TWO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EQUAL-FACTS-SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EQUAL-TIMES-MINUS-ONE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EQUAL-TIMES-MINUS-TWO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EQUO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ERB-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ERECIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ERFARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ERFARG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ERFCTD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ERFGAMMARED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ERFGAMNUMRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ERFRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ERFTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ERRBREAK1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ERRBREAK2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ERREV-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ERRLFUN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ERROR-SIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ERRSET-NAMESTRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ESAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ESHIFT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::ESSEN-SING-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ESTCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ESTCHECK2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ETF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EULER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EVAL-DERIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EVAL-MON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EVAL-PRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EVEN-FUNCTION-REFLECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVEN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EVENFN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EVENFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EVERY-TRIGARG-ALIKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::EVERYPTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::EVERYPTERMS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVERYSECOND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EVERYSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EVERYSUBST0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EVERYSUBST00)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EVERYSUBST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EVERYSUBST2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVFAC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::EVFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EVFUNMAKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EVMAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVOD-MEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVOD-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVOD-MTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EVTILDEGLESS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXACTONLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXCHANGECOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXCHANGEROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXCHANGEVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXCISE-EXTRA-VARIABLES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXCLUDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXECARGMATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXECF19)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EXECFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EXP$LI-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXP-C*LOGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXP-CONVERG-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::EXP-PT-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPAND-AND-DISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPAND-DISTINCT-ROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPAND-SING-TRIG?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EXPAND-TRIGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::EXPAND1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::EXPANDEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::EXPANDROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPANDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPANDSUMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPANDTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPANDTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPANINTEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EXPASIN-FUNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::EXPCOT-FUNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::EXPEXP-FUNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::EXPFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPFACTORP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPGAM-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL-CHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL-CI)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER T) T) MAXIMA::EXPINTEGRAL-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL-EI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL-LI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL-SHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL-SI)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL_CHI-TO-HYPERGEOMETRIC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL_CI-TO-HYPERGEOMETRIC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL_SHI-TO-HYPERGEOMETRIC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::EXPINTEGRAL_SI-TO-HYPERGEOMETRIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EXPLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPLODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPLODEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPLODEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPLODEN-FORMAT-FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::EXPLOG-FUNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::EXPO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPONENT-OF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPONENTIALIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPONENTIATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::EXPONENTIATE-SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPOR1P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EXPPLYGAM-FUNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXPPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::EXPPOLYCONTROL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EXPSEC-FUNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EXPTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EXPTAN-FUNS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EXPTB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXPTBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EXPTHACK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::EXPTRL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::EXTEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXTENDED-NUMBER-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXTOPCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EXTRACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EXTRACTVARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::EXTREME-FLOAT-VALUES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::EZ1CALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::EZEROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::EZGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EZGCD2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::EZTESTDIVIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::F-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F16P217TEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::F19COND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::F19P220-SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::F1P137)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::F1P137TEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F24P146)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F24P146TEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F29P146)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F29P146TEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::F2P105V2COND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F2P105V2COND-SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::F3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F35P147)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F35P147TEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::F36P147)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::F37P147)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::F50COND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F50P188-SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F81)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F82)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F83)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F84)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F85)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::F86)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACMGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACRPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FACRTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACSUM-EXPONENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FACT20)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FACT2Z)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACT5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACT5MOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FACTCOMB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTCOMB1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTCOMBPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FACTEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTOR-IF-SMALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTOR-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTOR1972)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTOR72)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTORALG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTORIAL-TRANS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTORLOGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTORNUMBER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTOROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTOROUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTOROUT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTORSUM0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTORSUM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTORSUM2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTOSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FACTPLUS0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FACTPLUS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTPLUS2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTPLUSCOMB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTPLUSDEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTPOW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FACTPOWERSELECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FACTQSNT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FACTRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTS2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTXN+-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTXN+1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FACTXN-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FALSEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::FAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::FANCYDIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FANCYPAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FANCYPAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FANCYPOIS1C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FANCYPOIS1S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::FANCYPOISSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FASPRIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FASPRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FASTCONT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FBINO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FCTRL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FDEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FEXPRCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) T) MAXIMA::FFIB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FILESTRIP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::FILL-IN-INVERSES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::FILL-ROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FILLARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FILTER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FILTER-SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FIND-CF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FIND-CF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIND-FIRST-TRIGARG)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION NIL T) MAXIMA::FIND-LISP-READTABLE-FOR-MACSYMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIND-STREAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIND-TLISTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FINDBASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDBE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FINDEXPON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FINDFLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FINDFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDIBASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDLEASTVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FINDPR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FINDROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FINDSES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDSIGNOFACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDSIGNOFTHEIRPRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FINDSUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FINDTHEM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FINDTL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FINITE-SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FIRST-FORM-LINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FIRST-ORDER-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FIRSTN)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::FIXED-LENGTH-PARTITIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIXEDMATCHP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIXEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIXFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIXINTGREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FIXMULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIXNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FIXUPREST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FIXVL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FIXVL0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FIXVL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::FLATC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::FLATSIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FLATTENL-OP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLEVENP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FLGREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FLGREAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLMAXL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLOAT-INF-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLOAT-NAN-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FLOAT-NEWTON)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::FLOAT-NUMERICAL-EVAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLOAT-OR-LOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLOAT-OR-RATIONAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FLOAT-RATIO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FLOAT-ZETA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FLOAT2RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLOATFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLOATTOFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::FLONUM-EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FLOOR-INTEGRAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FLRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FLSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::FMAP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::FMAPL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FMP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FMT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FNEWVAR)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::FOR-EVAL-THEN-MQUOTE-SIMP-ARGL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) FIXNUM) MAXIMA::FORCEBREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FORGET)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::FORGET-GLOBAL-ASSUMPTIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FORGET1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FORM-MEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FORM-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FORM-MRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FORM-MTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::FORMAT-PROMPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FORMAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FORMX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FORQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::FORTRAN-PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FORTSCAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FORTSCAN-MTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FORWARD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FP2FLO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FPACOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPARCSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FPASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPASIN-CORE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPASINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPATAN2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPCOFRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPCOFRAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPCOS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::FPE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPENTIER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPEXP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPEXPM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::FPEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPFORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::FPGAMMA1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPGCDCO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPGREATERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FPINTEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPINTPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPLESSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FPLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FPLOG1P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::FPMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::FPMIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::FPOLY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::FPOLY2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::FPOLYSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::FPONE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::FPPI1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPPOSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPPREC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FPQFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPR-DIF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPRATION1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPROUND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FPSCAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPSHIFT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::FPSIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPSIN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPSINCOS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPSINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPSQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPTANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPTIMES*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FPTIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FPZEROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FR-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FRAC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::FRAC-BFLOAT-EXPINTEGRAL-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FRAC-EXPINTEGRAL-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T) T) MAXIMA::FRACTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) T) MAXIMA::FRACTEST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::FRACTEST2)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) *) MAXIMA::FRAME-INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::FREE-LISP-VARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREE-LISP-VARS-M-TLAMBDA)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::FREE-LISP-VARS-M-TLAMBDA&ENV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREE-LISP-VARS-OF-ARGL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FREE-NOT-ZERO-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::FREE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FREEARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FREEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FREEOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FREEOFL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREEPAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::FREESUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREEVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREEVAR0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREEVARPAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FREEVNZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FRPOLY?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FSEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::FSGEO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::FSPLIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FSTRINGC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FULLRATSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FULLSTRIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FULLSTRIP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FUMCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::FUNCER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FUNCLOGOR%E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FUNCTION-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FUNCTION-MODE-@)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FUNCTIONP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FUNGEN&ENV-FOR-MEVAL-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::FUU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FXSHFR-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::FXSHFT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER T) *) MAXIMA::G-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GAM-CONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::GAMMA-INCOMPLETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GAMMA-LANCZOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::GAMMA1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GAMMAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GAMMAFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GAMMAGREEK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GAMMAGREEKTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GAMMAINCOMPLETETW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GAMMARED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::GAMMAREDS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) *) MAXIMA::GAMMA_INCOMPLETE-TO-GAMMAGREEK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GATHER)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GCCON)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GCCON1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GCD-DEGREE-VECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GCDISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GCDL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GCDRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GCEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GCFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GCPOWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GCTIME1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GCTIMEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::GEGENPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GEN-POINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GEN-TR-LAMBDA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GENATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GENERIC-AUTOLOAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GENEXPANDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GENFIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GENNEGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GENPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GENREF)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL (VALUES T T)) MAXIMA::GENSUMINDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GENSYM-READABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GERED1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GERED2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GEREDF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GEREDNO1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GEREDNO2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GET!)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-ARRAY-POINTER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GET-CONST-OR-INT-TERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-FACTOR-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::GET-FREE-INDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-GNUPLOT-TERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-LARGE-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-LARGE-FACTORS-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GET-LEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::GET-LIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-LINEINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-LISP-FUN-TYPE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GET-NEWEXP&FACTORS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::GET-NOT-CONST-OR-INT-TERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-ONE-FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GET-ONE-FACTOR-ECM)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER *) *) MAXIMA::GET-ONE-FACTOR-P-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GET-ONE-FACTOR-POLLARD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::GET-PLOT-OPTION-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-RANGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-ROTATION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::GET-SERIES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GET-SMALL-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GET-TEX-ENVIRONMENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GET-THETA-FOR-VERTICAL-Z)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETALIAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETCHAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETCHARN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETD0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETDEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GETEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GETEXP-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GETEXPLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETFACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETFNCOEFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETFNSPLIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GETFUN-LT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETGOODVALS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETL-LM-FCN-PROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETLABCHARN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GETLABELS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GETLABELS*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETLIMVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETMINOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETOPR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GETOPR0)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GETOPTIMVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GETRISCHVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETSIGNL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETUNHACK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETVALUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GETVARDEGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-ADD-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-AMM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GF-AT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-AT-ERRCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-CHAR?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GF-CINV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-CJACOBI)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GF-CLEAR-TABLES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GF-CMINUS-B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GF-CMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-COEFF-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-COMPOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GF-CP2SMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GF-CPLUS-B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GF-CPOW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GF-CTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-CARD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-CHAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-FS-ORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-FSX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-FSX-BASE-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-ORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-PRIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-RED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-DATA-SHORT-PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA-X^P-POWERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DATA?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-DEGREE-ERRCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::GF-DISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GF-DISREP-FACTORS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-DISTINCT-DEGREE-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GF-DIVIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-DLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-DLOG-BABY-GIANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::GF-DLOG-F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-DLOG-NAIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-DLOG-RHO-BRENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-DLOGB)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-EQUAL-DEGREE-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::GF-EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-FIELD?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-GCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GF-GCD-COFACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-GCDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-GROUP-ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-INV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-IRR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T INTEGER FIXNUM) T) MAXIMA::GF-IRR-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-JACOBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-L2N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-L2P-ERRCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-L2X)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-LOG-ERRCHK1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-LOG-ERRCHK2)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GF-MAKE-LOGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::GF-MATADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-MATADD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-MATADD2)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GF-MATADD2-ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::GF-MATMULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-MATMULT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-MATMULT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-MAYBE-NORMAL-BASIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::GF-MERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::GF-MINPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-MINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-MOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-MULT-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER) T) MAXIMA::GF-N2L)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (INTEGER FIXNUM) T) MAXIMA::GF-N2L-TWOARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-N2P-ERRCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER) T) MAXIMA::GF-N2X)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-NCX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-NMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NONCONST-RANDOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-NORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-NORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-NORMAL-BASIS-REP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-NORMAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-NP2SMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NREM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-NRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-NRT-EXIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NS2PMOD-FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-NS2PMOD-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NXCPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NXCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-NXX2X)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-NXYECPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-NZX+CX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-ORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::GF-ORD-BY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-P2X)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-P2X-RAW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-P2X-RED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-PLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T INTEGER T) T) MAXIMA::GF-POW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-POW$)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::GF-POW-BY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::GF-POWER-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::GF-POWER-TABLE-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GF-PRECOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GF-PRIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-PRIM-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::GF-PRIMPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM) T) MAXIMA::GF-PRIMPOLY-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-PRIMPOLY-P-EXIT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T FIXNUM T T) T) MAXIMA::GF-PRIMPOLY-P2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-PTH-ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-RANDOM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GF-RANDOM-NORMAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-RED?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-REM)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GF-SET-RAT-HEADER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-SQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-SQUARE-FREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-TRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-TRACE-POLY-F2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-UNIT-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::GF-X2ARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-X2CRE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::GF-X2L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-X2N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-X2P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GF-XCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GF-XECTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::GF-XYECPLUS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (INTEGER FIXNUM T) T) MAXIMA::GF-X^P-POWERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GF-ZX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::GFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GFSPLIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::GGR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GGR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GGRM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::GGRM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GNUPLOT-COLOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::GNUPLOT-CURVE-STYLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GNUPLOT-PALETTE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::GNUPLOT-PLOT3D-COMMAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::GNUPLOT-POINTTYPE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) FIXNUM) MAXIMA::GNUPLOT-POINTTYPES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GNUPLOT-PRINT-HEADER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::GNUPLOT-PROCESS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GNUPLOT-TERMINAL-AND-FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GOBBLE-COMMENT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::GOBBLE-WHITESPACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GOOD-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GOODFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GPCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GPDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GPPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GPTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::GREATERRATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::GRUNTZ1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::GVAR-LIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::GVAR-LOGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::HACKIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HAIPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HALFANGLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HALFANGLEAUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::HALFANGLEAUX-FACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HALFSPLIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::HALVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HAND-SIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HANKEL-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HANKEL-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HARRFIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HAS-CONST-OR-INT-TERM)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::HAS-DISTINCT-NONZERO-ROOTS-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HAS-INT-SYMBOLS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HAS-NOT-ALIKE1-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HAS-REPEAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HASHER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HASVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HDOT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) *) MAXIMA::HERMITE-TO-HYPERGEOMETRIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HERMPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HETD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HEURTRIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HEURTRIAL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::HEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::HGFSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::HGFSIMP-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HIDELIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HIDELIMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HIPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HLINSOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HORN+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HORNREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::HREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HSIMP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::HSTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::HTJORY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::HYP-ATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) *) MAXIMA::HYP-COS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HYP-INTEGERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HYP-NEGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HYP-NEGP-IN-L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::HYPEREX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::HYPEREX0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::HYPEREX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::HYPERTRIGINT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::HYPGEO-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::HYPREDERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::HYPREDINCGM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::I-$DEPENDENCIES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::I-$GRIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::I-$REMOVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::I-$REMVALUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::IDENTITYMX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IGNORE-ERRORS-MFUNCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::IGPRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ILT0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ILT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ILT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ILT3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IMAG-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IMODP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IMODP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IMPLIED-QUOTEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::IMPLODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IMPROPER-ARG-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IN-DOMAIN-OF-ASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::IN-INTERVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INCR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INCREASELIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INCREMENT-TRUNCS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INCRLIMK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IND1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IND2)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) T) MAXIMA::INDEX*)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::INFIN-ORD-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INFINITYP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INFOLSTCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::INFOSTORE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INFR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INFSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INFSIMP*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INFSIMP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INFSIMP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INHERIT-PROPL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INIT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::INIT-BREAK-POINTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INIT-LAMBERT-W-0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INIT-LAMBERT-W-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::INIT-LAMBERT-W-MINUS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INIT-PRIME-DIFFS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::INITIAL-ANALYSIS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::INITIALIZE-NUMERIC-CONSTANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INITIALIZERSMOSTLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INLIST3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INSERT-BREAK-POINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INSERT-IT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T)
-            MAXIMA::INSERT-NECESSARY-FUNCTION-DECLARES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INSIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INSRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INSURE-ARRAY-PROPS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTBASEHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTBYTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTCV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTCV1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTCV2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTCV3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTDIFFL1L2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTEGER-BELLN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::INTEGER-PART-OF-SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTEGER-PARTITIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTEGER-REPRESENTATION-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTEGER-STIRLING1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTEGER-STIRLING2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTEGERP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTEGERP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTEGERPFR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::INTEGERTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::INTEGRALLOOKUPS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::INTEGRAND-CHANGEVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTEGRATE-EXP-SPECIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTEGRATE-MEXPT-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTEGRATE-MEXPT-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INTEGRATE-USE-ROOTSOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTEGRATE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTEGRATE5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTEGRATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::INTERHERMPOL)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::INTERN-INVERT-CASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INTERP-POLYS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTERSECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTERSECT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTERSECT-INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTERSECT-TESTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTERVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INTERVAL-ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INTERVAL-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::INTERVAL2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::INTFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTGREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::INTI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTIR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTIR-REF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTIR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T T) *) MAXIMA::INTIR1-REF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTIR2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTIR3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::INTIR3-R0TEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::INTIR3-REF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTIRA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTIRFACTOROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::INTOFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTOPOIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::INTOPOISCO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::INTSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::INTSC0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::INTSC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INTSET1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INTSETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::INTSUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::INTSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::INTSUM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INV-MOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INVERT-TERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::INVERTBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::INVOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IPOLY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::IPOLY2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IPOLYSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IR-OR-EXTEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IREDUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IS-A-POLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IS-BOOLE-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IS-MAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::IS-MAND_TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::IS-MNOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::IS-MNOT_TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::IS-MOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::IS-MOR_TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ISGEO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ISGEO1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ISGREATERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ISINOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ISLINEAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ISMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ISMAX-CORE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ISO1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ISO2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ISOLAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ISQUADRATICP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ISTRENGTH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ISUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ISUM-GIVEUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ISUM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ITERATE-OVER-BKPTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ITH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::IVAR2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::J1TF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::J2TF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::JACOBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::JACOBPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::JMAUG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::JOINVARLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::K)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER T) T) MAXIMA::K-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KAAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::KANSEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KBATEMANTW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::KC-ARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KC-ARG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KCNTXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KDR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KELLIPTICTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::KERNSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KEY-VAR-POW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::KEYHOLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::KILL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KILL-OPERATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::KILL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KILL1-ATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::KILL2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::KILL3)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::KILLALLCONTEXTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KILLC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KILLCONTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KILLFRAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KILLVARDEGSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KILLVARDEGSN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KINDP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::KINDP34)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KLIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KNOWN-PS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::KNOWNFACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::KSUBSET-LEX-SUCCESSOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::KTFORK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::KTI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::KUMMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LAB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LABEQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LAGPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::LAGRANGE3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::LAGRANGE33)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LAMBDA-MEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LAMBDA-WRAP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LAPDEFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LAPDELTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LAPDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LAPERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LAPEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LAPINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::LAPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LAPLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LAPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::LAPPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LAPSHIFT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LAPSIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LAPSINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::LAPSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LAPTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LASSOCIATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LBP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LCPRODL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LEADALGCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LEADARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LEADCOEFFICIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LEADING-COEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LEADOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LEADTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LEARN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LEARN-ABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LEARN-NUMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LED-CALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LEFT-OB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::LEGEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LEGENPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGF14)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGF16)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGF20)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGF24)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGF36)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LEGPOL-CORE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LENGTH-ONE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LENIENT-EXTENDED-REALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LENIENT-REALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LESSTHAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LET-MACRO-GET-LAST-VAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LET-MACRO-GET-VARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LET-MACRO-HAIR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LET-RULE-SETTER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LFIBTOPHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LGCD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LGCPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LGCRECIPROCAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LGCSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LGCSIMPLEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LGCSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LGCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LHOP-NUMDEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LHOSPITAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LHOSPITAL-CATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LHSIMP)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::LI-ASYMPTOTIC-EXPANSION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LI-ORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LI2NUMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LI2SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LI3NUMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LI3SIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LIFTING-FACTORS-IMAGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LIKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIM-ABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LIM-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIM-FINITEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIM-IMAGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIM-INFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LIM-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIM-MINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIM-PLUSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LIM-POWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LIM-RECIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LIM-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIM-ZEROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::LIMCP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LIMFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LIMFACT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIMINV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LIMIT-CONTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::LIMIT-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::LIMIT-NO-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::LIMIT-POLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LIMIT-SUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LIMIT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LIMIT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LIMITINF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LIMITNEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LIMITSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LIMITSIMP-EXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LIMROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LIMUNKNOWN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIMUNKNOWN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIN-MEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIN-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIN-MTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LIN-VAR-FIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LINCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LINDEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LINE-INFO-FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LINE-INFO-LINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LINEAR*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LINEAR-DISPLA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LINEAR-TERM-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LINEARCONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LINEARIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LINEARIZE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LINEARIZE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LINEARIZE3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LINEARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::LINHACK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LINHACKCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LINOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LINPOWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LINPOWER0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LINSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LISIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LISIMP-NEGATIVE-INTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LISP->LISP-TR-LAMBDA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LISP-ARRAY-ALIKE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LISP-FCN-TYPEP)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T *) T) MAXIMA::LISPIFY-MAXIMA-KEYWORD-OPTIONS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LISPM-MFUNCTION-CALL-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::LISPM-REARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LIST-MEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LIST-OF-MLISTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::LIST-REF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::LIST-VARIABLE-BINDINGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LISTARGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LISTARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LISTIFY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LISTOF0S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LISTOVARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LISTOVARS0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LISTOVARS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LISTOVARSL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LITTLEFR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LITTLESLOMMEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LMAINVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LMAKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LMAKE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LMUL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LNEWVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LNEWVAR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOAD-AND-TELL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LOAD-FUNCTION)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (*) T) MAXIMA::LOAD-MACSYMA-MACROS-AT-RUNTIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LOADFILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LOBJ->POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LOCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LODEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOFACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LOG*RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOG-GAMMA-LANCZOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LOG-IMAG-0-2%PI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOG-RED-CONTRACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LOG-REDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LOG-TRANSFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LOGARC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOGBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LOGCON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOGCONCOEFFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LOGCPI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LOGCPI0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LOGCPJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LOGEQUIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOGMABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::LOGNX2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOGNXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOGQUAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOGQUAD0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LOGRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOGTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LOGX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LOOPP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOWDEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LOWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LOWERHALF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LPOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LPR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LRDTAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::LSA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LSAFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LSFT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LSTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::LT-ARBPOW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::LT-ARBPOW2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LT-BESSEL_K0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LT-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LT-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LT-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LT-LTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::LT-SF-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LT1E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LT1ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LT1GAMMAGREEK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LT1HSTRUVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LT1J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LT1J^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LT1KELLIPTIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::LT1LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LT1LSTRUVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LT1M)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LT1P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LT1Q)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::LT1S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LT1YREF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::LT2J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LTERMVEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::LTSCALE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::LTW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LTY)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) *) MAXIMA::LUCAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::LUCAS-SEQUENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M$EXP?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M*S+C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M-SUBSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-A*T)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-A*X+B/C*X+D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-A*X^M+C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ARBPOW1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ARBPOW2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ASSOC_LEGENDRE_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ASSOC_LEGENDRE_Q)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-B*X+A)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-BESSEL_I*HANKEL_1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-BESSEL_I*HANKEL_2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-BESSEL_K*HANKEL_1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-BESSEL_K*HANKEL_2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-BESSEL_Y*HANKEL_1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-BESSEL_Y*HANKEL_2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-C*T^V)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-C*X^2+B*X+A)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-CHEBYFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::M2-D*X^M*%E^A*X)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-DEFLTEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ELLIPTIC_EC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ELLIPTIC_KC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-10)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-10-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-1A)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-2-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-4-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-5-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-6)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-6-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-7)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-7-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-8)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-8-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-8-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-9)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-EXP-TYPE-9-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-E^-T)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-E^T)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-F+C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HANKEL_1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HANKEL_1*BESSEL_J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HANKEL_1*HANKEL_2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HANKEL_1^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HANKEL_2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HANKEL_2*BESSEL_J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HANKEL_2^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HYP-ONEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-HYPERGEOMETRIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-JACOBI_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-LEGENDRE_P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-LOG-EXP-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-LOG-EXP-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::M2-LTEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONE-GEN-LAGUERRE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONE-HERMITE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONE-LAGUERRE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEEXPINTEGRAL_CHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEEXPINTEGRAL_CI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEEXPINTEGRAL_E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEEXPINTEGRAL_E1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEEXPINTEGRAL_EI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEEXPINTEGRAL_SHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEEXPINTEGRAL_SI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEFRESNEL_C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEFRESNEL_S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEGAMMAGREEK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEGAMMAINCOMPLETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEIONEJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEIONEK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEIONEY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEI^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEJ^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEKBATEMAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEKELLIPTIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEKONEJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEKONEY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEK^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONELOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEP0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEPJAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONESLOMMEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEYONEJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-ONEY^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-PARABOLIC_CYLINDER_D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::M2-RATROOTFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-SQROOTT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-STRUVE_H)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-STRUVE_L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-SUM-WITH-EXP-CASE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-SUM-WITH-EXP-CASE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-SUM-WITH-EXP-CASE3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-SUM-WITH-EXP-CASE4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-SUM-WITH-EXP-CASE5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-TWO-HANKEL_1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-TWO-HANKEL_2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-TWOI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-TWOJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-TWOK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-TWOY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-T^-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-T^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-UNIT_STEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-WHITTAKER_M)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::M2-WHITTAKER_W)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MABS-SUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MABSBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-FSYMEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-FSYMEVAL-SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-NAMESTRING-SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-READ-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-SPECIAL-MACRO-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-SPECIAL-OP-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-TIMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::MACSYMA-TOP-LEVEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-TRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MACSYMA-TRACE-SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-UNTIMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MACSYMA-UNTRACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MACSYMA-UNTRACE-SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::MAIN-PROMPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKCF)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-BKPT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T (VECTOR T) FIXNUM) T)
-            MAXIMA::MAKE-BREAK-POINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAKE-DECLARES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKE-DEFINT-ASSUMPTIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-DISP-HACK-OB)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-EF-DATA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAKE-ELLIPTIC-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAKE-ELLIPTIC-F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKE-EQUAL-HASH-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-GF-DATA)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MAKE-GLOBAL-ASSUMPTIONS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MAXIMA::MAKE-GRID-VERTICES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAKE-LI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MAKE-LIMIT-ASSUMPTIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-LINE-INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKE-LINSOLS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKE-LONG-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAKE-MAXIMA-TEX-GLUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-MGENARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-MRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAKE-NUMBER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MAKE-OPERATION)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MAKE-PARAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MAKE-PARSER-FUN-DEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKE-SWITCH-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-TC-STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MAKE-TRACE-HOOK)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MAKE-TSTACK-SLOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKE-VALUES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKE-VAR-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::MAKEALIAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAKEFACT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAKEGAMMA1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKELABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAKEPREDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKESTRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKNAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAKORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKPOINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAKPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAKPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKPROD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAKPRODG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKSTRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKSYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAKSYMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MANIFESTLY-COMPLEX-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MANIFESTLY-NONREAL-P)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::MANIFESTLY-PURE-IMAGINARY-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MANIFESTLY-REAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::MAP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAP2C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAPATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAPCAR-EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAPFR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::MAPLIST_TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MAPPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MAPPLY-TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::MAPPLY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAPTR-LISP->LISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::MAREF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MARK+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MARK+0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MARK+1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARK+3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MARK-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MARK-0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MARK-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MARKND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARKP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARKS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARRAY-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARRAY-TYPE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MARRAY-TYPE-UNKNOWN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::MARRAYREF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MARRAYREF-GENSUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MARRAYREF1$)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::MARRAYSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::MARRAYSET-GENSUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MARRAYSET1$)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::MASET1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MATCH-SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MATCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MATCHERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MATCHSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MATOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MATRIX-MATRIX-PRODUCTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MATRIXHELPER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAX-NUMERIC-RATIO-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXCOEF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXCOEFFICIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXI)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MAXIMA-BANNER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-BRANCH-ACOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-BRANCH-ACOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-BRANCH-ASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-BRANCH-ATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-CONSTANTP)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-DECLARED-ARRAY-ALIKE1)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-DECLARED-ARRAY-MEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-DECLARED-ARRAYP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::MAXIMA-DISPLAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAXIMA-GETENV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-INTEGERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-LISP-DEBUGGER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-RATIONALIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-RATIONALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-REDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-REMF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MAXIMA-SUBSTITUTE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-UNDECLARED-ARRAY-ALIKE1)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXIMA-UNDECLARED-ARRAY-MEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXIMA-UNDECLARED-ARRAYP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MAXIMIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MAXIMUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAXMINL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAXNORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAYBE-BOOLE-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MAYBE-BREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAYBE-INVERT-STRING-CASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MAYBE-REALPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::MAYBE-RESET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MAYBE-SIMPLIFYA)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) *) MAXIMA::MAYBE-SIMPLIFYA-PROTECTED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MAYBPC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MBAGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MBIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MBIND-DOIT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::MBREAK-LOOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MBUILDQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MBUILDQ-ASSOCIATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MBUILDQ-SPLICE-ASSOCIATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MBUILDQ-SUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::MCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MCONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MCONS-EXP-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MCONS-OP-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MCX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MDATA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::MDEFARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MDEFCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MDEFINE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MDEFLISTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MDEFMACRO1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MDEFPARAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MEASURE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MEMALIKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MEMBERCAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MEMBERROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MEMQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEMQARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MEMSIMILAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MEMSIMILARL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MENU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEQHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MEQP-BY-CSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEQUALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MERGE-SKEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MERGE-SOL-LIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MERGE-SOL-LIN-Z)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MERGE11)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MERGESOLN)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::MERRBREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::MERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::META-ADD2LNC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::META-FSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::META-MPUTPROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::META-OUTPUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::META-PUTPROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::METHOD-BY-LIMITS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::METHOD-RADICAL-POLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MEVAL*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MEVAL-ATOMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MEVAL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MEVAL1-EXTEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MEVAL2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEVALARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MEVALATOMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MEVALN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEVALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEVALP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MEVALP1_TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MEVALP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MEVALP_TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MEVALSUMARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEVENP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEXPLODEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MEXPTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MFACPPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MFBOUNDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MFORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MFORMAT-TRANSLATE-OPEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MFREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MFREEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::MFUNCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MFUNCTION-CALL-WARN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MFUNCTION-DELETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MFUNCTION1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGEN2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGENARRAY-AREF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGENARRAY-ASET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGENARRAY-CONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGENARRAY-GENERATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGENARRAY-NULL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGENARRAY-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MGENARRAY-TYPE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MGETL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MGQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MGRIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MGRP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MHEADER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MICRO-PER-CALL-TO-SEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MICRO-TO-SEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MID)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MID-)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MIDOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MIDPNT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::MILLER-RABIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MINIMIZE-VARLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MINIMUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MINLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MINMAXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MINOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T T) T) MAXIMA::MINORL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MINVARLIST-MRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MKILL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MKIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::ML-TYPEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::MLAMBDA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MLIST-ASSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MLISTCAN-$ALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MLOGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MLSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T T) *) MAXIMA::MM-INTIR1)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T T T T T) *) MAXIMA::MM-INTIR1-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MMACRO-APPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MMACRO-DISPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MMACROEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MMACROEXPAND1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MMACROEXPANSION-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MMAPCAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MMAPEV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MMINUSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MMINUSP*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MMMINUSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MNCEXPTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MNCTIMESP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MNEGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MNLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MNLOGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MNQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MOD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MODDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MODEDECLARE-INTERNAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MONICGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MONICIZE-ROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MONIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MONOM->FACL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MONOMGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MONOMGCDCO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MONSTERTRIG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MOPP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MOPP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MOPSTRINGNAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MOPSTRIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MORP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::MOSTPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::MOVECOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::MOVEROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MPARAMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::MPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) T) MAXIMA::MPC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::MPC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MPGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MPLUSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MPRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MPROPSCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MPUTPROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MQAPPLY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MQAPPLYP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MQUOTEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MRATCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MRATEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MREAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MREAD-NOPROMPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MREAD-PROMPTER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::MREAD-RAW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::MREAD-SYNERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MRECORD-ASSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRECORD-KILL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MREDEF-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRELATIONP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MREMPROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MRETURN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-ABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-ADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-ADD-ID)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-ADJOINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-COERCE-TO-LISP-FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-DIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-FZEROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-GREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-MAXIMA-TO-MRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-MRING-TO-MAXIMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-MULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-MULT-ID)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-NAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-NEGATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-PSQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-RDIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-RECIPROCAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MRING-SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MRV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MRV-COMPARE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MRV-LEADTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MRV-MAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MRV-MOVEDOWN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MRV-MOVEUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MRV-REWRITE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MRV-SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MSEEMINGLY-UNBOUND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MSETCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MSETERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MSETQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::MSIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-ARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-ARRAY-OBJECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-ATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MSIZE-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-INFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-MATCHFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MSIZE-MLABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MSIZE-MMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-MTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-NARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MSIZE-NOFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MSIZE-PAREN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MSIZE-POSTFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MSIZE-PREFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-SPACEOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSIZE-TEXT-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MSPECFUNP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MSTRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MSTRINGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MSUBLIS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MSUBLIS-SETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MSUBLIS-SUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MSUBLIS-UNSETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MSYMBOLP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-BIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-MCOND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-MDEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-MDO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-MDOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-MEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MSZ-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-MQAPPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MSZ-MTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MSZNARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::MTELL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MTERPRI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MTIMESP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM T) T) MAXIMA::MTOA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MTOINF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MTORAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::MTOSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM T) T) MAXIMA::MTYOTBSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::MUL)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::MUL*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MUL2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MUL2*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::MUL3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MULL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MULN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MULTBK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MULTFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MULTIDEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MULTIPLE-%PI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MULTIPLEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MULTIPLICATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MULTIPLY-GCFACTORS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::MULTIPLY-MATRIX-ELEMENTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MULTIPLYMATRICES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MULTL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MULTMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MULTOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MUNBIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MUNFORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::MUNLOCAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::MWHIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MXC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MXCOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MXORLISTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MXORLISTP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::MXPLUSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MXTIMESC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MY-PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MYADD2LNC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::MYCABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::MYDEFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::MZFREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NALGFAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NAMESONLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NARG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NARY1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NARY2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NATURALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NBN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NC-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NCMUL2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NCMULN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NCPOWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::NEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEG-MONOM?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEGINP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEGTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NESTLEV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEVERSET)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::NEW-ALG)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::NEW-COMMENT-LINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEW-FILE-SEARCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NEW-FILE-SEARCH1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEW-SKEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NEWDET)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::NEWEST-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NEWGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEWGCDCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWGCDL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) MAXIMA::NEWINV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::NEWLINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::NEWMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWPRIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWSYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEWSYM2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWVAR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWVAR3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEWVARMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NEWVARMAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NEWVARMEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::NEXT-COSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEXT-PRIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEXT-PRIME-DET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEXT-PRIME-PROB)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::NEXTH-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::NEXTK-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NEXTLEVEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::NFORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NFORMAT-ALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::NFORMAT-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISADDON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NISARGMATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NISARGSCHECKER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISBUILD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NISEXPOCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISEXTRACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISINNERNULL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISKERNEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NISLET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISLETSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISLETSIMPRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NISMATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISNEWLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISNUMBERPICKER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISPERMUTATIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NISREMLET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISREPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NISSEARCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISSWCAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISSWCDR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NISTREEBUILDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISTREELISTER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NISTREETRIMMER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NMR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NMT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NMTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NNI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NO-ERR-SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NO-SING-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::NOCONSTQUAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NODEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NON0RAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::NONCONSTQUADENUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NONEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NONINTEGERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NONNEGATIVE-INTEGERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NONNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NONPERIOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NONSQFRCASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NONSYMCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NONVARCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NONZERP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::NOR-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NORM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NOSHFT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NOT-ZERO-FREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NOTERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NOTINVOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NOTLOREQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NOUNLIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NPASK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NPCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NPCTIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NPQUO)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::NPRINC*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NRATFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NRETFACTOR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NROOT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::NROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NRTHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NRTHK1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NRTHK2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T) T) MAXIMA::NS-INTIR3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NSUBSTRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NTHCOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NTHCOL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NTHELEM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NTHKDR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUD-CALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUM-OF-LOG-L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::NUM-OF-LOGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::NUMBER-OF-DIGITS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUMBERINLISTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUMDEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUMDEN*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUMER)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::NUMERIC-BETA-INCOMPLETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::NUMERICAL-EVAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::NUMERSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::NUMJORY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::NUMMDENN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) T) MAXIMA::NUMMNUMN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::NUMN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUMNEEDSPAREN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::NUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) (VALUES T T)) MAXIMA::NXTBINCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::NZEROS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::NZL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OBJECT-FOR-DISPLAY-HACK)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T FIXNUM FIXNUM FIXNUM FIXNUM) T)
-            MAXIMA::OBMTRX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OBTAINAB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OBTAINABM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ODD-FUNCTION-REFLECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ODD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ODDELM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ODDFN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ODDFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ODDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ODNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OF-FORM-A*F<X>^N+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OFF-NEGATIVE-REAL-AXISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OFFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OLDCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OLDCONTENT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OLDCONTENT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OLDCONTENTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OLDGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OLDGCDCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OLDGCDL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OLDGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OLDREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ON-NEGATIVE-REAL-AXISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ONE-STEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ONEARGCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ONEDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ONEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ONEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ONEP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ONEVARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ONP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ONPU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::OP-EQUALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OP-SETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM *) *) MAXIMA::OPEN-SOCKET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::OPER-APPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OPERATOR-FREQUENCY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPERATOR-WITH-ARRAY-FLAG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPERATORP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPERATORP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPFORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPIDENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPMEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::OPT-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPT-HASH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPTIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPTIMIZE-PRINT-INST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPTIONP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPTIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OPTRIG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ORD-VECT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ORD-VECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ORDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ORDER-LIMITS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ORDER-VARS-BY-STRENGTH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ORDERLESSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ORDERPOINTER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ORDERVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ORDFN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ORDFNA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ORDHACK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ORDLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ORDMEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OSCIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::OTRACEMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OUT-OF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::OUTATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::OUTER-CONSTANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::OUTERMAP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::OUTERMAP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OUTPUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::OUTPUT-LINEAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::OUTPUT-LINEAR-ONE-LINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::OUTPUT-POINTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::OUTPUT-POINTS-TCL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::OUTPUT-TEXT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::P*LOGNXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::P*PIN%EX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::P-DELETE-ZEROS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::P-DESCENDING-POWERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::P1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::P11)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::P2CPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PACOEFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PADE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PADE-MONIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PADE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PAINVMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PAIROFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PALGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PALGSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PAQUO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-$DO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-AZIMUTH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-BUG-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-CONDITION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-ELEVATION)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PARSE-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARSE-INFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PARSE-INTEGRAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-MATCHFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARSE-NARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-NOFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARSE-POINTS-X-Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-POINTS-XY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-POINTS-Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARSE-POSTFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-PREFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-TAY-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-TAY-ARGS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARSE-TAY-ARGS2)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PARSE-TYI)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PARSE-TYIPEEK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARSER-ASSOC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PART*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PART+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PART1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::PARTFRAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARTFRACA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PARTIAL-DIAG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARTIAL-INTEGRATION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PARTITION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARTITION-NS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PARTITION-PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PARTNUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PASCAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PASIMP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::PATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PATCH-UP-MEVAL-IN-FSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PATIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCDIFCONC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCDIFFER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PCETIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PCOEFADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PCOEFVEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PCONSTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCONTENT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PCONTENTZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PCSUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PCSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PCSUBSTY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCSUBSTZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PCTIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDECGDFRM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDECOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDECOMP*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDECOMP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDECPOW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDECPRIMEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PDECRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDEGR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDEGREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDEGREER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDEGREEVECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDERIVATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PDIAG-ALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDIFROWS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDIS*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDISREP!)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDISREP*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDISREP*CHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDISREP*EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PDISREP+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDISREP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDISREP2EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PDIVIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PEEK-ONE-TOKEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PEEK-ONE-TOKEN-G)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PELSO1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PERIOD)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (FIXNUM (ARRAY FIXNUM) (ARRAY FIXNUM)) T)
-            MAXIMA::PERMUTATION-LEX-SUCCESSOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PEXPON*//)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PEXPTMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PEXPTSQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFACPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFACTOR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFACTOR11)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PFACTOR2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PFACTORALG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFACTORANY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PFACTORLIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFACTORQUAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::PFET1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFLAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFLATTEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::PFLOATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PFLOATP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::PFREEOFMAINVARSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::PFRNUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PGATH1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PGATH2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PGATH3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PGATHERCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PGCD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM) T) MAXIMA::PGCD2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PGCDA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PGCDCOFACTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PGCDEXPON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PGCDM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PGCDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PGCDU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PGCDU1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PGSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::PIN%EX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::PIN%EX0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PINTERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PINTERPOLATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PINTERPOLATE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PINTERPOLATE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PINTERPOLATE3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PINTERPOLATE4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PINTERPOLATE5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PINTERPOLATE6)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PIRREDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PIVOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PJAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::PJACTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PJACTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PKRONECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PLCM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PLCMCOFACTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PLOT-FILE-PATH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PLOT-OPTIONS-PARSER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PLOT-TEMP-FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PLOTCOLORP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PLS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::PLSK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PLSOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PLUSIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PLYGAM-CONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PLYGAM-ORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PLYGAM-POLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T T) *) MAXIMA::PM-INTIR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMAKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMINDEGVEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMINUSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMODCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PMODQUO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PMODREM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMODROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMODROOT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PMON1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMONICIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PMONZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PNEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PNEXT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T) T) MAXIMA::PNS-INTIR3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PNTHROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PNTHROOTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POFX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POINTERGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POINTTYPEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISCDECODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISCHANGESIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::POISCO*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::POISCO+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::POISCODIF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::POISCOINTEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISCOSINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POISCTIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::POISDECODEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISDIF4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISENCODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISINT4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POISLIM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISMAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POISMERGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POISMERGE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POISMERGE22)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POISMERGEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POISMERGECX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POISMERGES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POISMERGESX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISNEGPRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISPZERO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISSINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISSUBST1C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISSUBST1S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POISSUBSTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::POISSUBSTCO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POISSUBSTCO1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POISXCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POLCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLE-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POLELIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::POLES-IN-INTERVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLFACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::POLFOO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLY->PS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POLY-IN-VAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POLY?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POLYDECOMP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::POLYEV-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYGON-DUMMY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYGON-EDGES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYGON-PTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYINT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYINT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::POLYINX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM T) T) MAXIMA::POLYIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::POLYLOGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POLYST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POLYSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::POP-LOOP-CONTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::POP-MLAMBDA-CALL-STACK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POP-PW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::PORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POS-NEG-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POSEVEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POSINTEGERSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POSIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POSSIBLE-PREDICATE-OP-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::POWER*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POWER-MOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::POWER-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POWERCOEFLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::POWERLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::POWEROFX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::POWERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::POWERSET-SUBSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::POWERX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::POWRS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T T) *) MAXIMA::PP-INTIR1)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T T T T T) *) MAXIMA::PP-INTIR1-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER INTEGER) T) MAXIMA::PPEXPO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PPLUSCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PPPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PQR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PQUO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PQUOCOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PQUOTIENTCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PQUOTIENTCHK-SAFE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRADD2LNC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRE-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PRED-$READ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::PRED-REVERSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PREFIXCONC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PREM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PREMTERM-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRENUMBER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PREP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PREPFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRESIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PRESULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PRESULTANT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T *) *) MAXIMA::PRETTY-GOOD-FLOOR-OR-CEILING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PREVCONSTEXPAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRIMCYCLO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PRIMELMT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRIMEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRIMEP-LUCAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRIMEP-PROB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRIMEP-SMALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRINC*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRINCIP)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PRINCIPAL)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::PRINCIPAL-VALUE-INTEGRAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRINT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRINT-ABORT-MSG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRINT-INVERT-CASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRINT-MODULE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::PRINT-ONE-FRAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRINT-PT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRINT-SPACES)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PRINTLABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PRINTNET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRLAB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::PRMUSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRNET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROC-$DEFMATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROC-$DEFRULE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROC-$MATCHDECLARE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROC-$TELLSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROC-$TELLSIMPAFTER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROCESS-ERROR-ARGL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROCLAIM-PROPERTY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRODCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRODCOEF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T FIXNUM FIXNUM) T) MAXIMA::PRODHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRODND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRODNUMDEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PRODUCT-WITH-INNER-SCALARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PROP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PROPERTIES)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::PROPG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PROPSCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PRSMATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PRSNARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PS-GT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PS-INVERT-VAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PS-LIM-INFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSANS-ADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSCDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSCOEFF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSCONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSCOSA+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSCOSHA+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSCPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSCPLUS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSCSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSCSUBST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSCTIMES*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PSDERIV1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::PSDERIV2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDERIVATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDIFF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::PSDIFF2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSDISEXCNT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSDISEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSDISEXTEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::PSDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDISREP*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDISREP*EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDISREP+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSDISREP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDISREP2EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSDISREP^)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::PSDP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PSDP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSEXPON-GCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSEXPT-FN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSEXPT-FN-SING)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T FIXNUM T T) T) MAXIMA::PSEXPT-FN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSEXPT-FN2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSEXPT-LOG-ORD)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T T T FIXNUM T T T T) T) MAXIMA::PSEXPT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSFIND-S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSFIND-S1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PSFLOAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSHIFT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSINA+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSINHA+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSISIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSISIMP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSLOG-MONOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T FIXNUM T T) T) MAXIMA::PSLOG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSLOG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSLOG3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSMINUS-TERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PSMONSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T) T) MAXIMA::PSMONSUBST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSP2FOLDSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSP2FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSP2FORMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSPLIT-FIELD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSPLIT-FIELD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSPLUS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::PSPLUS2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSQFR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSQFRP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PSQUOREM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTANA+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTANHA+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTERM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTIMES*1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PSTIMES*2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTRIM-TERMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSTRUNC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSTRUNC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PSUMSQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PSUMSQ1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTCDIFFER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTCDIFFER-MINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTCPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PTCSUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PTCSUB-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PTDERIVATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTDERIVATIVE-COEFFS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PTERMCONT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PTERMVEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PTIMEFTRS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTIMES%E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTIMES*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTIMESCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTIMESMERGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTIMESROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PTMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PTORAT)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T)
-            MAXIMA::PTPT-SUBTRACT-POWERED-PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTPTDIFFER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTPTPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTPTQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PTTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PTTS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PUNIVARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PUREPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PUSH-AUTOLOAD-DEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PUSH-DEFVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PUSH-PRE-TRANSL-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PUSH-PW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PUT-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PUT-TRACE-INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PUTLIMVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PUTODR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PUTONLOGLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PUTONVLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::PUTOPR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PUTORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PUTPROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PUTPROP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::PVSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PWEIGHT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::PWTAYLOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::PZEROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::QTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::QUAD-CONTROL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T *) T) MAXIMA::QUAD-QAG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T *) T) MAXIMA::QUAD-QAGI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T *) T) MAXIMA::QUAD-QAGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T *) T) MAXIMA::QUAD-QAGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T *) T) MAXIMA::QUAD-QAWC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T *) T) MAXIMA::QUAD-QAWF)) 
+    '(FTYPE (FUNCTION (STRING STRING T) T) INTL::DOMAIN-LOOKUP-PLURAL)) 
 (PROCLAIM '(FTYPE (FUNCTION (T T T T T T *) T) MAXIMA::QUAD-QAWO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T *) T) MAXIMA::QUAD-QAWS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::QUAD-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::QUADIT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::QUADSD-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::QUAD_ARGUMENT_CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::QUEUE+P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::QUEUE-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::QUICK-SQFR-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::QUOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::QUOTE-%)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::QUOTE-CHARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::QUOTE-STRINGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::QUOTED-SYMBOLP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::R1M)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RADBYTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RADCAN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RADFUNP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RADICALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::RADLIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RADMABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RADSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RADSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAINV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RAISE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RAISEUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RALGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM T) T) MAXIMA::RAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RASSOCIATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAT->PS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::RAT-ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAT-NO-RATFAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAT0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAT10)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RAT3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAT8)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RAT8PRIME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATALGDENOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATCF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATCOEF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::RATCOEFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATDEGREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATDENOMINATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATDERIVATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATDIF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RATDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RATDISREPD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATDIVIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATDP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RATDP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATDX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATDX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RATEXAND1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RATEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RATFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RATFNT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATGREATERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RATGSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATINVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATION1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATIONALIZER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATLIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::RATLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATMIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATMINUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATNUMERATOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATNUMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATPL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATQU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::RATRAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATREP*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::RATROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RATS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATSETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATSETUP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RATSETUP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RATSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RATSQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RATTI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RATTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RATWTSETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RBP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RCCOEFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RCDIFF!)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RCEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RCEXPT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RCPLUS!)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RCPLYGAM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RDDEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RDFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RDIFFERENCE*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RDIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RDIS*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RDIS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RDSGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RDTAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RE-ERAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RE-SOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RE-SOLVE-FULL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RE-TAYLOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RE-TAYLOR-RECURSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::READ-COMMAND-TOKEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::READ-COMMAND-TOKEN-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::READ-ONLY-ASSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::READLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REAL-BRANCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REAL-ROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL FIXNUM) MAXIMA::REALIT-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REALONLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REALPOSITIVEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::REARRAY-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::RECOVERORDER1)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::RECOVERORDER2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::RECTZTO%PI2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RECUR-APPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RED-MONO-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REDGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REDRESULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REDUCE-VAR-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REDUCE-VAR-SET&OP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::REF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::REF-FPQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::REFINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::REFLECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::REFLECT0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) FIXNUM) MAXIMA::RELATIVE-LINE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REM-CONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REM-OPERS-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REM-TRACE-INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::REMALIAS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REMALIAS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::REMARRELEM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::REMBOX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMCOMPARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::REMFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMLABELS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMLAPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMOPR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMOV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REMOV0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::REMOV1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::REMOV2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REMOV3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REMOV4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMOVE-BINDINGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REMOVE-SINGULARITIES)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::REMOVE-TRANSL-ARRAY-FUN-PROPS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMOVE-TRANSL-FUN-PROPS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::REMOVE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMOVEALG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REMOVERULE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMPROPCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMRULE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REMSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REMVALUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RENUMBER-TLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::REPLAC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION NIL T) MAXIMA::REPLACE-COSET-IN-MULTIPLY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::REPLACEROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REPLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REPLIST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REQUIRE-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REQUIRE-LIST-OR-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::REQUIRE-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::RES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RESET-DO-THE-WORK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RESIDUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RESIMPLIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::RESM0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RESM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RESOLVENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RESPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::RESPROG0)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::RESTORE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::RESTORE-ASSUMPTIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::RESTORE-BINDINGS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::RESTORE-DEFINT-ASSUMPTIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RESTORE-FACTS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::RESTORE1)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::RESTORE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RESTORELC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RESTORELIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RESTOREX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RESTOROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RESULT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RESULTANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RETFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RETFACTOR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RETLIST-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::RETLIST_TR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RETRIEVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) FIXNUM) MAXIMA::REVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::REVEAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::REVSIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RFLOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RGB-COLOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RGRP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RGSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RHALF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RHEUR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RI-HI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RI-LO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RI-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RIB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RIDOFAB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RIGHT-OB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISCH-CONSTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISCH-PCONSTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RISCHADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::RISCHEXPLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RISCHEXPPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RISCHEXPVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISCHFORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISCHFPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RISCHINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISCHLOGDPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISCHLOGEPROG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISCHLOGPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::RISCHNOUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::RISPLIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISPLIT-BESSEL-J-OR-I)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISPLIT-BESSEL-K-OR-Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISPLIT-EXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RISPLIT-EXPT-FIXNUM-POW)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T) MAXIMA::RISPLIT-EXPT-GENERAL-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RISPLIT-EXPT-REAL^RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::RISPLIT-EXPT-SQRT-POW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISPLIT-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISPLIT-NOUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISPLIT-SN-CN-DN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RISPLIT-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM T) T) MAXIMA::RITEDIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RJFSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::RL-REDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RLESSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RMCONST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ROOT+ANYTHING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROOT-2Z/PI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROOT-BOUND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ROOTADDUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROOTFAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROOTSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ROOTSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROUND1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROUNDRHS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ROUNDROOTS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RPLUS*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RPOLY-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RPOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RPOWERSET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RPTROUBLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RREDUCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RREMAINDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RT-SEPAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RTC-DIVIDE-BY-GCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RTC-FIXITUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RTC-GETINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RTCON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::RTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RTZERL2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::RULE-APPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RULECHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RULEOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::RUN-TESTSUITE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::RZCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::S+C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SAFE-ASSOC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SAFE-GET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SAFE-MGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SAFE-MGETL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SAME-SHEET-SUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SANDMAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SAV&DEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::SAVE-LINENUMBERS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SAVEFACTOR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SAVEFACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::SBSTPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SC-CONVERG-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SCALAR-MATRIX-PRODUCTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SCALAR-OR-CONSTANT-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SCALARCLASS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SCALARCLASS-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SCALE-SL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) *) MAXIMA::SCAN-DIGITS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SCAN-KEYWORD-TOKEN)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SCAN-LISP-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SCAN-LISP-TOKEN)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SCAN-MACSYMA-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SCAN-MACSYMA-TOKEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SCAN-NUMBER-AFTER-DOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SCAN-NUMBER-BEFORE-DOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SCAN-NUMBER-EXPONENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SCAN-NUMBER-REST)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) MAXIMA::SCAN-ONE-TOKEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SCAN-ONE-TOKEN-G)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::SCAN-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SCAN-TOKEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::SCANMAP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SCAXN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SCE-INT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SCEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SCH-LOOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SCH-REPLACE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SCHATCHEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SCMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SCONVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SCPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SCRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SCS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::SC^N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SDIFFGRAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SDIFFMAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SDIFFTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SELECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SEMANT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SEMANTICS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SEND-GNUPLOT-COMMAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SENDEXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SEPARC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SER0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SER1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SERIESEXPAND*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SERIESPASS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SET-DISJOINTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SET-ENV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SET-FULL-LINEINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SET-INTERSECT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SET-LBP-AND-RBP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SET-LINEINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SET-MEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SET-MODULUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SET-NOT-EQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SET-PARTITIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SET-READTABLE-FOR-MACSYMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SET-SUBSETP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SET-SYMMETRIC-DIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SET-UNION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SET-UP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SET-UP-CURSOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SETARG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::SETUP-CLIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SETUP-MULTIVAR-DISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SEVN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SFORX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SHEUR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SHEUR0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SHEUR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SHOW-BREAK-POINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SHOW-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SHOW-OPEN-PLOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIDE-EFFECT-FREE-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-ANY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::SIGN-GJC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-MABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-MEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIGN-MINMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-MTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIGN-ODDINC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-POSFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-PREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN-SHIFT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN01)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIGNAL-MODE-ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGNDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIGNDIFF-MINMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIGNDIFF-SPECIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIGNDIS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::SIGNDIS2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SIGNDIS3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIGNDISCR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIGNFACTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIGNNP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIGNSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::SIGNUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::SIGNUM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-$ELLIPTIC_E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-$ELLIPTIC_EU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-$ELLIPTIC_F)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-$ELLIPTIC_PI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-$IS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ACOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ACOSH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ACOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ACOTH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ACSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ACSCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%AIRY_AI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%AIRY_BI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%AIRY_DAI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%AIRY_DBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ASEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ASECH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ASIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ASINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%AT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%COS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%COSH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%COT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%COTH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%CSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%CSCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ELLIPTIC_EC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%ELLIPTIC_KC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_CD)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_CN)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_CS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_DC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_DN)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_DS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_NC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_ND)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_NS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_SC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_SD)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_SN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%JACOBI_AM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_CD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_CN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_CS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_DC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_DN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_DS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_NC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_ND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_NS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_SC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_SD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%JACOBI_SN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%SEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%SECH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%SIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%SINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%TAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-%TANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-BELLN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-BESSEL-I)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-BESSEL-J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-BESSEL-K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-BESSEL-Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-BETA-INCOMPLETE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            MAXIMA::SIMP-BETA-INCOMPLETE-GENERALIZED)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            MAXIMA::SIMP-BETA-INCOMPLETE-REGULARIZED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-CABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-CARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-CEILING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-CHARFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-CONJUGATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-DIVISORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::SIMP-DOMAIN-ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-DOUBLE-FACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-ERF-GENERALIZED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-ERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-ERFI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-EXPINTEGRAL-CHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXPINTEGRAL-CI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXPINTEGRAL-E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXPINTEGRAL-EI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXPINTEGRAL-LI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXPINTEGRAL-SHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXPINTEGRAL-SI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-EXPINTEGRAL_E1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-FLOOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-FRESNEL-C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-FRESNEL-S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-GAMMA-INCOMPLETE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            MAXIMA::SIMP-GAMMA-INCOMPLETE-GENERALIZED)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *)
-            MAXIMA::SIMP-GAMMA-INCOMPLETE-REGULARIZED)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-GENERALIZED-LAMBERTW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-HANKEL-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-HANKEL-2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-IMAGPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-INVERSE-ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-INVERSE-ERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-KRON-DELTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-LAMBERTW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-LIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-LOG-GAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-MAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-MAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-MIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-MNOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-MOEBIUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-MOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-NUMMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-REALPART)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMP-ROOTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-ROUND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMP-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-SQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-STIRLING1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-STIRLING2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-STRUVE-H)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-STRUVE-L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-TRUNCATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-ZETA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SIMP2>F<2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMP2F1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPAB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPARGS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPATAN2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPBERN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPBETA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPBINOCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPBUILDQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPDERIV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPDTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPEULER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPG-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPGAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPGFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPINF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPINF-EXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::SIMPINF-IC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPINF-PLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPINF-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPINTEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPKTF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPLAMBDA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLE-EQUAL-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLE-TRIG-ARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLERD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLEXPON)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPLIFY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLIFY-LOG-OF-EXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPLIFYA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM$LI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPLIM$MAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPLIM$MIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM$PSI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPLIM%ACOSH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%AIRY_AI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%AIRY_BI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%AIRY_DAI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%AIRY_DBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPLIM%ASIN-%ACOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPLIM%ASINH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLIM%ATAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPLIM%ATAN2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPLIM%ATANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%BESSEL_I)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%BESSEL_J)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%BESSEL_K)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%BESSEL_Y)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%ELLIPTIC_KC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPLIM%ERF-%TANH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%ERFC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%ERFI)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%ERF_GENERALIZED)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_CHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_CI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_E)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_E1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_EI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_LI)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_SHI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%EXPINTEGRAL_SI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPLIM%FRESNEL_C)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPLIM%FRESNEL_S)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%GAMMA_INCOMPLETE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%INVERSE_ERF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%INVERSE_ERFC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLIM%INVERSE_JACOBI_CS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLIM%INVERSE_JACOBI_DC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLIM%INVERSE_JACOBI_DS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLIM%INVERSE_JACOBI_NC)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLIM%INVERSE_JACOBI_NS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLIM%INVERSE_JACOBI_SC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%SIGNUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLIM%TAN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIM%ZETA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SIMPLIMEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIMFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIMLN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLIMPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPLIMPLUS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLIMSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPLIMSCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPLIMSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPLIMTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPLN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPLN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPMAP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPMATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPMDEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPMDEFMACRO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPMIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPMQAPPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPNCEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPNCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SIMPNCT-ALIKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPNCT-ANTISYM-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPNCT-ASSUMESCALARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPNCT-BASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPNCT-CONSTANTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SIMPNCT-INVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPNCT-MERGE-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPNCT-MERGE-PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPNCT-ONEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPNCT-POWER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPNCT-SC-OR-CONST-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPNRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIMPNRT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPPLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SIMPPROD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SIMPPROD1-SAVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPQUOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPR2F1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMPSIGNUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SIMPSUM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SIMPSUM1-SAVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SIMPSUM2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SIMPTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIN%)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SIN-COS-INTSUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIN-COS-INTSUBS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SIN-SQ-COS-SQ-SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::SIN/COS-PLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::SIN/COS-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SINBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SINCOSHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SINDIF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM FIXNUM) T) MAXIMA::SINGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SINH^N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SININT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SININT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SININTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SINNX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SINRX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SINSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SIN^N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SKR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SLASH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SLOMMELTJANDY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::SLOW-OSCILLATION-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SMINMAX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SMONO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SMONOGEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SMONOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::SMOOTH-ENOUGH-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SNUMDEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SOLCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::SOLVABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SOLVE-A*F<X>^N+B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SOLVE-A*F<X>^N+B1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SOLVE-BY-DECOMPOSITION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVE-SIMPLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SOLVE1A)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SOLVE3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVECASE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVECUBIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVELIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SOLVENTH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVENTH1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SOLVENTH3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SOLVENTHP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVEQUAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVEQUARTIC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SOLVEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOME-BFLOATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SOME-FLOATP)) 
+(PROCLAIM '(FTYPE (FUNCTION (T T T INTEGER) T) INTL:DNGETTEXT)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION
-                ((ARRAY LONG-FLOAT) (ARRAY UNSIGNED-SHORT) FIXNUM) T)
-            MAXIMA::SORT-NGONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SORT-POLES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SORTED-REMOVE-DUPLICATES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SORTGREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP1ADD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SP1ADDBUC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SP1ADDTO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SP1ATRIG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SP1ATRIG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SP1EXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP1EXPT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SP1GREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP1KGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP1LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP1LOG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SP1PUTBUC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SP1PUTBUC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SP1SINCOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SP1SINCOS1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SP1SINCOS2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SP1SINTCOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP1TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SP1TLIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SP1TPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP1TRIG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP1TRIGEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP1UNTREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SP2DIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SP2DIFF1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SP2DIFF2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP2EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP2EXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SP2INTEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SP2INTEG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SP2INTEG12)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SP2INTEG13)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SP2INTEG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP2LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SP2SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP2TRIG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SP3FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP3FORM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SP3RECONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SP3SUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SP3SUBSTP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::SP3SUBSTPN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPABS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SPANG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SPANGSIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::SPARSE-LIFT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::SPC0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPC1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPC2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPC2A)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPC2B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SPC3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPC4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SPC5)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SPC5B)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPC7)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SPDERIVATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SPDERIVATIVE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SPECDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SPECIAL-CONVERGENT-FORMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPECIALP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SPECREPCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPECREPP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SPEXP)) 
+    '(FTYPE (FUNCTION (T T T T T T T T T) T) MAXIMA::ADAPTIVE-PLOT
+            MAXIMA::DRATIO)) 
 (PROCLAIM '(FTYPE (FUNCTION (STRING T *) T) MAXIMA::SPLIT-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPLIT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SPLITPFQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPLITPROD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPLITSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::SPRDET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SPRECIP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SPSIMPCASES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SQ-SUMSQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SQCONT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SQDTC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SQFRNORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SQFRP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SQRT1+X^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SQRT1-X^2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SQRTINVOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SQRTX^2-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SRATEXPND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SRATP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SRATSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SRATSUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SRBINEXPND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SRCONVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SRCONVERT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SRDIS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SRDISREP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SRF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SRINTEGEXPD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SRRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SRRAT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SRRAT3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SSET-DIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SSOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SSSQFR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STARDISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::START-CLIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::START-GNUPLOT-PROCESS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::STEP-7-MM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::STEP-7-MP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::STEP-7-PM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::STEP-7-PP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::STEP-INTO)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::STEP-NEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::STEP4)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::STEP4-A)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::STEP4-INT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::STEP7)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::STEP7-CORE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL FIXNUM) MAXIMA::STERPRI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::STF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::STIMEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::STIRLING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::STIRLING0)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::STOP-GNUPLOT-PROCESS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T FIXNUM) T) MAXIMA::STORA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STOTALDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::STRCAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRGRIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::STRICTLY-IN-INTERVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRING*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRING*1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STRING1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STRING<$)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRIP-LINEINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRIP-LINEINFO-OP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STRIP-ZEROES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRIPDOLLAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRIPTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRMDO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRMDOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::STRMEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STRONGER-DATUM?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STRONGER-VAR?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::STRONGER-VARS?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STRONGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRPRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STRSYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STURM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STURM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::STURMAPC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STURMOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::STURMSEQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::STYO)) 
-(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) T) MAXIMA::STYOTBSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SUB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SUB*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUB-PRINT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SUBARGCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUBC-INTERNAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBEXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBEXPRESSION-MATCHES-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUBFUNARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SUBFUNMAKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SUBFUNMAKES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUBFUNNAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUBFUNSUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUBGEN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SUBIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBLISS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBRESGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBRESULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SUBSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SUBSCS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBSETL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBST-DIFF-MATCH)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::SUBST-EXCEPT-SECOND-ARG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SUBST-IF-NOT-FREEOF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBST0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SUBST1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUBST10)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::SUBST2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUBST2S)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SUBSTFORSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SUBSTINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SUBSTINT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SUBSTITUTEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::SUBSTL)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SUBSTPART-TRANSLATION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SUBSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SUBVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUBVARDLG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUM-C*LOGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUM-OF-INTSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::SUM-VAR-SETS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUMCOEF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUMCOMBINE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUMCOMBINE2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SUMCONSIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUMCONTRACT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUMCONTRACT2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUMI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::SUMPLS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::SUMSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SUMTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::SUMULTIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUPC-INTERNAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SUPERCOSNX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SUPERSINX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SUPERTRIG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::SUSUM1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SWAP-ROWS)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) (VALUES T T)) MAXIMA::SYMBOLCONC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SYMBOLIC-EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::SYMBOLS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::SYNTACTIC-SUBSTITUTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAGIRR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TAKE-PRINCIPAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TAN-PLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::TAN-TIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TANBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TANSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TANSC1)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::TAY-DEPTH-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TAY-ERROR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TAY-EXPONENTIALIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAY-ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAYAPPROX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAYCHK2RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::TAYLIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TAYLOR*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAYLOR-INFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAYLOR-TRUNC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TAYLOR1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAYLOR2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAYLOR3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TAYLORIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TAYLOR_SIMPLIFIER_CALLER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TAYLOR_SIMPLIFY_RECURSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM) T) MAXIMA::TB2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TBF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TBIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TBOUND-FREE-VARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TBOUNDP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TC-STATE-MULTIPLY-TABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) INTEGER) MAXIMA::TC-STATE-NCOSETS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) INTEGER) MAXIMA::TC-STATE-NVARS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TC-STATE-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TC-STATE-RELATIONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TC-STATE-ROW1-RELATIONS)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) T) MAXIMA::TC-STATE-SUBGROUP-GENERATORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TCHEBYPOL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TCL-OUTPUT-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TCONS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TCONS3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::TDBU)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TDNEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TDPN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TDPOS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TDPZ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TDZERO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TELLRAT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TELLRATDISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TERM*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TERM-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::TERPRI*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) *) MAXIMA::TEST-BATCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::TEST-INVERSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TESTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TESTA*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TESTDIVIDE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TESTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TESTT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TESTTNEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::TEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-ARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-AT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-ATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-BIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-CHAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-CHOOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-CUBRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TEX-D)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-DABBREV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-DERIVATIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TEX-FORMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TEX-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-GAMMA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-INFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-INT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-KRON-DELTA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-LBP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-LIMIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TEX-LIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-LSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MATCHFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MATRIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MBOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MCOND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MDO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MDOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-MLABEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MLABOX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-MPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MQAPPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MQUOTIENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-MTEXT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-NARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-NOFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-PAREN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-POSTFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-PREFIX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-RAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-RBP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-SETUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-SPACEOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TEX-SQRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-STRING)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-STRIPDOLLAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-STRIPDOLLAR0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TEX-SUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEX-TRY-SYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::TEX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEXMDO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEXMDOIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEXNUMFORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEXSYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TEXWORD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TFGELI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TFGELI0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TFGELI1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::THNO33)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::THNO34)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::THNO35)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::THRAD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::THREAD)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::THROW-MACSYMA-TOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TIMEORG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TIMER-HANDLER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TIMER-MLIST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TIMESBIGFLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TIMESIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TIMESK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TIMESKL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TIMESLOOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TIMESROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TIMESTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TIMEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TIMEX0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TIMEX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TLIMP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TLIST-MERGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TM$KILL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMACCESS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMCOMBI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMDEFARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMDET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMERGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TMEXCHANGE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMFACTORIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::TMINITIALFLAG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::TMINOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMKILL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMKILLARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TMLATTICE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMLATTICE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TMLIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMMAXP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T) T) MAXIMA::TMMOVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TMNOMOREUSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMPATHP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T) T) MAXIMA::TMPERMUTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMPIVOT-ISOLATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TMRATCONV)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMREARRAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TMS-FORMAT-PRODUCT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMSORT-LATTICE)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::TMSORT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMSTORE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMSYMETRICP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TMUNIFY-LOOP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::TMUNPIVOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TODD-COXETER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TOPLEVEL-MACSYMA-EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TOPLEVEL-OPTIMIZE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TOPLEVEL-OPTIMIZE-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TOTAL-NARY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TOTAL-SIGN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TOTIENT-BY-FS-N)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TOTIENT-FROM-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TOTIENT-WITH-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-ARGS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-ARRAYCALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TR-ARRAYSETQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-CLASS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TR-DECLARE-VARMODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-EXP-TO-DISPLAY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::TR-FORMAT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::TR-GENSYM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-INFAMOUS-NOUN-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::TR-LAMBDA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TR-LISP->LISP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-LISP->LISP-DEFAULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-LISP->LISP-FUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TR-LISP-FUNCTION-CALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::TR-LOCAL-EXP)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T) T) MAXIMA::TR-MACSYMA-USER-FUNCTION-CALL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TR-MAREF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TR-MASET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TR-MDEFINE-TOPLEVEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TR-MFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TR-MPROG-BODY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::TR-NARGS-CHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-NOSIMPP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-SEQ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TR-WARNP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRACE-APPLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRACE-ENTER-BREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TRACE-ENTER-PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRACE-ERROR-BREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRACE-EXIT-BREAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TRACE-EXIT-PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRACE-FSHADOW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRACE-FSYMEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRACE-HANDLER)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::TRACE-MPRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRACE-OPTION-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRACE-PRINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRACE-UNFSHADOW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRACEMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRACEMOD0)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRACEMOD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRANSFORM-TVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSLATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSLATE-$MAX-$MIN)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) *)
-            MAXIMA::TRANSLATE-AND-EVAL-MACSYMA-EXPRESSION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSLATE-ATOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSLATE-ATOMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T *) T) MAXIMA::TRANSLATE-FILE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TRANSLATE-FORM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TRANSLATE-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSLATE-MACEXPR-TOPLEVEL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSLATE-PREDICATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSLATOR-EVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRANSPOSE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TRANSPOSE-ELS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRD-MSYMEVAL-AUX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRDISP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TREEDET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRFAIL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIANG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) MAXIMA::TRIANG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIG-3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TRIG-CONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIG-LOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIG-LOG-1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRIG-LOG-1-NEG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIG-LOG-1-POS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIG-LOG-3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIG-LOG-3-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRIG-LOG-3A-EXEC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIG-NOT-SUBST-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRIG-RIGHT-PLACEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRIG-SIN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRIG-SUBST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIG-SUBST-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIG1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIG2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIGEXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIGFP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIGFREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIGIN1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRIGINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRIGP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TRIGRED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TRIMF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::TRISPLIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TRIVIAL1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-$EQUAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MEQUAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MGEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MGREATERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MLEQP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MLESSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MNOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MNOTEQUAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-MOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRP-NOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRUE*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRUEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::TRUFAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRUNC-VECT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRUNC-VECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::TRY-DEFINT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TRY-EXPANSION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TRY-FLOAT-COMPUTATION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRY-INTSC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TRY-INTSUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TRY-LHOSPITAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::TRY-LHOSPITAL-QUIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRYRISCH)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TRYRISCH1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TS-FORMULA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSBASE-COMB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TSDIFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSEXP-COMB)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TSEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSEXPT-RED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TSEXPT1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::TSPRSUM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSTACK-SLOT-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSTACK-SLOT-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSTACK-SLOT-SPECIAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSTACK-SLOT-TBIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSTACK-SLOT-VAL-MODES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TSTIMES-GET-PW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TSTIMES-L-MULT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::TTPJAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TUNBIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TUNBINDS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TVAR-LIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TVAR?)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TWOARGCHECK)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MAXIMA::TYI)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::TYI*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::TYI-PARSE-INT)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::TYI-RAW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::TYOTBSP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UCONTENT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UDM-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UFACT-STRIP-ZEROES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNDEFINE-SYMBOL)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::UNFAM-SING-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::UNI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::UNION*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNION-VAR-SET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::UNION1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNIPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::UNITCIR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNIVAR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::UNKIND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNKNOWN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNKNOWN-ATOMS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNMRK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNMRKS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNPARSE-TYI)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNQUOTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::UNRAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNTRANS-OP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNTREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNTREE1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UNTRUE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::UPDATE-HEIGHTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::UPOLY+)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UPPERHALF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UPRIMITIVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::UPS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::USE-RADCAN-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::USED-AREA)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::USOLVE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::UTPJAC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VALUE-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::VAR-EXPAND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VAR-OR-CONST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VARIABLE-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::VARINVERT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VARP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VARSORT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VFVP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::VGREAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VISIBLEP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::VMAKE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::VRSHFT-SL)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T (VECTOR T)) T) MAXIMA::WALK-GET-LINEINFO)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) *) MAXIMA::WARN-FEXPR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::WARN-MEVAL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) *) MAXIMA::WARN-MODE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MAXIMA::WARN-UNDECLARED)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::WARN-UNDEFINED-VARIABLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::WHICHFN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::WHITFUN)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::WHITTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::WHITTINDTEST)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::WHOLE-INTSUBS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::WLINEARPOLY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::WNA-ERR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::WRAP-AN-IS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::WTM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::WTPCTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::WTPCTIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::WTPEXPT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::WTPTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::WTPTIMES1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::WTPTIMES2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::WTPTIMES3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::WWHIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::X$-CL-MACRO-READ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::X**Q)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM T) T) MAXIMA::X**Q1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::XAPPEND)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::XCHDIR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::XEXPONGET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::XMAXIMA-COLOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::XMAXIMA-CURVE-STYLE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::XMAXIMA-PALETTE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::XMAXIMA-PALETTES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::XMAXIMA-PRINT-HEADER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::XOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::XPTIMES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::XRUTOUT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::XTORTERM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::YTJ)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::YUK-SU-META-PROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::Z-FUNCTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::Z1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::Z2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ZASSG)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ZEPOW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZERO-LIM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZERO-PRODUCTP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZEROCOEFL)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZEROEQUIV1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZEROEQUIV2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZEROHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZEROLP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZEROP-IN-L)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ZEROP/ROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZEROP1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZEROP2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZERORES)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZERP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ZFACT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZFACTSPLIT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ZFF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZFREE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZGCD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) T) MAXIMA::ZGCD-LIFT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::ZGCD-LIFT*)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZGCD1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZIREDUP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZL-GET)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZL-INTERSECTION)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZL-REMPROP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) *) MAXIMA::ZMTORAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZN-CHARACTERISTIC-FACTORS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZN-DISTRIB-LISTS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T) T) MAXIMA::ZN-DLOG)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::ZN-GCDEX)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZN-GCDEX1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) MAXIMA::ZN-NRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ZN-P-ERRCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZN-PE>)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) T) MAXIMA::ZN-PRIMROOT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ZN-PRIMROOT-P)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZN-SHANKS-PHI-STEP-BC)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZN-TABLE-ERRCHK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ZN_ORDER)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::ZP)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::ZPDEGREEVECTOR)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ZQ-AMM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T) T) MAXIMA::ZQ-NRT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM FIXNUM) T) MAXIMA::ZROW)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::ZS-INTIR3)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ZTO%PI2)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) *) MAXIMA::ZTO1)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::ZTOINF)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T T) *) MAXIMA::ZTORAT)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MAXIMA::[MAX-TRUNC])) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) *) MAXIMA::|''MAKE-FUN|)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T T T T) *)
-            MAXIMA::|(PCL::FAST-METHOD PRINT-OBJECT (MAXIMA-$ERROR T))|)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MAXIMA::|/#ALIKE|)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MAXIMA::|:SPREAD|)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::|__si::MAKE-POLYGON|)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MAXIMA::|__si::MAKE-RI|)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MT19937:%RANDOM-DOUBLE-FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) MT19937:%RANDOM-SINGLE-FLOAT)) 
-(PROCLAIM '(FTYPE (FUNCTION (INTEGER T) T) MT19937::%RANDOM-INTEGER)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL T) MT19937::GENERATE-SEED)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MT19937::INT-INIT-RANDOM-STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MT19937::MAKE-RANDOM-OBJECT)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION ((VECTOR T)) *) MT19937::RANDOM-MT19937-UPDATE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (T) (SIMPLE-ARRAY (UNSIGNED-BYTE 32) (627)))
-            MT19937::RANDOM-STATE-STATE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION ((VECTOR T) *) T) MT19937::VEC-INIT-RANDOM-STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) T) MT19937:INIT-RANDOM-STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (*) *) MT19937:MAKE-RANDOM-STATE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T *) T) MT19937:RANDOM)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MT19937:RANDOM-CHUNK)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) MT19937:RANDOM-STATE-P)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT FIXNUM) *) SLATEC::D9UPAK)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT) *) SLATEC::DEI)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT) *) SLATEC::DGAMLM)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (FIXNUM (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                        (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM)
-                *)
-            SLATEC::DGTSL)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
-                   FIXNUM LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR FIXNUM) FIXNUM)
-                *)
-            SLATEC::DQAGE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (T LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT FIXNUM
-                   LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR FIXNUM) FIXNUM)
-                *)
-            SLATEC::DQAGIE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT FIXNUM (VECTOR LONG-FLOAT)
-                   LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT
-                   FIXNUM FIXNUM (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR FIXNUM) (VECTOR FIXNUM) (VECTOR FIXNUM)
-                   FIXNUM)
-                *)
-            SLATEC::DQAGPE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
-                   LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR FIXNUM) FIXNUM)
-                *)
-            SLATEC::DQAGSE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
-                   LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT FIXNUM
-                   FIXNUM (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR FIXNUM) FIXNUM)
-                *)
-            SLATEC::DQAWCE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT
-                   LONG-FLOAT FIXNUM FIXNUM FIXNUM LONG-FLOAT
-                   LONG-FLOAT FIXNUM FIXNUM FIXNUM (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR FIXNUM) (VECTOR FIXNUM)
-                   FIXNUM (VECTOR LONG-FLOAT))
-                *)
-            SLATEC::DQAWOE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
-                   LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT
-                   FIXNUM FIXNUM (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                   (VECTOR LONG-FLOAT) (VECTOR FIXNUM) FIXNUM)
-                *)
-            SLATEC::DQAWSE)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                ((VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                 (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT))
-                *)
-            SLATEC::DQCHEB)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (FIXNUM (VECTOR LONG-FLOAT) LONG-FLOAT LONG-FLOAT
-                        (VECTOR LONG-FLOAT) FIXNUM)
-                *)
-            SLATEC::DQELG)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT (VECTOR LONG-FLOAT)
-                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
-                    (VECTOR LONG-FLOAT) FIXNUM)
-                *)
-            SLATEC::DQMOMO)) 
+(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM *) *) MAXIMA::OPEN-SOCKET)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION
-                (FIXNUM FIXNUM FIXNUM LONG-FLOAT (VECTOR LONG-FLOAT)
-                        (VECTOR FIXNUM) FIXNUM)
-                *)
-            SLATEC::DQPSRT)) 
+    '(FTYPE (FUNCTION (T T T) *) MAXIMA::SIMP-%INVERSE_JACOBI_DC
+            MAXIMA::THNO35
+            BIGFLOAT::|(PCL::FAST-METHOD CIS (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD SIGNUM (BIGFLOAT))|
+            MAXIMA::SIMPLIMLN MAXIMA::LEGF16 MAXIMA::SIMPFACT
+            BIGFLOAT::|(PCL::FAST-METHOD RATIONALIZE (LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FFLOOR (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD MAXIMA::TO (BIGFLOAT))|
+            MAXIMA::SIMPEULER MAXIMA::RATCOEFF
+            MAXIMA::SIMP-%INVERSE_JACOBI_CN MAXIMA::COEFF
+            MAXIMA::TEX-GAMMA MAXIMA::SIMPBERN MAXIMA::LIMIT1
+            MAXIMA::SIMP-STRUVE-L
+            BIGFLOAT::|(PCL::FAST-METHOD ACOSH (BIGFLOAT))|
+            MAXIMA::SIMP-%ACOTH MAXIMA::SIMP-%ASINH
+            MAXIMA::HYPERTRIGINT1
+            BIGFLOAT::|(PCL::FAST-METHOD COSH (BIGFLOAT))|
+            MAXIMA::GEGENPOL
+            BIGFLOAT::|(PCL::FAST-METHOD ASIN (BIGFLOAT))|
+            MAXIMA::F2P105V2COND-SIMP MAXIMA::SIMPGAMMA
+            BIGFLOAT::|(PCL::FAST-METHOD SUB1 (BIGFLOAT))|
+            MAXIMA::SIMP-BESSEL-J MAXIMA::SAME-SHEET-SUBS
+            MAXIMA::SIMPBIGFLOAT MAXIMA::MSIZE-PREFIX
+            MAXIMA::SIMP-%JACOBI_DS MAXIMA::SIMPLIM%EXPINTEGRAL_CHI
+            MAXIMA::ERFRED MAXIMA::SIMPDERIV MAXIMA::SIMP-ERFI
+            MAXIMA::SIMP-%ELLIPTIC_EC MAXIMA::SIMP-CABS
+            MAXIMA::ERFGAMNUMRED MAXIMA::COEFFICIENT
+            MAXIMA::SIMPLIM%GAMMA_INCOMPLETE MAXIMA::SIMP-LOG-GAMMA
+            MAXIMA::SIMPLIM$PSI BIGFLOAT::BF-RD
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-DIVIDE (BIGFLOAT))|
+            MAXIMA::MSIZE-PAREN MAXIMA::LT-EXP MAXIMA::LEGF24
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-ATAN (COMPLEX-BIGFLOAT))|
+            MAXIMA::$POWERSERIES
+            BIGFLOAT::|(PCL::FAST-METHOD RATIONALIZE (LISP:FLOAT))|
+            MAXIMA::SIMPLIM%EXPINTEGRAL_SI MAXIMA::TRY-LHOSPITAL-QUIT
+            MAXIMA::SIMP-%ATAN
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-MINUS (BIGFLOAT))|
+            MAXIMA::LEGF36
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-MINUS (COMPLEX-BIGFLOAT))|
+            MAXIMA::SIMPEXPT MAXIMA::SIMP-%COT
+            MAXIMA::SIMP-%INVERSE_JACOBI_NS MAXIMA::SIMPLIM%BESSEL_Y
+            MAXIMA::SIMP-BETA-INCOMPLETE-GENERALIZED
+            MAXIMA::$BETA_INCOMPLETE MAXIMA::SIMP-HANKEL-2
+            MAXIMA::SIMP-%JACOBI_DN MAXIMA::MUL3
+            MAXIMA::SIMP-%JACOBI_CN MAXIMA::SIMP-%JACOBI_NS
+            MAXIMA::WHOLE-INTSUBS
+            BIGFLOAT::|(PCL::FAST-METHOD ABS (BIGFLOAT))|
+            MAXIMA::E3PROG MAXIMA::SINCOSHK
+            MAXIMA::SIMP-%INVERSE_JACOBI_ND
+            BIGFLOAT::|(PCL::FAST-METHOD ACOS (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD EXP (BIGFLOAT))|
+            MAXIMA::F29P146 MAXIMA::SIMP-BESSEL-Y
+            MAXIMA::MARRAYREF-GENSUB MAXIMA::SIMPLIM%EXPINTEGRAL_SHI
+            MAXIMA::SIMP-GAMMA-INCOMPLETE-REGULARIZED
+            MAXIMA::GF-MINPOLY MAXIMA::$LAPLACE
+            MAXIMA::SIMP-$ELLIPTIC_PI MAXIMA::SIMP-%ASEC
+            MAXIMA::$GAMMA_INCOMPLETE_GENERALIZED MAXIMA::$ELLIPTIC_PI
+            MAXIMA::TRIG-CONST MAXIMA::SIMPLIM%ERFC
+            MAXIMA::SIMPLIM%AIRY_DAI MAXIMA::LHOSPITAL-CATCH
+            MAXIMA::LIMIT-SUBS MAXIMA::STEP7-CORE MAXIMA::HGFSIMP
+            MAXIMA::$CARLSON_RF MAXIMA::ARRFUNCALL MAXIMA::SIMPLIM$LI
+            MAXIMA::SIMP-%ACOSH MAXIMA::SP2INTEG
+            MAXIMA::SIMP-%INVERSE_JACOBI_SN
+            BIGFLOAT::|(PCL::FAST-METHOD RATIONALIZE (BIGFLOAT))|
+            MAXIMA::COEFSOLVE MAXIMA::SIMP-STIRLING2
+            MAXIMA::SIMP-FRESNEL-C MAXIMA::SUBSC
+            MAXIMA::SIMP-%JACOBI_SN
+            BIGFLOAT::|(PCL::FAST-METHOD SINH (BIGFLOAT))|
+            MAXIMA::SIMPLIM%EXPINTEGRAL_CI MAXIMA::TEX-DERIVATIVE
+            MAXIMA::SIMP-%JACOBI_DC MAXIMA::REFLECT0
+            MAXIMA::SIMPLIM%AIRY_DBI MAXIMA::LT1HSTRUVE
+            MAXIMA::MSIZE-MLABEL MAXIMA::SIMPLN MAXIMA::TEX-INFIX
+            MAXIMA::SIMP-IMAGPART MAXIMA::SIMP-BESSEL-I
+            MAXIMA::TAN-PLUS
+            BIGFLOAT::|(PCL::FAST-METHOD ATANH (BIGFLOAT))|
+            MAXIMA::COT-PLUS MAXIMA::THNO33 MAXIMA::SIMP-NUMMOD
+            MAXIMA::SIMP-BETA-INCOMPLETE MAXIMA::SIMPLIM%EXPINTEGRAL_EI
+            MAXIMA::2F1POLYS MAXIMA::SIMP-%ELLIPTIC_KC
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-LOG (BIGFLOAT))|
+            MAXIMA::SIMP-EXPINTEGRAL-SI MAXIMA::BYDIF MAXIMA::SIMP-%SEC
+            MAXIMA::GAMMAREDS MAXIMA::SIMP-%INVERSE_JACOBI_DS
+            MAXIMA::SIMPNCT INTL::READ-NESTED-COMMENT
+            MAXIMA::SIMP-EXPINTEGRAL-CI MAXIMA::COLEXPT
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-DIVIDE (COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD REALPART (BIGFLOAT))|
+            MAXIMA::ARCHK MAXIMA::SIMP-INVERSE-ERF MAXIMA::SP1SINTCOS
+            MAXIMA::SIMP-%COTH MAXIMA::SIMP-EXPINTEGRAL-SHI
+            MAXIMA::SIMPLIM%BESSEL_J MAXIMA::SIMPLIM%EXPINTEGRAL_E1
+            MAXIMA::XMAXIMA-CURVE-STYLE MAXIMA::LEGF20
+            BIGFLOAT::|(PCL::FAST-METHOD PHASE (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FTRUNCATE (BIGFLOAT))|
+            MAXIMA::LEGF14 MAXIMA::SIMP-MOEBIUS MAXIMA::SIMP-ERFC
+            MAXIMA::TRACE-EXIT-PRINT MAXIMA::LHOSPITAL MAXIMA::HACKIT
+            MAXIMA::LAGPOL MAXIMA::SIMPLIM%BESSEL_I MAXIMA::SIMPPLOG
+            MAXIMA::SIMPLIM%ERF_GENERALIZED
+            MAXIMA::SIMP-%INVERSE_JACOBI_SC
+            BIGFLOAT::|(PCL::FAST-METHOD SQRT (COMPLEX-BIGFLOAT))|
+            MAXIMA::EXPAND1 MAXIMA::SIMPLIM%AIRY_BI
+            MAXIMA::SIMP-ERF-GENERALIZED MAXIMA::SIMP-$ELLIPTIC_E
+            MAXIMA::SUBSCS MAXIMA::SIMP-%JACOBI_SD MAXIMA::LAPDELTA
+            MAXIMA::SIMP-STIRLING1 MAXIMA::FPOLYSUM MAXIMA::MONSTERTRIG
+            BIGFLOAT::|(PCL::FAST-METHOD ASINH (BIGFLOAT))|
+            MAXIMA::EXPFACTOR MAXIMA::SIMP-%ACOS MAXIMA::SIMPNCEXPT
+            MAXIMA::TEX-MPLUS MAXIMA::APPLY1 MAXIMA::SIMPLIMSC
+            MAXIMA::LOG*RAT MAXIMA::LOGCPJ MAXIMA::SIMP-%JACOBI_CD
+            MAXIMA::SIMPLIM%ERFI MAXIMA::MSZ-MPLUS MAXIMA::SUBSTINT
+            MAXIMA::HYP-ATANH MAXIMA::LT1GAMMAGREEK
+            MAXIMA::OUTER-CONSTANT
+            BIGFLOAT::|(PCL::FAST-METHOD SIN (BIGFLOAT))|
+            MAXIMA::INTSC0 MAXIMA::SIMPBINOCOEF MAXIMA::LT1J^2
+            MAXIMA::SIMP-%JACOBI_SC MAXIMA::INTSUBS
+            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (LISP:COMPLEX))|
+            BIGFLOAT::|(PCL::FAST-METHOD DECODE-FLOAT (BIGFLOAT))|
+            MAXIMA::LEGPOL MAXIMA::F29P146TEST MAXIMA::$RESIDUE
+            BIGFLOAT::BF-RG MAXIMA::ERFGAMMARED MAXIMA::SIMP-SQRT
+            BIGFLOAT::|(PCL::FAST-METHOD SIGNUM (COMPLEX-BIGFLOAT))|
+            MAXIMA::LEGFUN MAXIMA::SIMP-$ELLIPTIC_F
+            MAXIMA::SIMP-STRUVE-H MAXIMA::SIMPLIM%AIRY_AI
+            MAXIMA::SIMPLIM%ZETA MAXIMA::SIMP-%INVERSE_JACOBI_CD
+            MAXIMA::TEX-PAREN MAXIMA::SIMP-TRUNCATE MAXIMA::THNO34
+            MAXIMA::F35P147TEST MAXIMA::SUBSTL MAXIMA::DESJY
+            MAXIMA::SIMP-%SECH MAXIMA::SIMPABS MAXIMA::SIMP-EXP
+            BIGFLOAT::|(PCL::FAST-METHOD COS (BIGFLOAT))|
+            MAXIMA::TEX-PREFIX MAXIMA::ZTORAT MAXIMA::HTJORY
+            MAXIMA::SIMP-MNOT MAXIMA::SIMP-BELLN
+            MAXIMA::SIMP-GAMMA-INCOMPLETE MAXIMA::SIMP-%ASIN
+            BIGFLOAT::|(PCL::FAST-METHOD ADD1 (BIGFLOAT))|
+            MAXIMA::CTPJAC BIGFLOAT::BF-RF MAXIMA::EEZZ MAXIMA::STEP7
+            MAXIMA::TEX-SQRT
+            BIGFLOAT::|(PCL::FAST-METHOD UNARY-FCEILING (BIGFLOAT))|
+            MAXIMA::SIMP-%COSH
+            BIGFLOAT::|(PCL::FAST-METHOD INTEGER-DECODE-FLOAT (BIGFLOAT))|
+            MAXIMA::IS-MNOT_TR MAXIMA::SIMP-EXPINTEGRAL-E
+            MAXIMA::SIMP-%INVERSE_JACOBI_SD MAXIMA::EASY-SUBS
+            MAXIMA::FMAP1 MAXIMA::SIMPBETA MAXIMA::SIMP-%CSC
+            MAXIMA::SIMP-%JACOBI_CS MAXIMA::LTW MAXIMA::TIMESIN
+            BIGFLOAT::|(PCL::FAST-METHOD PHASE (COMPLEX-BIGFLOAT))|
+            MAXIMA::F24P146 MAXIMA::SIMP-ZETA MAXIMA::POISSUBSTCO
+            MAXIMA::SIMP-%INVERSE_JACOBI_CS MAXIMA::GF-EVAL
+            MAXIMA::SIMP-FRESNEL-S
+            BIGFLOAT::|(PCL::FAST-METHOD ABS (COMPLEX-BIGFLOAT))|
+            MAXIMA::SIMP-%INVERSE_JACOBI_DN
+            MAXIMA::SIMPLIM%EXPINTEGRAL_LI MAXIMA::GF-MATADD
+            MAXIMA::SIMP-%ACSCH MAXIMA::SIMPLIM%EXPINTEGRAL_E
+            MAXIMA::APPLY2 MAXIMA::SP2INTEG13
+            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (BIGFLOAT))|
+            MAXIMA::MSIZE-MMINUS
+            MAXIMA::SIMP-BETA-INCOMPLETE-REGULARIZED
+            MAXIMA::SIMP-CEILING MAXIMA::TRACE-ENTER-PRINT
+            MAXIMA::SIMP-%JACOBI_ND MAXIMA::SIMP-%INVERSE_JACOBI_NC
+            MAXIMA::MAPPLY MAXIMA::SP3SUBSTP1 MAXIMA::SIMPSIGNUM
+            MAXIMA::MEVALP1_TR MAXIMA::SIMP-%ACOT
+            BIGFLOAT::|(PCL::FAST-METHOD SUB1 (COMPLEX-BIGFLOAT))|
+            MAXIMA::F50COND MAXIMA::SIMP-EXPINTEGRAL-EI MAXIMA::F35P147
+            BIGFLOAT::|(PCL::FAST-METHOD CONJUGATE (COMPLEX-BIGFLOAT))|
+            MAXIMA::THREAD MAXIMA::SIMPLIM%ELLIPTIC_KC
+            BIGFLOAT::|(PCL::FAST-METHOD SQRT (BIGFLOAT))|
+            MAXIMA::GF-MATMULT MAXIMA::RADLIM MAXIMA::SP2DIFF1
+            MAXIMA::SIMPLIMFACT
+            BIGFLOAT::|(PCL::FAST-METHOD ZEROP (BIGFLOAT))|
+            MAXIMA::LOGCPI
+            BIGFLOAT::|(PCL::FAST-METHOD TAN (BIGFLOAT))|
+            MAXIMA::SIMP-DIVISORS MAXIMA::SIMPQUOT MAXIMA::LT1J
+            MAXIMA::BETA-INCOMPLETE MAXIMA::%FIND-ROOT
+            MAXIMA::SIMP-FLOOR MAXIMA::POLYINX MAXIMA::SIMPMIN
+            MAXIMA::SIMP-LAMBERTW
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-COMPLEX (BIGFLOAT))|
+            MAXIMA::TEX-CUBRT
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-LOG (COMPLEX-BIGFLOAT))|
+            MAXIMA::MSIZE-NOFIX MAXIMA::TEX-MLABEL
+            BIGFLOAT::|(PCL::FAST-METHOD REALPART (COMPLEX-BIGFLOAT))|
+            MAXIMA::SIMPLIM%INVERSE_ERFC
+            MAXIMA::BETA-EXPAND-ADD-INTEGER
+            MAXIMA::SIMP-GAMMA-INCOMPLETE-GENERALIZED
+            MAXIMA::LEGPOL-CORE MAXIMA::SIMPMQAPPLY MAXIMA::INTI
+            MAXIMA::SCE-INT MAXIMA::SP3SUBST MAXIMA::F24P146TEST
+            MAXIMA::TEX-NOFIX MAXIMA::RECTZTO%PI2 MAXIMA::DERIVINT
+            MAXIMA::SIMP-MAX
+            BIGFLOAT::|(PCL::FAST-METHOD CONJUGATE (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD IMAGPART (COMPLEX-BIGFLOAT))|
+            MAXIMA::LAPINT MAXIMA::SIMPLIM%BESSEL_K MAXIMA::TEX-POSTFIX
+            MAXIMA::SIMPINTEG
+            BIGFLOAT::|(PCL::FAST-METHOD ADD1 (COMPLEX-BIGFLOAT))|
+            MAXIMA::LT1LSTRUVE MAXIMA::SIMPLIM%INVERSE_ERF
+            MAXIMA::SIMP-%JACOBI_NC MAXIMA::SIMPMATRIX
+            BIGFLOAT::BF-ELLIPTIC-PI MAXIMA::BETWEENP
+            MAXIMA::SIMP-EXPINTEGRAL_E1
+            BIGFLOAT::|(PCL::FAST-METHOD EPSILON (COMPLEX-BIGFLOAT))|
+            MAXIMA::SIMP-%CSCH MAXIMA::SIMP-%ACSC MAXIMA::ELLIPTIC-PI
+            BIGFLOAT::|(PCL::FAST-METHOD IMAGPART (BIGFLOAT))|
+            MAXIMA::SIMP-GENERALIZED-LAMBERTW MAXIMA::SIMP-%COS
+            MAXIMA::$BETA_INCOMPLETE_REGULARIZED MAXIMA::$CARLSON_RD
+            MAXIMA::CREATE-POLY MAXIMA::TRY-LHOSPITAL
+            MAXIMA::SIMP-BESSEL-K MAXIMA::SIMP-EXPINTEGRAL-LI
+            MAXIMA::SIMPATAN2 MAXIMA::SIMP-HANKEL-1 MAXIMA::SRATSUBST
+            MAXIMA::SIMPLIM%SIGNUM MAXIMA::SIMP-%ATANH
+            MAXIMA::MSIZE-POSTFIX MAXIMA::LT-EXEC MAXIMA::INTSC1
+            MAXIMA::SIMP-MIN
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT-SIGN (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TANH (BIGFLOAT))|
+            MAXIMA::SIMP-CONJUGATE MAXIMA::CONFL MAXIMA::DESMJY
+            MAXIMA::SIMPLIMIT MAXIMA::RATLOG MAXIMA::SIMP-%ASECH
+            MAXIMA::SIMP-ERF MAXIMA::INTSC
+            BIGFLOAT::|(PCL::FAST-METHOD ONE-ARG-ATAN (BIGFLOAT))|
+            MAXIMA::SIMP-INVERSE-ERFC)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T) *)
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMERIC NUMERIC))|
+            MAXIMA::$TLDEFINT
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD DESCRIBE-OBJECT (COMPLEX-BIGFLOAT T))|
+            MAXIMA::F81 MAXIMA::SIMP2>F<2
+            BIGFLOAT::|(PCL::FAST-METHOD FROUND (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (BIGFLOAT NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:RATIONAL BIGFLOAT))|
+            MAXIMA::RESM0
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT BIGFLOAT))|
+            MAXIMA::INTEGRAND-CHANGEVAR
+            BIGFLOAT::|(PCL::FAST-METHOD INIT-LAMBERT-W-K (INTEGER BIGFLOAT))|
+            MAXIMA::F83 MAXIMA::FPOLY2
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (COMPLEX-BIGFLOAT BIGFLOAT))|
+            MAXIMA::TAYLIM
+            BIGFLOAT::|(PCL::FAST-METHOD CEILING (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD FCEILING (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::DIFAPPLY
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (BIGFLOAT LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT LISP:RATIONAL))|
+            MAXIMA::SOLVEX MAXIMA::SP2INTEG2
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (COMPLEX-BIGFLOAT NUMBER))|
+            MAXIMA::MAPPLY1
+            MAXIMA::|(PCL::FAST-METHOD PRINT-OBJECT (MAXIMA-$ERROR T))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::F16P217TEST MAXIMA::F84
+            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMERIC NUMERIC))|
+            MAXIMA::$LDEFINT MAXIMA::ALGIII
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (NUMBER COMPLEX-BIGFLOAT))|
+            MAXIMA::$CARLSON_RJ
+            BIGFLOAT::|(PCL::FAST-METHOD ROUND (BIGFLOAT))|
+            MAXIMA::F50P188-SIMP
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (COMPLEX-BIGFLOAT BIGFLOAT))|
+            MAXIMA::$CHANGEVAR MAXIMA::COT-TIMES
+            BIGFLOAT::|(PCL::FAST-METHOD INIT-LAMBERT-W-K (INTEGER NUMBER))|
+            MAXIMA::$DEFINT
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT LISP:RATIONAL))|
+            MAXIMA::SIMPLIMEXPT MAXIMA::LIMIT MAXIMA::F82
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT LISP:FLOAT))|
+            MAXIMA::LT-LTP
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (COMPLEX-BIGFLOAT NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (COMPLEX-BIGFLOAT NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT COMPLEX-BIGFLOAT))|
+            MAXIMA::LIMFACT2
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (NUMBER BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT LISP:RATIONAL))|
+            MAXIMA::GAMMA1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|
+            MAXIMA::FREESUM MAXIMA::DEFINT-LIST MAXIMA::F86
+            MAXIMA::LISPM-MFUNCTION-CALL-AUX
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (COMPLEX-BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (NUMBER BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (BIGFLOAT BIGFLOAT))|
+            MAXIMA::LAPSINH
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (BIGFLOAT LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMERIC NUMBER))|
+            MAXIMA::RATROOT
+            BIGFLOAT::|(PCL::FAST-METHOD FLOOR (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (NUMBER COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT LISP:COMPLEX))|
+            MAXIMA::F85 MAXIMA::LT1S MAXIMA::SP3SUBSTPN
+            MAXIMA::METHOD-BY-LIMITS BIGFLOAT::BF-RJ1
+            BIGFLOAT::|(PCL::FAST-METHOD SCALE-FLOAT (BIGFLOAT INTEGER))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (COMPLEX-BIGFLOAT NUMBER))|
+            MAXIMA::MAYBE-RESET
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (LISP:RATIONAL BIGFLOAT))|
+            MAXIMA::GGRM1 MAXIMA::DEN1DEN1
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (BIGFLOAT LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (COMPLEX-BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::LT1P MAXIMA::LIMIT2
+            BIGFLOAT::|(PCL::FAST-METHOD FLOAT (LISP:RATIONAL BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:RATIONAL BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TRUNCATE (BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT LISP:COMPLEX))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (LISP:COMPLEX BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (NUMBER COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (BIGFLOAT LISP:RATIONAL))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (NUMBER COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (BIGFLOAT LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-COMPLEX (LISP:FLOAT BIGFLOAT))|
+            MAXIMA::LT1Q MAXIMA::SER0
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::BF-RJ
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT LISP:COMPLEX))|
+            MAXIMA::GNUPLOT-CURVE-STYLE MAXIMA::ZMTORAT
+            BIGFLOAT::|(PCL::FAST-METHOD INIT-LAMBERT-W-K (INTEGER COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMBER NUMERIC))|
+            BIGFLOAT::|(PCL::FAST-METHOD EXPT (NUMERIC NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-LOG (NUMBER NUMERIC))|
+            MAXIMA::$BETA_INCOMPLETE_GENERALIZED
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (LISP:RATIONAL BIGFLOAT))|
+            MAXIMA::JACOBPOL MAXIMA::SIMPPROD1-SAVE MAXIMA::DERIVAT
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (LISP:COMPLEX BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD FFLOOR (BIGFLOAT))|
+            MAXIMA::LT1M MAXIMA::DEFINT-LOG-EXP
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-ATAN (BIGFLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (BIGFLOAT COMPLEX-BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-- (BIGFLOAT LISP:COMPLEX))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-/ (LISP:FLOAT BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD EXPT (BIGFLOAT INTEGER))|
+            MAXIMA::LAPSIN
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (NUMBER COMPLEX-BIGFLOAT))|
+            MAXIMA::SIMPSUM1-SAVE
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-* (COMPLEX-BIGFLOAT NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|
+            MAXIMA::DINTEGRATE MAXIMA::TAN-TIMES
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-= (NUMBER BIGFLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD FTRUNCATE (BIGFLOAT))|
+            MAXIMA::NUMJORY
+            BIGFLOAT::|(PCL::FAST-METHOD TWO-ARG-+ (COMPLEX-BIGFLOAT COMPLEX-BIGFLOAT))|)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
-                    FIXNUM)
-                *)
-            SLATEC::DQWGTC)) 
+    '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT FIXNUM) *) SLATEC::D9UPAK)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T *) *) INTL::LOAD-DOMAIN
+            MAXIMA::PRETTY-GOOD-FLOOR-OR-CEILING MAXIMA::TEST-BATCH
+            INTL::FIND-DOMAIN MAXIMA::$XREDUCE MAXIMA::AFORMAT
+            MAXIMA::MAPLIST_TR MAXIMA::$RATCOEF GETOPT:GETOPT
+            MAXIMA::$PSUBSTITUTE MAXIMA::$SUBSTITUTE
+            MAXIMA::FORMAT-PROMPT MAXIMA::APPLY-REFLECTION-SIMP
+            MAXIMA::LAPLACE MAXIMA::$GCD MAXIMA::$DIVIDE
+            MAXIMA::MARRAYREF MAXIMA::$INTEGRATE GETOPT::MATCH-OPTION
+            MAXIMA::SCANMAP1 MAXIMA::$COEFF MAXIMA::$OUTERMAP)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T T T) *) MAXIMA::STEP-7-MM
+            MAXIMA::GF-DLOG-F MAXIMA::STEP-7-PM MAXIMA::STEP-7-PP
+            MAXIMA::DLOG-F MAXIMA::STEP-7-MP MAXIMA::ZS-INTIR3)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T T) *) MAXIMA::GNUPLOT-PLOT3D-COMMAND
+            MAXIMA::DIMNARY-BOOLEAN MAXIMA::INTIR3-REF
+            MAXIMA::DIMNARY-MTEXT MAXIMA::AS-15.2.9
+            MAXIMA::SIN/COS-TIMES MAXIMA::AS-15.2.3
+            MAXIMA::CSC/SEC-TIMES MAXIMA::DIMENSION MAXIMA::AS-15.2.8
+            MAXIMA::DIMNARY MAXIMA::AS-15.2.4 MAXIMA::AS-15.2.5
+            MAXIMA::AS-15.2.2 MAXIMA::AS-15.2.7 MAXIMA::INTIR3-R0TEST
+            MAXIMA::AS-15.2.6)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T *) *) MAXIMA::HYP-COS
+            BIGFLOAT::FIND-ROOT-SUBR MAXIMA::WARN-MODE
+            MAXIMA::SCAN-DIGITS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T) *) MAXIMA::DIFAP1 MAXIMA::FAN
+            MAXIMA::SUBST2 MAXIMA::LT2J MAXIMA::RATRAD
+            MAXIMA::OUTPUT-TEXT* MAXIMA::INTSUM1 MAXIMA::SIN/COS-PLUS
+            MAXIMA::DEN1DENN MAXIMA::CSC/SEC-PLUS MAXIMA::COMPOSE
+            MAXIMA::MSIZE MAXIMA::SC^N MAXIMA::DIFFHK MAXIMA::PJACTEST
+            MAXIMA::LT-ARBPOW2 MAXIMA::F19P220-SIMP MAXIMA::TEX
+            MAXIMA::SBSTPT)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
                 (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
                     FIXNUM)
                 *)
-            SLATEC::DQWGTF)) 
+            SLATEC::DQWGTC SLATEC::DQWGTF SLATEC::DQWGTS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T T T T T T) *) MAXIMA::MM-INTIR1-EXEC
+            MAXIMA::MM-INTIR1 MAXIMA::PP-INTIR1-EXEC MAXIMA::PM-INTIR1
+            MAXIMA::PP-INTIR1 MAXIMA::INTIR1-REF)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
-                    FIXNUM)
+                (FIXNUM FIXNUM FIXNUM LONG-FLOAT (VECTOR LONG-FLOAT)
+                        (VECTOR FIXNUM) FIXNUM)
                 *)
-            SLATEC::DQWGTS)) 
-(PROCLAIM '(FTYPE (FUNCTION NIL *) SLATEC::FDUMP)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION ((VECTOR LONG-FLOAT) FIXNUM LONG-FLOAT) *)
-            SLATEC::INITDS)) 
+            SLATEC::DQPSRT)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION (STRING STRING STRING FIXNUM FIXNUM FIXNUM) *)
-            SLATEC::XERCNT)) 
-(PROCLAIM '(FTYPE (FUNCTION (STRING) T) SLATEC::XERHLT)) 
+    '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT) *)
+            SLATEC::ZEXP)) 
 (PROCLAIM
     '(FTYPE (FUNCTION (STRING STRING STRING FIXNUM FIXNUM) *)
             SLATEC::XERMSG)) 
 (PROCLAIM
-    '(FTYPE (FUNCTION ((VECTOR FIXNUM) FIXNUM) *) SLATEC::XGETUA)) 
-(PROCLAIM '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT) *) SLATEC::ZABS)) 
+    '(FTYPE (FUNCTION (LONG-FLOAT) T) MAXIMA::AIRY-DAI-REAL
+            MAXIMA::AIRY-DBI-REAL MAXIMA::AIRY-AI-REAL
+            MAXIMA::AIRY-BI-REAL)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
-                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM
-                    FIXNUM FIXNUM LONG-FLOAT LONG-FLOAT LONG-FLOAT
+                (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
                     LONG-FLOAT)
                 *)
-            SLATEC::ZBUNI)) 
+            SLATEC::ZMLT SLATEC::ZDIV SLATEC::ZSHCH)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
                 (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM FIXNUM
@@ -6748,26 +985,36 @@
                 *)
             SLATEC::ZBUNK)) 
 (PROCLAIM
+    '(FTYPE (FUNCTION ((ARRAY T)) T) MAXIMA::$POLAR_TO_XY
+            MAXIMA::$SPHERICAL_TO_XYZ)) 
+(PROCLAIM
     '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
-                    LONG-FLOAT)
+                (LONG-FLOAT LONG-FLOAT (VECTOR LONG-FLOAT)
+                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                    (VECTOR LONG-FLOAT) FIXNUM)
                 *)
-            SLATEC::ZDIV)) 
-(PROCLAIM
-    '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT) *)
-            SLATEC::ZEXP)) 
+            SLATEC::DQMOMO)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
+                (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
+                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM
+                    FIXNUM FIXNUM LONG-FLOAT LONG-FLOAT LONG-FLOAT
                     LONG-FLOAT)
                 *)
-            SLATEC::ZMLT)) 
+            SLATEC::ZBUNI)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T FIXNUM FIXNUM) *) MAXIMA::B-SEARCH-EXPR)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (STRING STRING STRING FIXNUM FIXNUM FIXNUM) *)
+            SLATEC::XERCNT)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
-                    LONG-FLOAT)
+                (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
+                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM
+                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) LONG-FLOAT
+                    LONG-FLOAT LONG-FLOAT)
                 *)
-            SLATEC::ZSHCH)) 
+            SLATEC::ZWRSK)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
                 (LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT) *)
@@ -6776,24 +1023,985 @@
     '(FTYPE (FUNCTION
                 (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
                     (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM
-                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) LONG-FLOAT
-                    LONG-FLOAT LONG-FLOAT)
+                    FIXNUM)
                 *)
-            SLATEC::ZWRSK)) 
+            SLATEC:ZBESK)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
-                   LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM FIXNUM FIXNUM
-                   FIXNUM (VECTOR FIXNUM) (VECTOR LONG-FLOAT))
+                (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
+                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM
+                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM)
                 *)
-            SLATEC:DQAG)) 
+            SLATEC:ZBESY)) 
+(PROCLAIM '(FTYPE (FUNCTION (T INTEGER T) T) MAXIMA::GF-POW)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T INTEGER T INTEGER INTEGER T) T)
+            MAXIMA::*F-POW$)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (T LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT LONG-FLOAT
-                   LONG-FLOAT FIXNUM FIXNUM FIXNUM FIXNUM FIXNUM
-                   (VECTOR FIXNUM) (VECTOR LONG-FLOAT))
+                (FIXNUM (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                        (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM)
                 *)
-            SLATEC:DQAGI)) 
+            SLATEC::DGTSL)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                (FIXNUM (VECTOR LONG-FLOAT) LONG-FLOAT LONG-FLOAT
+                        (VECTOR LONG-FLOAT) FIXNUM)
+                *)
+            SLATEC::DQELG)) 
+(PROCLAIM '(FTYPE (FUNCTION (T INTEGER FIXNUM) T) MAXIMA::GF-IRR-P)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (INTEGER FIXNUM T) T) MAXIMA::GF-X^P-POWERS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION ((VECTOR LONG-FLOAT) T) T) MAXIMA::$GET_RANGE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T) (*))
+            BIGFLOAT::|(PCL::FAST-METHOD FFLOOR (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD FCEILING (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD FROUND (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD FTRUNCATE (NUMBER))|)) 
+(PROCLAIM '(FTYPE (FUNCTION (T) FUNCTION) INTL::DOMAIN-ENTRY-READFN)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (INTEGER) T) MAXIMA::GF-N2L MAXIMA::GF-N2X)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T) INTEGER) MAXIMA::TC-STATE-NVARS
+            MAXIMA::TC-STATE-NCOSETS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T) SIMPLE-STRING) INTL::DOMAIN-ENTRY-LOCALE
+            INTL::DOMAIN-ENTRY-DOMAIN)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION NIL *) MAXIMA::BREAK-PROMPT MAXIMA::BREAK-CURRENT
+            MAXIMA::MAIN-PROMPT MAXIMA::SCAN-ONE-TOKEN
+            CL-INFO::LOAD-PRIMARY-INDEX MAXIMA::MBREAK-LOOP
+            COMMAND-LINE:GET-APPLICATION-ARGS MAXIMA::FPONE
+            MAXIMA::CONTINUEP MAXIMA::$QUIT SLATEC::FDUMP)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                ((ARRAY LONG-FLOAT) (ARRAY UNSIGNED-SHORT) FIXNUM) T)
+            MAXIMA::SORT-NGONS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T) *) MAXIMA::ANTIDERIV MAXIMA::HALVE
+            MAXIMA::MOD1 MAXIMA::GVAR-LIM MAXIMA::$NUM
+            MAXIMA::SCAN-NUMBER-REST MAXIMA::$SUMCONTRACT
+            MAXIMA::MEVAL-ATOMS MAXIMA::RATS MAXIMA::SCAXN
+            MAXIMA::$EXPINTEGRAL_CI MAXIMA::FPLOG1P
+            MAXIMA::TR-MDEFINE-TOPLEVEL MAXIMA::$TRIGEXPAND
+            MAXIMA::$%TH MAXIMA::MEVAL MAXIMA::FLOOR-INTEGRAL
+            MAXIMA::LIM-LOG MAXIMA::ARGNUM MAXIMA::SP1TRIG
+            MAXIMA::RDSGET MAXIMA::SSSQFR MAXIMA::$INTOSUM
+            MAXIMA::MTOSC MAXIMA::ESAP MAXIMA::DISTRIBUTE-OVER
+            MAXIMA::CONJUGATE-BESSEL-K MAXIMA::TRANSPOSE-ELS
+            MAXIMA::CONJUGATE-ASIN MAXIMA::$ERFC MAXIMA::GM
+            MAXIMA::AUTOLDCHK MAXIMA::CONJUGATE-GAMMA-INCOMPLETE
+            MAXIMA::$COS MAXIMA::CSIGN MAXIMA::$FLOAT MAXIMA::TRISPLIT
+            MAXIMA::SRDISREP MAXIMA::$FULL_LISTIFY
+            MAXIMA::CONJUGATE-ATANH MAXIMA::CONJUGATE-SUM
+            MAXIMA::%PIARGS-CSC/SEC MAXIMA::$GF_MATNEG MAXIMA::$COT
+            MAXIMA::XMAXIMA-PALETTE MAXIMA::COMPSPLT-EQ MAXIMA::$ACSCH
+            MAXIMA::CEILING-INTEGRAL MAXIMA::NFORMAT MAXIMA::$SETIFY
+            MAXIMA::$AIRY_AI MAXIMA::SFORX MAXIMA::$COMBINE
+            MAXIMA::LT-SF-LOG MAXIMA::$ALLROOTS MAXIMA::$SIN
+            MAXIMA::SIMPLIFY MAXIMA::FPACOS MAXIMA::GET-SMALL-FACTORS
+            MAXIMA::SCAN-NUMBER-BEFORE-DOT MAXIMA::CONJUGATE-BESSEL-J
+            MAXIMA::$INVERSE_ERFC MAXIMA::$EXPINTEGRAL_SI
+            BIGFLOAT::BF-ELLIPTIC-K MAXIMA::HYPREDERF
+            MAXIMA::CONJUGATE-BETA-INCOMPLETE-GENERALIZED
+            CL-INFO::PRINT-PROMPT MAXIMA::$BERN MAXIMA::$LMAX
+            MAXIMA::CONJUGATE-GAMMA-INCOMPLETE-GENERALIZED
+            MAXIMA::$MAKEGAMMA MAXIMA::$GF_INVERT_BY_LU
+            MAXIMA::SIMPNCT-INVERT MAXIMA::POISDECODEC MAXIMA::$SINH
+            MAXIMA::RDFACT MAXIMA::MINIMUM MAXIMA::$LMIN
+            MAXIMA::$EXPINTEGRAL_CHI MAXIMA::FORM-MRAT MAXIMA::SUBVAR
+            MAXIMA::RATFNT MAXIMA::DIFF%DERIV
+            MAXIMA::CONJUGATE-EXPINTEGRAL-E1 MAXIMA::$INVERSE_ERF
+            MAXIMA::%PIARGS-SIN/COS MAXIMA::SCAN-NUMBER-EXPONENT
+            MAXIMA::INTEGRALLOOKUPS MAXIMA::$LOGARC MAXIMA::$EXP
+            BIGFLOAT::BF-ERFC MAXIMA::INIT-LAMBERT-W-MINUS1
+            MAXIMA::$ACOT MAXIMA::CONJUGATE-EXPINTEGRAL-CHI
+            MAXIMA::$RATEXPAND MAXIMA::$GAMMA MAXIMA::GF-CMOD
+            BIGFLOAT::BF-FRESNEL-C MAXIMA::$ROOTSCONTRACT MAXIMA::$PFET
+            MAXIMA::SEVN MAXIMA::REFLECT
+            MAXIMA::CONJUGATE-EXPINTEGRAL-E MAXIMA::MEVALN
+            MAXIMA::$LOG_GAMMA MAXIMA::DILOG MAXIMA::ELLIPTIC-K
+            BIGFLOAT::BF-ERFI MAXIMA::$ATAN
+            MAXIMA::SCAN-NUMBER-AFTER-DOT MAXIMA::RESIMPLIFY
+            MAXIMA::SPECREPCHECK MAXIMA::$SIGNUM MAXIMA::PRED-REVERSE
+            MAXIMA::$EXPINTEGRAL_EI MAXIMA::FR-ARGS MAXIMA::ALBK
+            MAXIMA::$NZETA MAXIMA::LFIBTOPHI MAXIMA::INTOPOISCO
+            MAXIMA::CONJUGATE-LOG MAXIMA::ZTO1 MAXIMA::MEVAL1-EXTEND
+            MAXIMA::TRANSLATE-FORM MAXIMA::CONJUGATE-ATAN
+            MAXIMA::LOG-REDUCE MAXIMA::DEMOIVRE MAXIMA::$DEMOIVRE
+            MAXIMA::$GF_MINIMAL_POLY MAXIMA::LOGCON MAXIMA::RATDISREP
+            MAXIMA::$MAKE_ELLIPTIC_F MAXIMA::$COTH MAXIMA::SET-MODULUS
+            MAXIMA::ASSUME MAXIMA::STIRLING0 MAXIMA::$RADCAN
+            MAXIMA::WARN-UNDEFINED-VARIABLE BIGFLOAT-IMPL:1+
+            MAXIMA::CONJUGATE-ACOS MAXIMA::FPLOG MAXIMA::$ACOSH
+            MAXIMA::IGPRT INTL::PARSE-PLURALS MAXIMA::$ERF
+            MAXIMA::LIMUNKNOWN MAXIMA::GGRM MAXIMA::$ACSC MAXIMA::$ZETA
+            MAXIMA::SP2EXPAND MAXIMA::DISPLA MAXIMA::$AIRY_DAI
+            MAXIMA::$MAKEFACT MAXIMA::DERIV MAXIMA::$GF_EVAL
+            MAXIMA::COMPSPLT MAXIMA::$NICEINDICES MAXIMA::TBF
+            MAXIMA::RADMABS MAXIMA::EXTREME-FLOAT-VALUES
+            MAXIMA::$LOGCONTRACT MAXIMA::RAISE MAXIMA::FINDSUB
+            MAXIMA::SP2EXPT MAXIMA::GNUPLOT-PALETTE MAXIMA::UNRAT
+            MAXIMA::HYPEREX0 MAXIMA::TANSC1 MAXIMA::$POISSIMP
+            MAXIMA::BATAPP MAXIMA::RATSQRT MAXIMA::$GFACTOR
+            MAXIMA::FACTRAT MAXIMA::SCONVERT MAXIMA::SUSUM1
+            MAXIMA::$SQRT MAXIMA::BFLOAT-LOG-GAMMA MAXIMA::$BFLOAT
+            MAXIMA::$ED MAXIMA::HYPEREX1 MAXIMA::MQAPPLY1 MAXIMA::GGCD
+            MAXIMA::$COSH MAXIMA::SIGNFACTOR MAXIMA::MAKE-NUMBER
+            MAXIMA::FREE-LISP-VARS MAXIMA::$PLOG MAXIMA::PIN%EX
+            MAXIMA::GF-DISREP-FACTORS MAXIMA::$ATANH
+            MAXIMA::$BFALLROOTS MAXIMA::TRIMF
+            MAXIMA::TRANSLATE-FUNCTION MAXIMA::MRATEVAL
+            BIGFLOAT::BF-FRESNEL-S MAXIMA::SSP MAXIMA::BIGFLOATM*
+            MAXIMA::$EXPINTEGRAL_SHI MAXIMA::$ASECH MAXIMA::LIM-EXP
+            MAXIMA::LGCTIMES MAXIMA::SP1TRIGEX MAXIMA::$TRUNCATE
+            MAXIMA::MICRO-TO-SEC MAXIMA::CONJUGATE-PRODUCT
+            MAXIMA::GF-CINV MAXIMA::FLOAT-ZETA MAXIMA::TR-MFUN
+            MAXIMA::$AIRY_DBI MAXIMA::EXPANDROOT MAXIMA::$ACOS
+            MAXIMA::IS-MNOT MAXIMA::MAKPOLY MAXIMA::%PIARGS-TAN/COT
+            MAXIMA::ASYMREDU MAXIMA::LRDTAY MAXIMA::SP1TIMES
+            MAXIMA::RDTAY MAXIMA::PIN%EX0 BIGFLOAT::BF-INVERSE-ERFC
+            MAXIMA::PFREEOFMAINVARSP MAXIMA::$LUCAS GETOPT::ANALYZE-ARG
+            MAXIMA::EPROG MAXIMA::MARKND MAXIMA::$LAMBERT_W
+            MAXIMA::COERCE-FLOAT MAXIMA::CONJUGATE-EXPINTEGRAL-CI
+            MAXIMA::MEVAL* MAXIMA::FPASIN MAXIMA::NEWLINE
+            MAXIMA::EF-CMINUS-B MAXIMA::$EF_MINIMAL_POLY MAXIMA::$ASINH
+            MAXIMA::SIMPLN1 MAXIMA::GAMMARED MAXIMA::SIMPINF-TIMES
+            MAXIMA::COMPSPLT-SINGLE MAXIMA::$GF_DETERMINANT
+            MAXIMA::$FIX MAXIMA::GET-ONE-FACTOR-ECM
+            MAXIMA::$MAKE_ELLIPTIC_E MAXIMA::XCHDIR MAXIMA::$EF_MATNEG
+            MAXIMA::CONVERT-LIST MAXIMA::SUPERSINX MAXIMA::SIMPLIMPLUS1
+            MAXIMA::ADDBIGFLOAT MAXIMA::$CSCH BIGFLOAT::BF-ERF
+            MAXIMA::LOG-IMAG-0-2%PI
+            MAXIMA::TRANSLATE-AND-EVAL-MACSYMA-EXPRESSION
+            MAXIMA::SIMPINF MAXIMA::TR-LISP->LISP MAXIMA::INTOFP
+            MAXIMA::MRATCHECK MAXIMA::*BREAK-POINTS*
+            MAXIMA::SIMPLIM%ATAN2 MAXIMA::$BASHINDICES MAXIMA::STRMEVAL
+            MAXIMA::GCDRED MAXIMA::BATAP-INF MAXIMA::GETEXPLIST
+            MAXIMA::PFLOATP MAXIMA::$UNKNOWN MAXIMA::$OUTOFPOIS
+            MAXIMA::NUM-OF-LOGS MAXIMA::CHANGEVAR
+            MAXIMA::LISP->LISP-TR-LAMBDA BIGFLOAT::BF-ELLIPTIC-EC
+            MAXIMA::SIMPLIM%ACOSH MAXIMA::SIGN MAXIMA::SUPERCOSNX
+            MAXIMA::SPECDISREP MAXIMA::GETFUN-LT MAXIMA::$ECHELON
+            MAXIMA::SUBSTINT1 MAXIMA::$DOUBLE_FACTORIAL
+            MAXIMA::SIMPLIM%ASINH MAXIMA::$ENTIER MAXIMA::$SEC
+            BIGFLOAT::BF-INVERSE-ERF MAXIMA::$ROUND MAXIMA::$FRESNEL_S
+            MAXIMA::$ASEC MAXIMA::$NTERMS MAXIMA::$EXPINTEGRAL_E1
+            MAXIMA::ERFCTD MAXIMA::$DETERMINANT MAXIMA::$TAN
+            MAXIMA::GENERIC-AUTOLOAD MAXIMA::INTFORM MAXIMA::FLOAT2RAT
+            MAXIMA::CDISREP MAXIMA::TAYLOR_SIMPLIFIER_CALLER
+            MAXIMA::LOGRED MAXIMA::FACTCOMB MAXIMA::LIMITNEG
+            MAXIMA::GETEXP MAXIMA::MAKE-ELLIPTIC-E
+            MAXIMA::$EXPINTEGRAL_LI MAXIMA::$TANH MAXIMA::$ABS
+            MAXIMA::BATAP-NEW MAXIMA::$EXPONENTIALIZE MAXIMA::EVFACT
+            MAXIMA::FACTEXPAND MAXIMA::SRATSIMP
+            MAXIMA::$MAKE_RANDOM_STATE MAXIMA::FORGET
+            BIGFLOAT::LAMBERT-BRANCH-APPROX MAXIMA::DETERMINANT1
+            MAXIMA::CGCDLIST MAXIMA::COMPSPLT-GENERAL MAXIMA::LMUL
+            MAXIMA::LGCRECIPROCAL MAXIMA::CONJUGATE-BESSEL-Y
+            MAXIMA::TIMESBIGFLOAT MAXIMA::FORMAT1 MAXIMA::$AIRY_BI
+            MAXIMA::RISPLIT BIGFLOAT-IMPL:1- MAXIMA::MEVAL1
+            MAXIMA::$ERFI
+            MAXIMA::CONJUGATE-GAMMA-INCOMPLETE-REGULARIZED
+            MAXIMA::GETOPR0 MAXIMA::$EF_INVERT_BY_LU MAXIMA::MEVALATOMS
+            MAXIMA::$GF_MATINV MAXIMA::NFORMAT-CHECK MAXIMA::IDENTITYMX
+            MAXIMA::MAXIMUM MAXIMA::LIM-RECIP MAXIMA::$XTHRU
+            MAXIMA::REPLAC MAXIMA::$EF_DETERMINANT MAXIMA::SP2INTEG1
+            MAXIMA::$ASIN MAXIMA::SIMPAB MAXIMA::RATEXP
+            MAXIMA::DISCONTINUITIES-DENOM MAXIMA::STIRLING
+            MAXIMA::RATDISREPD MAXIMA::F3 MAXIMA::FORGET1
+            MAXIMA::ABS-INTEGRAL MAXIMA::$ACOTH MAXIMA::LOWER
+            MAXIMA::$FRESNEL_C MAXIMA::$LOG MAXIMA::SIGN-ODDINC
+            MAXIMA::GF-CP2SMOD MAXIMA::CONJUGATE-EXPINTEGRAL-LI
+            MAXIMA::$DENOM MAXIMA::$RATIONALIZE MAXIMA::BATA0
+            MAXIMA::$TOTALDISREP MAXIMA::FLOAT-RATIO
+            MAXIMA::TOPLEVEL-OPTIMIZE-1 MAXIMA::SUMCONSIMP MAXIMA::NEG
+            MAXIMA::$EF_EVAL MAXIMA::CONJUGATE-BESSEL-I
+            MAXIMA::INTEGER-PART-OF-SUM MAXIMA::$CSC
+            MAXIMA::$TRIANGULARIZE MAXIMA::MAKE-ELLIPTIC-F
+            MAXIMA::$ELLIPTIC_EC MAXIMA::PSDISREP BIGFLOAT::BF-FRESNEL
+            MAXIMA::MAKEFACT1 MAXIMA::SP1 MAXIMA::DSKSETQ-AUX
+            MAXIMA::BREAK-DBM-LOOP MAXIMA::ERRBREAK2
+            MAXIMA::ABSARG-MABS MAXIMA::MAXIMA-GETENV MAXIMA::*MMINUS
+            MAXIMA::SP1EXPT2 MAXIMA::COMPLEX-BFLOAT-LOG-GAMMA
+            MAXIMA::GF-CMINUS-B MAXIMA::MNLOGP MAXIMA::$SECH
+            MAXIMA::LGCSIMP MAXIMA::$ELLIPTIC_KC MAXIMA::CV
+            MAXIMA::$EF_FACTOR MAXIMA::$EULER MAXIMA::MAKEGAMMA1
+            MAXIMA::HYPEREX MAXIMA::TRIGRED)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (*) T) MAXIMA::$PRINT MAXIMA::MFORMAT
+            MAXIMA::$REMAINDER MAXIMA::$ALLBUT
+            MAXIMA::$CARTESIAN_PRODUCT MAXIMA::MAKE-TC-STATE
+            MAXIMA::$GF_MULT_TABLE MAXIMA::$TLIMIT MAXIMA::MTELL
+            MAXIMA::$FILENAME_MERGE INTL:SETLOCALE MAXIMA::$KILLCONTEXT
+            MAXIMA::$APPEND MAXIMA::$GF_MATADD MAXIMA::$READONLY
+            BIGFLOAT-IMPL:* MAXIMA::$DPART MAXIMA::RUN-TESTSUITE
+            MAXIMA::COMPLEX-BIGFLOAT-NUMERICAL-EVAL-P MAXIMA::LAPSUM
+            MAXIMA::$SUBMATRIX MAXIMA::$SCONCAT MAXIMA::$EF_POWER_TABLE
+            MAXIMA::RETLIST_TR MAXIMA::$EF_ADD MAXIMA::BREAK-HELP
+            MAXIMA::$BACKTRACE MAXIMA::SIMP-DOMAIN-ERROR
+            MAXIMA::$EF_MATMULT MAXIMA::$EF_SUB MAXIMA::STEP-INTO
+            MAXIMA::FLOAT-NUMERICAL-EVAL-P MAXIMA::MAKE-GF-DATA
+            MAXIMA::$ACTIVATE MT19937::MAKE-RANDOM-OBJECT
+            MAXIMA::$GF_ORDER MAXIMA::MFORMAT-TRANSLATE-OPEN
+            BIGFLOAT-IMPL:+ MAXIMA::$GF_POWER_TABLE
+            MAXIMA::MAKE-DISP-HACK-OB MAXIMA::$BDISCR MAXIMA::$LIMIT
+            COMMAND-LINE:MAKE-CL-OPTION MAXIMA::$GET_PLOT_OPTION
+            MAXIMA::$GF_MULT MAXIMA::MAKE-EF-DATA MAXIMA::$GF_DIV
+            MAXIMA::$LDISP MAXIMA::$RATWEIGHT MAXIMA::$EF_MULT
+            MAXIMA::$RUN_TESTSUITE MAXIMA::EXPO MAXIMA::MAKE-MRING
+            MAXIMA::MMAPCAR MAXIMA::$MULTINOMIAL_COEFF MAXIMA::$CONCAT
+            MAXIMA::MRETURN MAXIMA::$EF_MATADD MAXIMA::$EF_ORDER
+            MAXIMA::$EF_RANDOM MAXIMA::$GF_RANDOM MAXIMA::$DISP
+            MAXIMA::DEACTIVATE MAXIMA::$GENFACT MAXIMA::$GF_INFO
+            MAXIMA::ACTIVATE MAXIMA::STRCAT MAXIMA::$TIMEDATE
+            MAXIMA::MAKE-MGENARRAY MAXIMA::MAKE-LINE-INFO
+            MAXIMA::NPRINC* MAXIMA::$DEACTIVATE MAXIMA::$ZN_POWER_TABLE
+            MAXIMA::ZN-GCDEX MAXIMA::$TELLRAT MAXIMA::SCAN-STRING
+            MAXIMA::BIGFLOAT-NUMERICAL-EVAL-P MAXIMA::$UNION
+            MAXIMA::$DEPENDS MT19937::INT-INIT-RANDOM-STATE
+            MAXIMA::POP-MLAMBDA-CALL-STACK MAXIMA::TYI
+            MAXIMA::$SET_PLOT_OPTION MAXIMA::$FACTS
+            MAXIMA::COMPLEX-FLOAT-NUMERICAL-EVAL-P MAXIMA::$TMLINSOLVE
+            MAXIMA::DBM-READ MAXIMA::$EF_DIV INTL::MAKE-DOMAIN-ENTRY
+            MAXIMA::$GF_MATMULT MAXIMA::$GNUPLOT_REPLOT
+            MAXIMA::MAKE-BKPT MAXIMA::$EF_MULT_TABLE
+            MAXIMA::SUM-VAR-SETS MAXIMA::$UNTELLRAT
+            MAXIMA::LOAD-MACSYMA-MACROS-AT-RUNTIME MAXIMA::$QUOTIENT
+            MAXIMA::$GF_SUB MAXIMA::$INPART MAXIMA::$GF_ADD
+            MAXIMA::$GENSYM MAXIMA::LIMIT-NO-ERR
+            MAXIMA::|__si::MAKE-RI| MAXIMA::$BREAK MAXIMA::$RATVARS
+            MAXIMA::$ERROR MAXIMA::MAKE-TSTACK-SLOT
+            MAXIMA::|__si::MAKE-POLYGON| MAXIMA::$EF_INFO
+            MAXIMA::BREAK-QUIT MAXIMA::$SYMMDIFFERENCE
+            MAXIMA::USED-AREA MAXIMA::MREAD MAXIMA::RAT-ERROR
+            MAXIMA::ADD MAXIMA::TYI-RAW MAXIMA::$IN_EXACTLY_ONE
+            MAXIMA::$FREEOF MAXIMA::STEP-NEXT MAXIMA::MREAD-NOPROMPT
+            MAXIMA::$PART MAXIMA::LAPPROD MAXIMA::NUMERICAL-EVAL-P
+            MT19937:INIT-RANDOM-STATE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (FIXNUM) *) MAXIMA::FRAME-INFO MAXIMA::DBM-UP
+            MAXIMA::LUCAS)) 
+(PROCLAIM '(FTYPE (FUNCTION (T) PATHNAME) INTL::DOMAIN-ENTRY-FILE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T) T) MAXIMA::SOLVEQUARTIC MAXIMA::LIM-FINITEP
+            MAXIMA::TRIGFP MAXIMA::SORT-POLES MAXIMA::LIM-MINUS
+            MAXIMA::MANIFESTLY-PURE-IMAGINARY-P MAXIMA::STRMDOIN
+            MAXIMA::UPS MAXIMA::GET-LINEINFO MAXIMA::LOGQUAD
+            MAXIMA::REMLABELS MAXIMA::ARCFUNCP INTL::DOMAIN-ENTRY-P
+            MAXIMA::DATUM-LIM MAXIMA::PROC-$TELLSIMPAFTER MAXIMA::MNUMP
+            MAXIMA::$DEBUGMODE MAXIMA::DBVARP MAXIMA::KILLVARDEGSN
+            MAXIMA::NUM1 MAXIMA::FREEVARPAR MAXIMA::M2-C*X^2+B*X+A
+            MAXIMA::TSTACK-SLOT-P MAXIMA::EXPANDTIMES MAXIMA::INTBASEHK
+            MAXIMA::BBSORT1 MAXIMA::FIXEXPAND MAXIMA::INIT-PRIME-DIFFS
+            MAXIMA::PDECOMP* MAXIMA::TRACE-PRINT
+            MAXIMA::GET-ARRAY-POINTER MAXIMA::PLOTCOLORP MAXIMA::ZEROP1
+            MAXIMA::MGENARRAY-TYPE MAXIMA::$EF_P2N
+            MAXIMA::BFLOAT-DOUBLE-FACTORIAL MAXIMA::CHECK-OPTION-LABEL
+            MAXIMA::SHOW-BREAK-POINT MAXIMA::AT-SUBSTP MAXIMA::MACSIMP
+            MAXIMA::GF-DIFF MAXIMA::RISCHLOGEPROG MAXIMA::FINDINT
+            MAXIMA::SPLIT2 MAXIMA::TRP-MEQUAL MAXIMA::PLYGAM-ORD
+            MAXIMA::KAR MAXIMA::PDECPRIMEP MAXIMA::E1+
+            MAXIMA::PSDISEXPAND MAXIMA::BASELIST MAXIMA::EF-DATA?
+            MAXIMA::TERM-LIST MAXIMA::SPECREPP MAXIMA::PSMINUS
+            MAXIMA::INTEGRATE1 MAXIMA::MODE MAXIMA::$UNTRACE_IT
+            MAXIMA::GEN-POINT MAXIMA::SAVEFACTORS MAXIMA::PSEXPON-GCD
+            MAXIMA::PSTRUNC MAXIMA::PMONICIZE MAXIMA::AIRY-AI
+            MAXIMA::$WRITEFILE MAXIMA::AT1 MAXIMA::CREATE-LOBJS
+            MAXIMA::RPTROUBLE MAXIMA::KILLVARDEGSC MAXIMA::$TRACE_IT
+            MAXIMA::ARRFIND MAXIMA::IND MAXIMA::LINEAR-DISPLA
+            MAXIMA::MRING-RDIV MAXIMA::DOLLARIFY MAXIMA::ISMAX-CORE
+            MAXIMA::PFLATTEN MAXIMA::RAT->PS MAXIMA::EVEN1
+            MAXIMA::MARKP MAXIMA::RATINVERT MAXIMA::SIMPNRT1
+            MAXIMA::MAKNAM MAXIMA::IN-DOMAIN-OF-ASIN
+            CL-INFO::INFO-EXACT MAXIMA::GETSIGNL MAXIMA::$TAYTORAT
+            MAXIMA::UNTREE MAXIMA::$CFDISREP MAXIMA::%ITOPOT
+            MAXIMA::$OPTIMIZE MAXIMA::$GF_NEG
+            MAXIMA::EF-DATA-X^Q-POWERS MAXIMA::EXPINTEGRAL-EI
+            MAXIMA::SP3FORM1 MAXIMA::RGET MAXIMA::RULEOF
+            MAXIMA::$SET_RANDOM_STATE MAXIMA::PS-GT
+            MAXIMA::RISPLIT-BESSEL-J-OR-I MAXIMA::PMAKE MAXIMA::DPSIMP
+            MAXIMA::DECIMALSIN MAXIMA::DISPLINE
+            MAXIMA::MINIMIZE-VARLIST MAXIMA::PROC-$TELLSIMP
+            MAXIMA::HARRFIND MAXIMA::KILLFRAME
+            MAXIMA::TC-STATE-ROW1-RELATIONS MAXIMA::PROC-$DEFRULE
+            MAXIMA::FLOATFACT MAXIMA::CL-RAT-TO-MAXIMA
+            MAXIMA::GF-DATA-FSX MAXIMA::I-$REMVALUE
+            MAXIMA::DEGVECDISREP MAXIMA::EDISREP MAXIMA::ARRFUNP
+            MAXIMA::EF-MAYBE-NORMAL-BASIS MAXIMA::$SHOWRATVARS
+            MAXIMA::CHECKRAT MAXIMA::RISPLIT-SN-CN-DN
+            MAXIMA::TAYLOR_SIMPLIFY_RECURSE
+            MAXIMA::MANIFESTLY-COMPLEX-P MAXIMA::TRY-FLOAT-COMPUTATION
+            MAXIMA::CONDENSEY MAXIMA::SCALARCLASS-LIST
+            MAXIMA::$PRINTPOIS MAXIMA::SPLITSUM MAXIMA::$RANK
+            MAXIMA::RAT8 MAXIMA::LIN-MEXPT MAXIMA::MRELATIONP
+            MAXIMA::$REMOVE_PLOT_OPTION MAXIMA::DBZ-ERR1
+            MAXIMA::EF-DATA-RED MAXIMA::CALLSOLVE MAXIMA::NOSHFT-SL
+            MAXIMA::M2-EXP-TYPE-2 MAXIMA::FSTRINGC MAXIMA::BF-NOSHFT-SL
+            MAXIMA::SIN% MAXIMA::PSEXPT-FN-SING MAXIMA::TAYAPPROX
+            MAXIMA::SP1KGET MAXIMA::CONDENSESOLNL MAXIMA::SPRECIP
+            MAXIMA::FPATAN MAXIMA::DECL-COMPLEXP MAXIMA::CONSTANT
+            MAXIMA::PARSE-PREFIX MAXIMA::RI-P MAXIMA::$COLLAPSE
+            MAXIMA::GNUPLOT-TERMINAL-AND-FILE MAXIMA::MMAPEV
+            CL-INFO::REARRANGE-MATCHES MAXIMA::$NZETAR
+            MAXIMA::DISTREXEC MAXIMA::ODD1 MAXIMA::UNDEFINE-SYMBOL
+            MAXIMA::ADD-POINT MAXIMA::GF-ZX MAXIMA::LOGQUAD0
+            MAXIMA::DELSIMP MAXIMA::ROUND1 MAXIMA::UFACT-STRIP-ZEROES
+            MAXIMA::TLIMP MAXIMA::NEWVAR1 MAXIMA::$LISTIFY
+            MAXIMA::LIM-INFP SYSTEM::SHORT-NAME MAXIMA::$TEX1
+            MAXIMA::TMLATTICE1 MAXIMA::FULLRATSIMP MAXIMA::SUBFUNARGS
+            MAXIMA::CONTSORT MAXIMA::CONSTFUN MAXIMA::GVAR-LOGP
+            MAXIMA::$EVENP MAXIMA::$EF_SET_DATA MAXIMA::FPTANH
+            MAXIMA::$FACTCOMB MAXIMA::COMPLEX-ERF-UPPER-HALF-PLANE
+            MAXIMA::GETALIAS MAXIMA::NUMNEEDSPAREN
+            MAXIMA::$PATHNAME_NAME MAXIMA::PSMINUS-TERMS
+            MAXIMA::$TRANSPOSE MAXIMA::REMOVE-TRANSL-ARRAY-FUN-PROPS
+            MAXIMA::OPT-HASH MAXIMA::COEF-SIGN MAXIMA::PFACTORANY
+            MAXIMA::ZEROEQUIV1 MAXIMA::M2-B*X+A MAXIMA::FREEVAR
+            MAXIMA::ROT* MAXIMA::CLEAN-LIMIT-EXP
+            MAXIMA::STRIP-LINEINFO-OP MAXIMA::MAYBE-INVERT-STRING-CASE
+            MAXIMA::MOPP MAXIMA::ASKSIGN01 MAXIMA::UCONTENT
+            MAXIMA::$LOAD MAXIMA::LOG-RED-CONTRACT
+            MAXIMA::TR-INFAMOUS-NOUN-FORM MAXIMA::SHOW-EXP
+            MAXIMA::ALGPGET MAXIMA::EF-IRR MAXIMA::WHICHFN
+            MAXIMA::DINTERNP MAXIMA::RPOS MAXIMA::FRAC
+            MAXIMA::$LISTOFVARS MAXIMA::DISTREP MAXIMA::M2-EXP-TYPE-3
+            MAXIMA::PDEGREEVECTOR MAXIMA::TR-ARRAYCALL
+            MAXIMA::QUOTE-STRINGS MAXIMA::SOLVENTH1
+            MAXIMA::STRIP-LINEINFO MAXIMA::SIMPLIMPLUS
+            MAXIMA::MAXIMA-BRANCH-ATANH MAXIMA::PRE-ERR
+            MAXIMA::ADD-UP-DEG MAXIMA::RESTORELIM MAXIMA::PRIMCYCLO
+            MAXIMA::INTEGERP2 MAXIMA::RAT0 MAXIMA::MXORLISTP
+            MAXIMA::MANIFESTLY-REAL-P MAXIMA::PFLAT1
+            MAXIMA::ZN-SHANKS-PHI-STEP-BC MAXIMA::M2-CHEBYFORM
+            MAXIMA::MRING-MULT MAXIMA::RATDEGREE MAXIMA::PMINUSP
+            MAXIMA::CF-BACK-RECURRENCE MAXIMA::DINTNUM MAXIMA::PMONZ
+            MAXIMA::EVOD-MEXPT MAXIMA::DISPATOMGRADS MAXIMA::CMARK
+            MAXIMA::POISDIF4 MAXIMA::SQRTINVOLVE MAXIMA::CFRATSIMP
+            MAXIMA::SUBST10 MAXIMA::%E-INTEGER-COEFF
+            MAXIMA::PRIMEP-LUCAS MAXIMA::LIST-OF-MLISTS
+            MAXIMA::CPOLY-SL MAXIMA::PROPERTIES MAXIMA::PASCAL
+            MAXIMA::FPSIN1 MAXIMA::LOAD-AND-TELL MAXIMA::NEGINP
+            MAXIMA::TMKILLARRAY MAXIMA::TSTIMES MAXIMA::ADJOIN-PVAR
+            MAXIMA::ZP MAXIMA::INTEGER-PARTITIONS MAXIMA::TSEXPT-RED
+            MAXIMA::GAMMA MAXIMA::OPTRIG MAXIMA::SET-FULL-LINEINFO
+            MAXIMA::INFSIMP MAXIMA::OBTAINAB MAXIMA::FNEWVAR
+            MAXIMA::SIGN-ANY MAXIMA::REM-OPERS-P MAXIMA::*RULECHK
+            MAXIMA::ALGSYS1 MAXIMA::SET-ENV MAXIMA::TOTAL-NARY
+            MAXIMA::INTEGER-REPRESENTATION-P MAXIMA::INCREMENT-TRUNCS
+            MAXIMA::MEVALARGS MAXIMA::RJFSIMP MAXIMA::$APPENDFILE
+            MAXIMA::NUMER MAXIMA::FACTORSUM2 MAXIMA::TRIG-SUBST-P
+            MAXIMA::$TEXEND MAXIMA::QUOTE-% MAXIMA::FLEVENP
+            MAXIMA::$VERBIFY MAXIMA::GF-PTH-ROOT MAXIMA::PARSE-AZIMUTH
+            MAXIMA::DCONV-$CRE MAXIMA::COMP-BF%GAMMA MAXIMA::RCCOEFP
+            MAXIMA::TRP-MLEQP MAXIMA::OPMEXPT
+            MAXIMA::INSERT-NECESSARY-FUNCTION-DECLARES
+            MAXIMA::TRANSLATE-ATOMS MAXIMA::LOGNXP MAXIMA::GF-X2P
+            MAXIMA::MACSYMA-UNTRACE MAXIMA::SP1ADD MAXIMA::MULL
+            MAXIMA::HAS-REPEAT MAXIMA::TRP-MLESSP MAXIMA::ARGSUBST
+            MAXIMA::OPIDENT MAXIMA::PMOD MAXIMA::ZEROP-IN-L
+            MAXIMA::$RATDENOM MAXIMA::CFMAK MAXIMA::BCONS
+            MAXIMA::BAD-FORM MAXIMA::TEX-CHAR MAXIMA::FACTOR1972
+            MAXIMA::$EXPINT MAXIMA::ODDELM MAXIMA::CSF MAXIMA::UNMRK
+            MAXIMA::KNOWNFACTORS MAXIMA::GF-DLOG MAXIMA::SQRT1-X^2
+            MAXIMA::$GF_L2P MAXIMA::DISPGRADEFS MAXIMA::GF-CHAR?
+            MAXIMA::MEXPLODEN MAXIMA::TLIST-MERGE MAXIMA::NEWVAR
+            MAXIMA::SIMPNCT-BASE MAXIMA::PGCDEXPON MAXIMA::MARRAY-TYPE
+            MAXIMA::MINMAXP MAXIMA::STRGRIND MAXIMA::EXPLODE
+            MAXIMA::$EF_IRREDUCIBLE MAXIMA::AMPERCHK MAXIMA::$GF_INV
+            MAXIMA::EXPLODEN MAXIMA::$GCFACTOR MAXIMA::$FIRST
+            MAXIMA::CHECK MAXIMA::POLYINT1 MAXIMA::$RECTFORM
+            MAXIMA::LSA MAXIMA::SRRAT2 MAXIMA::ROUNDROOTS1
+            MAXIMA::MFUNCTION1 MAXIMA::INIT MAXIMA::PARSE-TAY-ARGS
+            MAXIMA::TRP-MNOTEQUAL MAXIMA::FACTXN+1 MAXIMA::$EXP-FORM
+            MAXIMA::GF-DATA-P MAXIMA::READ-COMMAND-TOKEN
+            MAXIMA::UNIPOLY MAXIMA::PROC-$DEFMATCH MAXIMA::USE-RADCAN-P
+            MAXIMA::PSLOG2 MAXIMA::CPBER1 MAXIMA::ADISPLINE
+            MAXIMA::DTRANSLATE MAXIMA::FACTS1 MAXIMA::STYO
+            MAXIMA::RATALGDENOM MAXIMA::F1P137TEST
+            MAXIMA::MAXIMA-BRANCH-ACOS MAXIMA::CPBERL MAXIMA::SUMI
+            MAXIMA::$EF_L2N INTL::DOMAIN-ENTRY-ENCODING
+            MAXIMA::ATVARSCHK MAXIMA::TRP-MGREATERP MAXIMA::NPLUS
+            MAXIMA::POISCDECODE MAXIMA::TR-EXP-TO-DISPLAY
+            MAXIMA::GF-DATA? MAXIMA::DEFSTRUCT1 MAXIMA::GETVARDEGS
+            MAXIMA::ZEROHK MAXIMA::POLYGON-EDGES MAXIMA::RIDOFAB
+            MAXIMA::PFLOATP1 MAXIMA::PARSE-TAY-ARGS1 MAXIMA::$OP
+            MAXIMA::TANSC MAXIMA::UNTREE1 MAXIMA::FLOATTOFP
+            MAXIMA::NONZERP MAXIMA::$NEWCONTEXT MAXIMA::ARRAYFUN-MODE
+            MAXIMA::FP2FLO MAXIMA::TOTIENT-BY-FS-N MAXIMA::CHEBYS12
+            MAXIMA::EF-PRIM-P MAXIMA::RDIS*
+            MAXIMA::SIMPNCT-ASSUMESCALARP MAXIMA::ASKSIGN
+            MAXIMA::DELIM-ERR MAXIMA::CHECK-RANGE MAXIMA::TSBASE-COMB
+            MAXIMA::MMMINUSP MAXIMA::PFACTOR11
+            GETOPT::IS-OPTION-TERMINATOR MAXIMA::TRUEP
+            MAXIMA::TAY-ORDER MAXIMA::TRP-NOT MAXIMA::EF-GF-FIELD?
+            MAXIMA::CRECIP MAXIMA::BOX-LABEL MAXIMA::BIQUADRATICP
+            MAXIMA::$EF_MINIMAL_SET MAXIMA::DPREP MAXIMA::PSLOG-MONOM
+            MAXIMA::MAXIMA-BRANCH-ASIN MAXIMA::TRP-MAND MAXIMA::NBN
+            MAXIMA::BX**N+A MAXIMA::$EF_TRACE MAXIMA::LI-ORD
+            MAXIMA::$MAPATOM MAXIMA::LI2SIMP MAXIMA::EF-DATA-FSX-BASE-Q
+            MAXIMA::PSFIND-S1 MAXIMA::EXECARGMATCH MAXIMA::DPROG
+            MAXIMA::VRSHFT-SL MAXIMA::DENOMFIND MAXIMA::SIGN-MTIMES
+            MAXIMA::C*LOGS MAXIMA::LAB MAXIMA::MAKE-VAR-SET
+            MAXIMA::IND2 MAXIMA::MACSYMA-TRACE MAXIMA::GF-NP2SMOD
+            MAXIMA::PCONTENTZ MAXIMA::ASKSIGN1 MAXIMA::CONSTA
+            MAXIMA::LGCSORT MAXIMA::LIN-MPLUS MAXIMA::SIGNDIFF
+            MAXIMA::GF-NRT-EXIT MAXIMA::MRING-P MAXIMA::APPRSYS
+            MAXIMA::AIRY-DBI MAXIMA::FEXPRCHECK MAXIMA::NFORMAT-ALL
+            MAXIMA::SIMPLIMTIMES MAXIMA::PARSE-TAY-ARGS2
+            MAXIMA::REM-CONST MAXIMA::RATMINUS MAXIMA::NONEG
+            MAXIMA::PREMTERM-ERR MAXIMA::2PIREC
+            MAXIMA::BFLOAT-EXPINTEGRAL-LI MAXIMA::TR-ARGS
+            MAXIMA::BIGFLOAT-OR-NUMBER-P MAXIMA::$POLARFORM
+            MAXIMA::FREE1 MAXIMA::SP1LOG2 MAXIMA::TRD-MSYMEVAL-AUX
+            MAXIMA::PFACTORQUAD MAXIMA::SIGN01 MAXIMA::COMPILE-FUNCTION
+            MAXIMA::ERF MAXIMA::NISPERMUTATIONS MAXIMA::RISPLIT-NOUN
+            MAXIMA::EXPONENTIATE MAXIMA::FPEXPM1 MAXIMA::FLMAXL
+            MAXIMA::EXPINTEGRAL-LI MAXIMA::REMSIMP MAXIMA::FACTS2
+            MAXIMA::TAGIRR MAXIMA::FULLSTRIP
+            MAXIMA::ZN-CHARACTERISTIC-FACTORS MAXIMA::%ETOLOG
+            MAXIMA::TELLRATDISP MAXIMA::GETMINOR
+            MAXIMA::EXPINTEGRAL-SHI MAXIMA::MRING-MRING-TO-MAXIMA
+            MAXIMA::EMIT MAXIMA::LOWERHALF MAXIMA::SET-UP-CURSOR
+            MAXIMA::MATCHECK MAXIMA::$COPY MAXIMA::MULTOUT
+            MAXIMA::EVFAC1 MAXIMA::PUTODR MAXIMA::GFSPLIT
+            MAXIMA::TEX-DABBREV MAXIMA::GCDISP MAXIMA::INTEGERPFR
+            MAXIMA::INTERSECT-TESTS MAXIMA::UNQUOTE MAXIMA::MARK
+            MAXIMA::GETFACTORIAL MAXIMA::LIM-IMAGP MAXIMA::MULTIDEG
+            MAXIMA::TM$KILL MAXIMA::UDM-ERR MAXIMA::LMAINVAR
+            MAXIMA::$BATCHLOAD MAXIMA::GF-X2CRE MAXIMA::TMREARRAY
+            MAXIMA::%I-OUT-OF-DENOM MAXIMA::SIGN* MAXIMA::RPOLY-SL
+            MAXIMA::SUB-PRINT* MAXIMA::$EF_NEG MAXIMA::LOFACTORS
+            MAXIMA::EF-NORMAL-P MAXIMA::TDPZ MAXIMA::CHECKLABEL
+            MAXIMA::OFF-NEGATIVE-REAL-AXISP MAXIMA::LGCPLUS
+            MAXIMA::ISUM-GIVEUP MAXIMA::WTPTIMES2 MAXIMA::PDIS*
+            MAXIMA::IR-OR-EXTEND MAXIMA::E1- MAXIMA::AXESOPTIONP
+            MAXIMA::FREE-LISP-VARS-M-TLAMBDA&ENV
+            MAXIMA::MRING-RECIPROCAL MAXIMA::CONDENSESUBLIST
+            MAXIMA::SIGN-PREP MAXIMA::$RATNUMP MAXIMA::POINTTYPEP
+            MT19937:RANDOM-CHUNK MAXIMA::SPC2
+            MAXIMA::OUTPUT-LINEAR-ONE-LINE MAXIMA::FPFORMAT
+            MAXIMA::MRING-FZEROP MAXIMA::MDEFPARAM MAXIMA::SORTGREAT
+            MAXIMA::INCR1 MAXIMA::TRFAIL MAXIMA::EXTRACTVARS
+            MAXIMA::FPSQRT MAXIMA::PWEIGHT MAXIMA::DET
+            MAXIMA::MAKE-VALUES MAXIMA::COSBIGFLOAT MAXIMA::$DISTRIB
+            MAXIMA::MAXLIST MAXIMA::PRINT-INVERT-CASE
+            MAXIMA::MOPSTRINGNAM MAXIMA::RIGHT-OB MAXIMA::FXSHFR-SL
+            MAXIMA::$SIXTH MAXIMA::ATANBIGFLOAT MAXIMA::NEWGCDL
+            MAXIMA::RDIS MAXIMA::TEXMDO MAXIMA::M2-EXP-TYPE-5-1
+            MAXIMA::PGATH3 MAXIMA::DECL-REALP MAXIMA::MRING-ADD
+            MAXIMA::PARSE-CONDITION MAXIMA::CHECKENCODE MAXIMA::PSCONST
+            MAXIMA::OLDCONTENT MAXIMA::RISPLIT-TIMES MAXIMA::$SIGN
+            MAXIMA::|:SPREAD| MAXIMA::COVERSINEMYFOOT MAXIMA::RI-HI
+            MAXIMA::EXPLODEC MAXIMA::XAPPEND
+            MAXIMA::MAKE-EQUAL-HASH-TABLE MAXIMA::INTSET1
+            MAXIMA::EF-DATA-FSX MAXIMA::$RATDISREP MAXIMA::TRUE*
+            MAXIMA::DSRL MAXIMA::RATDP MAXIMA::PARSE-ELEVATION
+            MAXIMA::EF-DATA-ORD MAXIMA::D-SUMSIGN MAXIMA::$SETP
+            MAXIMA::SOLVE2 MAXIMA::SIMPINF-PLUS
+            MAXIMA::EXPINTEGRAL_SHI-TO-HYPERGEOMETRIC MAXIMA::$SECOND
+            MAXIMA::PLSOLVE MAXIMA::MMACROEXPAND MAXIMA::EF-DLOG
+            MAXIMA::EXPINTEGRAL_SI-TO-HYPERGEOMETRIC MAXIMA::CUNMRK
+            MAXIMA::SPABS MAXIMA::COMBINE MAXIMA::$CSIGN
+            MAXIMA::M2-EXP-TYPE-9-1 MAXIMA::FPART MAXIMA::MAKPOINT
+            MAXIMA::FUNGEN&ENV-FOR-MEVAL-AUX MAXIMA::UNION-VAR-SET
+            MAXIMA::FLOAT-NAN-P MAXIMA::SP1LOG MAXIMA::ASINTF
+            MAXIMA::MACSYMA-SPECIAL-MACRO-P MAXIMA::FUNCTION-MODE
+            MAXIMA::LEFT-OB MAXIMA::PARSE-$DO MAXIMA::NODEP
+            MAXIMA::FPENTIER MAXIMA::CFEXPAND MAXIMA::KEY-VAR-POW
+            MAXIMA::MAPTR-LISP->LISP MAXIMA::SIGN-MABS
+            MAXIMA::DONTFACTOR MAXIMA::INITIALIZERSMOSTLY MAXIMA::SRRAT
+            MAXIMA::DIVISORS MAXIMA::SQRT1+X^2 MAXIMA::STRSYM
+            MAXIMA::TEX-RBP CL-INFO::ENSURE-INFO-TABLES
+            MAXIMA::LIM-PLUSP MAXIMA::SUM-OF-INTSP
+            MAXIMA::GET-TEX-ENVIRONMENT MAXIMA::TRIGP
+            MAXIMA::TC-STATE-P MAXIMA::HIDE MAXIMA::KDR
+            MAXIMA::%PIARGS-OFFSET MAXIMA::IREDUP MAXIMA::SIGN1
+            MAXIMA::BERN MAXIMA::FIND-TLISTS MAXIMA::RATMIN
+            MAXIMA::LEADTERM MAXIMA::$LISTP MAXIMA::LOGMABS
+            MAXIMA::PARTFRACA MAXIMA::PARSE-MATCHFIX
+            MAXIMA::EXPINTEGRAL-CHI MAXIMA::CHOOZP MAXIMA::DPDISREP
+            MAXIMA::REVSIGN MAXIMA::UPRIMITIVE MAXIMA::IS-MOR
+            MAXIMA::MUNBIND MAXIMA::EXP-C*LOGS MAXIMA::TREEDET
+            MAXIMA::CONSRULE MAXIMA::FPSINH MAXIMA::COSNX
+            MAXIMA::GF-NXX2X MAXIMA::PIRREDP MAXIMA::PSFLOAT
+            MAXIMA::GF-DATA-CARD MAXIMA::SP2LOG MAXIMA::IS-BOOLE-CHECK
+            MAXIMA::$NZETAI MAXIMA::FPPOSP MAXIMA::TDPOS
+            MAXIMA::$IFACTORS MAXIMA::D-INTEGRALSIGN
+            MAXIMA::SUMCONTRACT1 MAXIMA::DRAW2D-DISCRETE
+            MAXIMA::BF-RPOLY-SL MAXIMA::GET-LISP-FUN-TYPE
+            MAXIMA::LISTARRAY MAXIMA::MINLIST MAXIMA::OPFORMAT
+            MAXIMA::KILL-OPERATOR MAXIMA::AIRY-BI MAXIMA::RAT10
+            MAXIMA::SUBC-INTERNAL MAXIMA::$EF_L2P
+            MAXIMA::MACSYMA-NAMESTRING-SUB MAXIMA::INVERT-TERMS
+            GETOPT::IS-SHORT-OPTION MAXIMA::$BFLOATP
+            MAXIMA::GET-FACTOR-LIST MAXIMA::SINNX
+            MAXIMA::SIMPNCT-SC-OR-CONST-P MAXIMA::$EF_N2P
+            MAXIMA::SUBFUNSUBS MAXIMA::FACTORALG
+            MAXIMA::EXPINTEGRAL_CHI-TO-HYPERGEOMETRIC MAXIMA::SYMBOLS
+            MAXIMA::%TO$ MAXIMA::SEMANT MAXIMA::LOWDEG MAXIMA::LNEWVAR
+            MAXIMA::INCRLIMK MAXIMA::POLE-ERR MAXIMA::GET-GNUPLOT-TERM
+            MAXIMA::$NEWDET MAXIMA::MSPECFUNP MAXIMA::NUMDEN*
+            MAXIMA::ATOMSON MAXIMA::FALSEP MAXIMA::M2-LOG-EXP-1
+            MAXIMA::MAXIMA-RATIONALIZE MAXIMA::$TENTH MAXIMA::DINTERN
+            MAXIMA::RISCH-PCONSTP MAXIMA::SPECIALP MAXIMA::SLASH
+            MAXIMA::FPCOFRAT MAXIMA::GF-DATA-CHAR MAXIMA::$ASKSIGN
+            MAXIMA::PACOEFP MAXIMA::SIMPLEXPON MAXIMA::M2-EXP-TYPE-1A
+            MAXIMA::PCONTENT MAXIMA::DATUM MAXIMA::FUNCLOGOR%E
+            MAXIMA::SPC7 MAXIMA::COUNT-GENERAL-INF MAXIMA::PFACPROD
+            MAXIMA::MRING-PSQRT MAXIMA::INIT-LAMBERT-W-0
+            MAXIMA::NONINTEGERP MAXIMA::COMPLEXITY MAXIMA::POLYINT2
+            MAXIMA::TDZERO MAXIMA::POLYGON-PTS MAXIMA::FASTCONT
+            MAXIMA::MONOM->FACL MAXIMA::FORQ MAXIMA::SIGNSUM
+            MAXIMA::CFACTORW MAXIMA::SQRTX^2-1 MAXIMA::$RATNUMER
+            MAXIMA::FPMINUS MAXIMA::OPERATOR-WITH-ARRAY-FLAG
+            MAXIMA::BF-VRSHFT-SL MAXIMA::ALGSYS0 MAXIMA::ABLESS1
+            MAXIMA::TR-LISP->LISP-DEFAULT MAXIMA::ILT0 MAXIMA::DEFC
+            MAXIMA::ARCLIST MAXIMA::OBJECT-FOR-DISPLAY-HACK
+            MAXIMA::NEG-MONOM? MAXIMA::PDISREP+
+            CL-INFO::EXACT-TOPIC-MATCH MAXIMA::PFACTOR
+            MAXIMA::CHECKED-OR MAXIMA::EXPPOLY MAXIMA::*RED1
+            MAXIMA::ABSARG1 MAXIMA::SUBVARDLG MAXIMA::EF-DATA-FS-ORD
+            MAXIMA::SUPERTRIG MAXIMA::DEFSTRUCT-TRANSLATE
+            MAXIMA::TRANSLATE-PREDICATE MAXIMA::M2-A*X+B/C*X+D
+            MAXIMA::NMTERMS MAXIMA::TVAR-LIM MAXIMA::$REALPART
+            MAXIMA::BX**N MAXIMA::SRCONVERT1 MAXIMA::PGATH1
+            MAXIMA::$SCALED_BESSEL_I1 MAXIMA::M2-EXP-TYPE-5
+            MAXIMA::DEFINITELY-SO MAXIMA::STRIPTIMES MAXIMA::HYP-NEGP
+            MAXIMA::BEYOND-EXTREME-VALUES MAXIMA::SETUP-MULTIVAR-DISREP
+            MAXIMA::RMCONST1 MAXIMA::JOINVARLIST MAXIMA::FACTXN+-1
+            COMMAND-LINE::CL-OPTION-NAMES MAXIMA::LISTOVARS0
+            MAXIMA::INSERT-BREAK-POINT MAXIMA::PRLAB
+            MAXIMA::GF-DATA-FSX-BASE-P MAXIMA::GAMMA-LANCZOS
+            MAXIMA::PRODND MAXIMA::ADJOIN-SING-DATUM MAXIMA::TEX-SETUP
+            MAXIMA::FOR-EVAL-THEN-MQUOTE-SIMP-ARGL MAXIMA::FIXUPREST
+            MAXIMA::CONSTLAM MAXIMA::TC-STATE-MULTIPLY-TABLE
+            MAXIMA::GF-L2X MAXIMA::ONEP MAXIMA::PREP1
+            MAXIMA::MGENARRAY-P MAXIMA::FACT5MOD MAXIMA::GETLABCHARN
+            MAXIMA::ILT3 MAXIMA::$THIRD MAXIMA::FIXNUMP
+            MAXIMA::COMPLEX-ERF MAXIMA::1P MAXIMA::ESTCHECK
+            MAXIMA::FPEND MAXIMA::LENIENT-REALP MAXIMA::HIDELIMA
+            MAXIMA::FIND-STREAM MAXIMA::ADD-LINEINFO MAXIMA::IS
+            MAXIMA::LINE-INFO-LINE MAXIMA::$LAST MAXIMA::PCONSTP
+            MAXIMA::BKPT-FORM MAXIMA::LGCSIMPLEP MAXIMA::PRIMEP-PROB
+            MAXIMA::LOGBIGFLOAT MAXIMA::CONDENSE MAXIMA::REPLIST1
+            MAXIMA::AIRY-DBI-COMPLEX MAXIMA::SERIESEXPAND*
+            MAXIMA::$LABELS MAXIMA::$ODDP MAXIMA::OP-SETUP
+            MAXIMA::RISCH-CONSTP MAXIMA::POISCHANGESIGN
+            MAXIMA::RGB-COLOR MAXIMA::RCONTENT
+            MAXIMA::MAXIMA-UNDECLARED-ARRAYP MAXIMA::ROOTFAC
+            MAXIMA::MAXIMA-BRANCH-ACOT MAXIMA::DCONV-$FLOAT
+            MAXIMA::$MINFACTORIAL MAXIMA::GETOP MAXIMA::APROG
+            MAXIMA::INTP MAXIMA::DEFA MAXIMA::FIXINTGREAT
+            MAXIMA::SAVEFACTOR1 MAXIMA::KAAR MAXIMA::$REVERSE
+            MAXIMA::DENOM1 MAXIMA::COMPLICATED MAXIMA::$FIFTH
+            MAXIMA::HASHER MAXIMA::TOPLEVEL-OPTIMIZE MAXIMA::DSKRAT
+            MAXIMA::$RANDOM MAXIMA::INTEGER-BELLN
+            MAXIMA::I-$DEPENDENCIES MAXIMA::TRIG2
+            MAXIMA::ORDER-VARS-BY-STRENGTH MAXIMA::LINCHK
+            MAXIMA::TRANSPOSE MAXIMA::GF-X2N MAXIMA::OUT-OF
+            MAXIMA::RISPLIT-EXPT MAXIMA::ONEP1 MAXIMA::ERFTF
+            MAXIMA::PARSE-POINTS-Y MAXIMA::$INTOPOIS MAXIMA::STRING*1
+            MAXIMA::POISCOSINE MAXIMA::COS% MAXIMA::M2-EXP-TYPE-8
+            MAXIMA::PTMINUS MAXIMA::PLOT-FILE-PATH MAXIMA::FASPRIN
+            MAXIMA::BIGFLOAT2RAT MAXIMA::AUGMULT
+            MAXIMA::CHECKFLAGANDACT MAXIMA::RATMAX MAXIMA::TDNEG
+            MAXIMA::M$EXP? MAXIMA::MACSYMA-FSYMEVAL MAXIMA::FRPOLY?
+            MAXIMA::ROOT-2Z/PI MAXIMA::$NOUNIFY MAXIMA::MGENARRAY-AREF
+            MAXIMA::MRING-NEGATE MAXIMA::SCPROD MAXIMA::DET1
+            COMMAND-LINE::CL-OPTION-ARGUMENT MAXIMA::ZIREDUP
+            MAXIMA::PSDISEXTEND MAXIMA::LIM-ZEROP
+            MAXIMA::COMPLEX-BFLOAT-ERF MAXIMA::COMEXP MAXIMA::FPARCSIMP
+            MAXIMA::NISREMLET MAXIMA::$SQFR MAXIMA::$PRIMEP
+            MAXIMA::ALLATOMS MAXIMA::ALGP MAXIMA::MBAGP MAXIMA::ISMAX
+            MAXIMA::MAKCF MAXIMA::VAR-OR-CONST MAXIMA::*FPEXP
+            MAXIMA::UNKNOWN MAXIMA::MEVALP MAXIMA::M*S+C
+            MAXIMA::PLOT-TEMP-FILE MAXIMA::MREDEF-CHECK
+            MAXIMA::MRING-COERCE-TO-LISP-FLOAT MAXIMA::SIGN-SHIFT
+            MAXIMA::TBOUND-FREE-VARS MAXIMA::NUMBERINLISTP
+            MAXIMA::EXPLODEN-FORMAT-FLOAT MAXIMA::ISTRENGTH
+            MAXIMA::MAKSYM MAXIMA::GETVALUE MAXIMA::DPSQFR
+            MAXIMA::LITTLEFR1 MAXIMA::VARSORT MAXIMA::$QUNIT
+            MAXIMA::CHECKSIGNTM MAXIMA::SRF MAXIMA::RISCHFORM
+            MAXIMA::TIMEORG MAXIMA::MQAPPLYP MAXIMA::CONSTTERMP
+            MAXIMA::NEWVARMAT1 MAXIMA::CSTRSETUP MAXIMA::UPPERHALF
+            MAXIMA::$FLATTEN MAXIMA::SPC2B MAXIMA::FPZEROP
+            MAXIMA::RATIONALIZER MAXIMA::PDEGR MAXIMA::M2-EXP-TYPE-2-1
+            MAXIMA::RISCHLOGDPROG MAXIMA::VFVP MAXIMA::SIMPLE
+            MAXIMA::TC-STATE-SUBGROUP-GENERATORS MAXIMA::REMLAPLACE
+            MAXIMA::TR-WARNP MAXIMA::TRP-MGEQP MAXIMA::OLDGCDCALL
+            MAXIMA::ASK-INTEGERP MAXIMA::SINRX MAXIMA::STRPRINT
+            MAXIMA::$SCALED_BESSEL_I0 MAXIMA::SCAN-TOKEN
+            MAXIMA::$EF_INV MAXIMA::*KAR MAXIMA::$LENGTH
+            MAXIMA::TEXNUMFORMAT MAXIMA::CONSSIZE MAXIMA::MAKSYMP
+            COMMAND-LINE::CL-OPTION-P MAXIMA::PMODROOT MAXIMA::FINDIT
+            MAXIMA::FACTXN-1 MAXIMA::MLOGP MAXIMA::FACTORNUMBER
+            MAXIMA::TAYLOR2 MAXIMA::MARGS MAXIMA::PRINCIP
+            MAXIMA::SIN-SQ-COS-SQ-SUB CL-INFO::REGEX-SANITIZE
+            MAXIMA::META-OUTPUT MAXIMA::DISPMATCHDECLARES MAXIMA::TSLOG
+            MAXIMA::TRANSLATE-MACEXPR-TOPLEVEL MAXIMA::REMOVEALG
+            MAXIMA::EULER MAXIMA::CPTIMESX MAXIMA::CFSQRT
+            MAXIMA::OPTIONS MAXIMA::TEXMDOIN MAXIMA::RISCHLOGPOLY
+            MAXIMA::EPS-SIGN MAXIMA::LOGTF MAXIMA::$GF_NORMAL_BASIS
+            MAXIMA::GF-SQUARE-FREE MAXIMA::OPTIM MAXIMA::TESTTNEG
+            MAXIMA::LEADCOEFFICIENT MAXIMA::FACTORSUM1 MAXIMA::MAXI
+            MAXIMA::AIRY-DAI-COMPLEX MAXIMA::PSPLIT-FIELD
+            MAXIMA::TMS-FORMAT-PRODUCT MAXIMA::REMOVE-BINDINGS
+            MAXIMA::$EF_UNIT_P MAXIMA::ELABEL
+            MAXIMA::MAKE-DEFINT-ASSUMPTIONS MAXIMA::STOTALDIFF
+            MAXIMA::CALLAPPRS MAXIMA::FINDBE MAXIMA::FINDP
+            MAXIMA::MEQHK MAXIMA::HYPGEO-EXEC
+            MAXIMA::START-GNUPLOT-PROCESS MAXIMA::SIMPLEXP
+            MAXIMA::PTIMEFTRS MAXIMA::TYOTBSP MAXIMA::POISSUBSTCO1
+            MAXIMA::CHECK-OPTION-STYLE MAXIMA::GF-DATA-EXP
+            MAXIMA::PSP2FOLDSUM MAXIMA::PMINDEGVEC MAXIMA::MULTFACT
+            MAXIMA::SPC2A MAXIMA::FPASIN-CORE MAXIMA::MMINUSP*
+            MAXIMA::GET-RANGE MAXIMA::STURM MAXIMA::$GF_INDEX
+            MAXIMA::RATBIGFLOAT MAXIMA::IMAG-ERR MAXIMA::TEVAL
+            MAXIMA::PDECGDFRM CL-INFO::DISPLAY-ITEMS MAXIMA::NUMP
+            MAXIMA::RATDENOMINATOR MAXIMA::PUSH-PRE-TRANSL-FORM
+            MAXIMA::TEX-STRIPDOLLAR MAXIMA::LET-MACRO-GET-LAST-VAR
+            MAXIMA::SUPC-INTERNAL MAXIMA::CFDISREP1 MAXIMA::TEXWORD
+            MAXIMA::EF-DATA-EXP MAXIMA::RHALF MAXIMA::ALGNORMAL
+            MAXIMA::$FIB MAXIMA::FORWARD MAXIMA::AIRY-DAI MAXIMA::LPOS
+            MAXIMA::$TMINVERSE MAXIMA::SER1 MAXIMA::TC-STATE-RELATIONS
+            MAXIMA::IMODP MAXIMA::EVERYSECOND MAXIMA::CFEVAL
+            MAXIMA::GET-ROTATION MAXIMA::PARTITION-PRODUCT
+            MAXIMA::GF-ADD-TABLE MAXIMA::COLLAPSE MAXIMA::KILLCONTEXT
+            MAXIMA::PSEXPT-LOG-ORD MAXIMA::ALG MAXIMA::SIMPLERD
+            MAXIMA::$POISSQUARE MAXIMA::TR-LISP->LISP-FUN
+            MAXIMA::FULLSTRIP1 MAXIMA::STURMOUT MAXIMA::EF-DATA-P
+            MAXIMA::INTEGERP1 MAXIMA::POLYFORM MAXIMA::REMABS
+            MAXIMA::MABSBIGFLOAT MAXIMA::MAKPROD1 MAXIMA::CONSTP
+            MAXIMA::PROC-$MATCHDECLARE MAXIMA::MAXCOEF MAXIMA::RULECHK
+            MAXIMA::RE-TAYLOR MAXIMA::TSTIMES-L-MULT MAXIMA::RADCAN1
+            MAXIMA::PUTORDER MAXIMA::TRP-$EQUAL MAXIMA::M2-EXP-TYPE-10
+            MAXIMA::$EIGHTH MAXIMA::ERROR-SIZE
+            MAXIMA::GET-LARGE-FACTORS-1 MAXIMA::TRANSLATE-$MAX-$MIN
+            MAXIMA::GF-P2X MAXIMA::MAXIMA-DECLARED-ARRAYP
+            MAXIMA::SCALARCLASS MAXIMA::TSPLUS
+            MAXIMA::$EF_PRIMITIVE_POLY_P MAXIMA::MFBOUNDP
+            MAXIMA::PSFIND-S MAXIMA::DISP2 MAXIMA::FREEVNZ
+            MAXIMA::MAKSTRING MAXIMA::TSTACK-SLOT-VAL-MODES
+            MAXIMA::RETLIST-AUX MAXIMA::GET-ONE-FACTOR
+            MAXIMA::GF-CJACOBI MAXIMA::LISTOVARS1 MAXIMA::%EINVOLVE
+            MAXIMA::AIRY-AI-COMPLEX MAXIMA::RDIS1 MAXIMA::NRETFACTOR1
+            MAXIMA::SPLITPROD MAXIMA::%ESPECIAL MAXIMA::TVAR?
+            MAXIMA::PCOEFVEC MAXIMA::DCONVX
+            MAXIMA::LENIENT-EXTENDED-REALP MAXIMA::ARCP
+            MAXIMA::COMBINEY MAXIMA::REPLIST MAXIMA::PREPFLOAT
+            MAXIMA::BIGFLOATP MAXIMA::REMOV MAXIMA::GETOPR
+            MAXIMA::M2-RATROOTFORM MAXIMA::GEN-TR-LAMBDA
+            MAXIMA::TMDEFARRAY MAXIMA::$GF_UNIT_P MAXIMA::EF-FIELD?
+            MAXIMA::$NUMFACTOR MAXIMA::RAT1 MAXIMA::LEADALGCOEF
+            MAXIMA::COMBINEY1 MAXIMA::TRACEMOD MAXIMA::SP2TRIG
+            MAXIMA::GETUNHACK MAXIMA::FACTCOMB1 MAXIMA::BFLOAT-ERF
+            MAXIMA::$ZN_CHARACTERISTIC_FACTORS MAXIMA::MIDPNT
+            MAXIMA::CHECK1 MAXIMA::PRIMEP MAXIMA::BIQUADP1
+            MAXIMA::TOTIENT-WITH-FACTORS MAXIMA::$GF_PRIMITIVE_P
+            MAXIMA::OBTAINABM MAXIMA::SKR MAXIMA::LINEARIZE
+            MAXIMA::M2-EXP-TYPE-9 MAXIMA::TRANSLATE
+            MAXIMA::FACTCOMBPLUS MAXIMA::FPROUND MAXIMA::GETFACT
+            MAXIMA::POLYP MAXIMA::BFLOAT-EXPINTEGRAL-SI MAXIMA::R1M
+            MAXIMA::$RATP MAXIMA::HAS-INT-SYMBOLS MAXIMA::PSP2FORMP
+            MAXIMA::TEX-STRIPDOLLAR0 MAXIMA::$PREV_PRIME SYSTEM:CMOD
+            MAXIMA::MRING-MULT-ID MAXIMA::NISKERNEL
+            MAXIMA::TOTIENT-FROM-FACTORS MAXIMA::$CFEXPAND
+            MAXIMA::FACTORIAL MAXIMA::MAXIMA-STRING MAXIMA::OLDCONTENTA
+            MAXIMA::FMT MAXIMA::PSQFR MAXIMA::MTIMESP MAXIMA::DEG
+            MAXIMA::INFSIMP* MAXIMA::HASVAR MAXIMA::ROOTSORT
+            MAXIMA::CHECKDERIV MAXIMA::RADSORT MAXIMA::TRIGFREE
+            MAXIMA::TRP-MNOT MAXIMA::NISLETSIMPRAT MAXIMA::FACTOROUT
+            MAXIMA::FPROG MAXIMA::TDPN MAXIMA::PQR MAXIMA::FANCYPAS
+            MAXIMA::M2-EXP-TYPE-7 MAXIMA::MMACROEXPAND1
+            MAXIMA::BFLOAT-EXPINTEGRAL-CI MAXIMA::MRING-ADD-ID
+            MAXIMA::MFACPPLUS MAXIMA::MGENARRAY-NULL MAXIMA::IS-MAND
+            MAXIMA::SIMPLIM%ATAN MAXIMA::$PRINTFILE MAXIMA::ZERP
+            MAXIMA::PFACTOR1 MAXIMA::DISTREXPANDROOT MAXIMA::NPASK
+            MAXIMA::$THROW MAXIMA::POISMAP MAXIMA::NISNEWLIST
+            MAXIMA::RTC-GETINFO MAXIMA::MAKELABEL MAXIMA::KELLIPTICTF
+            MAXIMA::$TRUNC MAXIMA::HLINSOLVE MAXIMA::DDIV
+            MAXIMA::BIGNUMP MAXIMA::SIGN-POSFUN MAXIMA::SEPARC
+            MAXIMA::MOPSTRIP MAXIMA::EVTILDEGLESS MAXIMA::MGEN2
+            MAXIMA::MRING-SUB MAXIMA::PSDP MAXIMA::POLYINT
+            MAXIMA::NOTLOREQ MAXIMA::PTERMVEC MAXIMA::NORM
+            MAXIMA::BF-FXSHFR-SL MAXIMA::PSPLIT-FIELD1
+            MAXIMA::UNPARSE-TYI MAXIMA::COMPLEXIFY MAXIMA::EXACTONLY
+            MAXIMA::ISP MAXIMA::M2-EXP-TYPE-4-1 MAXIMA::FACTOR-IF-SMALL
+            MAXIMA::MACSYMA-FSYMEVAL-SUB MAXIMA::POSIZE
+            COMMAND-LINE::CL-OPTION-ACTION CL-INFO::INEXACT-TOPIC-MATCH
+            MAXIMA::ERRLFUN1 MAXIMA::$FILE_TYPE
+            MAXIMA::DISTINCT-NONZERO-ROOTS-P MAXIMA::$SEVENTH
+            MAXIMA::TMEVAL MAXIMA::P1 MAXIMA::M2-EXP-TYPE-6-1
+            MAXIMA::MGENARRAY-GENERATOR MAXIMA::$EF_INDEX MAXIMA::TRIG1
+            MAXIMA::GF-NORMAL-P MAXIMA::TELLRAT1 MAXIMA::MAXNORM
+            MAXIMA::TAYLOR-INFO MAXIMA::$ISQRT MAXIMA::RATNUMERATOR
+            MAXIMA::EXLIST MAXIMA::SIN-COS-INTSUBS1 MAXIMA::PORDER
+            MAXIMA::RISCHFPROG MAXIMA::FILESTRIP MAXIMA::TBIND
+            MAXIMA::LIMINV MAXIMA::NEGP MAXIMA::QUOTED-SYMBOLP
+            MAXIMA::M2-EXP-TYPE-7-1 MAXIMA::NEWPRIME MAXIMA::EVOD
+            MAXIMA::PARSE-NOFIX MAXIMA::INITIALIZE-NUMERIC-CONSTANT
+            MAXIMA::$PATHNAME_TYPE MAXIMA::PTDERIVATIVE
+            MAXIMA::POISENCODE MAXIMA::LCPRODL
+            MAXIMA::SIMPLIFY-LOG-OF-EXP MAXIMA::ROOT-BOUND
+            MAXIMA::PSEXPT-FN2 MAXIMA::$ROTATE_LIST MAXIMA::MSYMBOLP
+            MAXIMA::OPTIONP MAXIMA::RZCONTENT MAXIMA::CFACTOR
+            MAXIMA::RAINV MAXIMA::$TAYLORINFO MAXIMA::ERRBREAK1
+            MAXIMA::DROPTERMS MAXIMA::TRANSLATE-ATOM MAXIMA::GOOD-FORM
+            MAXIMA::ADDLABEL MAXIMA::NRATFACT MAXIMA::MOP
+            MAXIMA::GENEXPANDS MAXIMA::MAYBE-BOOLE-CHECK
+            MAXIMA::MRECORD-KILL MAXIMA::HYP-NEGP-IN-L
+            MAXIMA::LOGCONCOEFFP MAXIMA::FORTSCAN-MTIMES
+            MAXIMA::%EINVOLVE01 MAXIMA::$FLOATNUMP MAXIMA::BF-CPOLY-ERR
+            MAXIMA::LINE-INFO-FILE MAXIMA::SPC4 MAXIMA::KILL1-ATOM
+            MAXIMA::UNMRKS MAXIMA::CHECK-OPTION-FORMAT
+            MAXIMA::DISPATVALUES MAXIMA::CHECK-NONINTEGER-FACTS
+            MAXIMA::MEVALP1 MAXIMA::ZEROLP MAXIMA::MAXIMA-INTEGERP
+            MAXIMA::TMACCESS MAXIMA::$GF_NORM MAXIMA::TEX-LBP
+            MAXIMA::INVERTBIGFLOAT MAXIMA::I-$REMOVE MAXIMA::MYCABS
+            MAXIMA::I-$GRIND MAXIMA::ORDER-LIMITS MAXIMA::NUM-OF-LOG-L
+            MAXIMA::EXPINTEGRAL_CI-TO-HYPERGEOMETRIC
+            MAXIMA::PARTITION-NS MAXIMA::POISNEGPRED MAXIMA::SOLVECASE
+            MAXIMA::$COPYLIST MAXIMA::$FOURTH MAXIMA::DECREMENT-TRUNCS
+            MAXIMA::CHECK-OPTION-TRANSFORM
+            MAXIMA::FREE-LISP-VARS-M-TLAMBDA MAXIMA::GF-RED?
+            MAXIMA::LIM-ABS MAXIMA::GAMMAFLOAT MAXIMA::FMP1
+            MAXIMA::FINDTL1 MAXIMA::BF-CPOLY-SL MAXIMA::FXSHFT-SL
+            MAXIMA::POFX MAXIMA::MANIFESTLY-NONREAL-P
+            MAXIMA::MAKESTRING MAXIMA::MEXPTP MAXIMA::MHEADER
+            MAXIMA::MRING-NAME MAXIMA::RE-TAYLOR-RECURSE
+            MAXIMA::$DIRECTORY MAXIMA::SIMPNCT-POWER MAXIMA::NUMDEN
+            MAXIMA::MPLUSP MAXIMA::PMODROOT1 MAXIMA::REMCOMPARY
+            MAXIMA::EF-DATA-PRIM MAXIMA::DELETMULT
+            MAXIMA::MGENARRAY-CONTENT MAXIMA::MEVENP MAXIMA::EF-RED?
+            MAXIMA::$GF_SET_AGAIN MAXIMA::HYP-INTEGERP MAXIMA::MSETQP
+            MAXIMA::ABEQ1 MAXIMA::ODNUMP MAXIMA::CONJUGATE-MEXPT
+            MAXIMA::PARSE-POINTS-XY MAXIMA::ENSURE-STRING
+            MAXIMA::$IDENTITY MAXIMA::$ARGS MAXIMA::PS-LIM-INFP
+            MAXIMA::POS MAXIMA::PNEXT1 MAXIMA::ECHELON1
+            MAXIMA::FORM-MPLUS MAXIMA::EXPINTEGRAL-SI MAXIMA::MEMQARGS
+            MAXIMA::TOPLEVEL-MACSYMA-EVAL
+            MAXIMA::POSSIBLE-PREDICATE-OP-P
+            MAXIMA::PRODUCT-WITH-INNER-SCALARP MAXIMA::DOT2L
+            MAXIMA::TEXSYM MAXIMA::TESTT MAXIMA::BKPT-FILE
+            MAXIMA::PSUMSQ MAXIMA::SIMPNCT-CONSTANTP
+            MAXIMA::TRANSLATOR-EVAL MAXIMA::SOME-BFLOATP
+            MAXIMA::NATURALP MAXIMA::GETFNSPLIT MAXIMA::MRING-GREAT
+            MAXIMA::MRING-ADJOINT MAXIMA::GF-DATA-RED MAXIMA::SRDIS
+            MAXIMA::FREEVAR0 MAXIMA::OPERATORP MAXIMA::NONPERIOD
+            MAXIMA::ORDERPOINTER MAXIMA::$EF_NORMAL_P MAXIMA::MOPP1
+            MAXIMA::LISTOF0S MAXIMA::ADDMLIST MAXIMA::MODDP
+            MAXIMA::LNEWVAR1 MAXIMA::RAT8PRIME MAXIMA::PAINVMOD
+            MAXIMA::CHECKED-AND MAXIMA::MNCTIMESP MAXIMA::COEFL
+            MAXIMA::FPCOS1 MAXIMA::STRIPDOLLAR
+            CL-INFO::PARSE-USER-CHOICE MAXIMA::FPINTPART
+            MAXIMA::TIMESTEST MAXIMA::MACSYMA-UNTIMER MAXIMA::$TAYLORP
+            MAXIMA::$EMPTYP MAXIMA::RISPLIT-MPLUS MAXIMA::FPCONTENT
+            MAXIMA::ORD-VECT1 MAXIMA::COMPATTLIST MAXIMA::ADJOIN-DATUM
+            MAXIMA::EVEN MAXIMA::IMPLIED-QUOTEP MAXIMA::LEADING-COEF
+            MAXIMA::MAKE-LINSOLS MAXIMA::FPASINH MAXIMA::MAKRAT
+            MAXIMA::$SCALARP MAXIMA::POLFACTORS MAXIMA::CABS
+            MAXIMA::ATANTF MAXIMA::FUNCTIONP MAXIMA::NISLETSIMP
+            MAXIMA::BBSORTEQNS MAXIMA::MGENARRAY-ASET
+            MAXIMA::ASCII-NUMBERP MAXIMA::MNLOG MAXIMA::SINBIGFLOAT
+            MAXIMA::DPDERIV MAXIMA::POWER-SET MAXIMA::INFOLSTCHK
+            MAXIMA::REMC MAXIMA::MXORLISTP1 MAXIMA::$NINTH
+            MAXIMA::NEWREP MAXIMA::SRCONVERT MAXIMA::FINDSIGNOFACTORS
+            MAXIMA::BAD-VAR-WARN MAXIMA::EXTENDED-NUMBER-P
+            MAXIMA::TANBIGFLOAT MAXIMA::LI3NUMER MAXIMA::FREEPAR
+            MAXIMA::CREATSYM MAXIMA::FORTSCAN MAXIMA::LEADARG
+            MAXIMA::NAMESONLY MAXIMA::MSTRING MAXIMA::REDUCE-VAR-SET
+            MAXIMA::NONNEGATIVE-INTEGERP MAXIMA::MACSYMA-TIMER
+            MAXIMA::RATFIX BIGFLOAT::INTOFP MAXIMA::WNA-ERR
+            MAXIMA::LIN-MTIMES MAXIMA::FINDIBASE MAXIMA::MNCEXPTP
+            MAXIMA::CYCLIC-P MAXIMA::PTERMCONT MAXIMA::HORNREP
+            MAXIMA::THRAD MAXIMA::RATION1 MAXIMA::ALIASLOOKUP
+            MAXIMA::PMODCONTENT MAXIMA::MAYBE-REALPART
+            MAXIMA::PS-INVERT-VAR MAXIMA::F1P137 MAXIMA::POLY->PS
+            MAXIMA::ZEROP2 MAXIMA::PRINT* MAXIMA::$IDENT
+            COMMAND-LINE:LIST-CL-OPTIONS MAXIMA::FLOAT-OR-RATIONAL-P
+            MAXIMA::GF-DATA-X^P-POWERS MAXIMA::CPOLY-ERR
+            MAXIMA::CRECIP-GENERAL MAXIMA::NISEXTRACT MAXIMA::REMORDER
+            MAXIMA::BKPT-FILE-LINE MAXIMA::ZEROEQUIV2 MAXIMA::CHEBYLI2
+            MAXIMA::FANCYPAC MAXIMA::REMPROPCHK MAXIMA::$CARDINALITY
+            MAXIMA::FACTOR72 MAXIMA::FREE-LISP-VARS-OF-ARGL
+            MAXIMA::M2-EXP-TYPE-8-2 MAXIMA::CHECK-INF-SING
+            MAXIMA::MACSYMA-READ-STRING MAXIMA::PUTONVLIST
+            MAXIMA::DOWNS MAXIMA::RATWTSETUP MAXIMA::$TOTIENT
+            MAXIMA::BFLOAT-EXPINTEGRAL-EI MAXIMA::RENUMBER-TLIST
+            MAXIMA::$PERMANENT MAXIMA::CMNULL MAXIMA::$INTEGERP
+            MAXIMA::FLIP MAXIMA::TMMAXP MAXIMA::$FULLSETIFY
+            MAXIMA::DISREP MAXIMA::TAYLOR-TRUNC MAXIMA::GF-DATA-ORD
+            MAXIMA::FORM-MTIMES MAXIMA::*DEFINE-INITIAL-SYMBOLS
+            MAXIMA::PABS MAXIMA::SIMPLIM%TAN MAXIMA::MNEGP
+            MAXIMA::SIGN-LOG MAXIMA::EF-PTH-CROOT MAXIMA::DOING-ROW
+            MAXIMA::FACTPLUSCOMB MAXIMA::MEQUALP MAXIMA::PARSE-BUG-ERR
+            MAXIMA::MODEDECLARE-INTERNAL MAXIMA::LISTOVARS
+            MAXIMA::OPERATORP1 MAXIMA::TMPIVOT-ISOLATE
+            MAXIMA::ALGCONTENT MAXIMA::CONSTCOEF MAXIMA::RTZERL2
+            MAXIMA::GF-L2N MAXIMA::FINDLEASTVAR MAXIMA::EXPP
+            MAXIMA::$GF_L2N MAXIMA::S+C MAXIMA::EVNUMP
+            CL-INFO::INFO-INEXACT MAXIMA::PALGP MAXIMA::DISPRULE1
+            MAXIMA::REALONLY MAXIMA::KILL1 MAXIMA::TUNBINDS
+            MAXIMA::UNTRANS-OP MAXIMA::INFR MAXIMA::NONNUMP
+            MAXIMA::NESTLEV MAXIMA::$ATOM MAXIMA::FPRATION1
+            MAXIMA::PSLOG MAXIMA::P*PIN%EX MAXIMA::MACSYMA-SPECIAL-OP-P
+            MAXIMA::EXPOR1P MAXIMA::INTOPOIS MAXIMA::RBP
+            MAXIMA::MULTIPLY-GCFACTORS MAXIMA::SOLVE-SIMPLIST
+            MAXIMA::TEX-TRY-SYM MAXIMA::$UNIQUE MAXIMA::NISNUMBERPICKER
+            MAXIMA::TRP-MOR MAXIMA::REMOVE-TRANSL-FUN-PROPS
+            MAXIMA::LISTARGP MAXIMA::%E-RIGHT-PLACEP MAXIMA::NNI
+            MAXIMA::SP3RECONST MAXIMA::PATCH-UP-MEVAL-IN-FSET
+            MAXIMA::MRING-DIV MAXIMA::$GFACTORSUM MAXIMA::MENU
+            MAXIMA::SAME MAXIMA::MONIZE MAXIMA::FIXFLOAT
+            MAXIMA::D-PRODSIGN MAXIMA::NEWVAR3 MAXIMA::DBNODE
+            MAXIMA::CFMIN MAXIMA::TR-SEQ MAXIMA::TSTACK-SLOT-TBIND
+            MAXIMA::$NONSCALARP MAXIMA::BFLOAT-EXPINTEGRAL-CHI
+            MAXIMA::GF-DATA-PRIM MAXIMA::MAXIMA-CONSTANTP
+            MAXIMA::RATNUMP MAXIMA::MXC MAXIMA::FACT5 MAXIMA::RI-LO
+            MAXIMA::ATOMVARS MAXIMA::POLYST MAXIMA::OLDREP
+            MAXIMA::$SHOW_HASH_ARRAY MAXIMA::STRMDO MAXIMA::POP-PW
+            MAXIMA::VARIABLE-P MAXIMA::POS-NEG-P MAXIMA::PDIS
+            MAXIMA::DISTREXECINIT MAXIMA::ERRSET-NAMESTRING
+            MAXIMA::DISREPLIST MAXIMA::$IMAGPART
+            MAXIMA::M2-EXP-TYPE-8-1 MAXIMA::PSLOG3 MAXIMA::FPATANH
+            MAXIMA::POSEVEN MAXIMA::READ-COMMAND-TOKEN-AUX
+            MAXIMA::PMINUS MAXIMA::FINDS MAXIMA::MAXCOEFFICIENT
+            MAXIMA::VALUE-MODE MAXIMA::FACTOSIMP MAXIMA::SOLVEQUAD
+            MAXIMA::TSTACK-SLOT-SPECIAL MAXIMA::BFLOAT-EXPINTEGRAL-SHI
+            MAXIMA::ARRAY-MODE-@ MAXIMA::DEFC1
+            MAXIMA::LOG-GAMMA-LANCZOS MAXIMA::$LIST_MATRIX_ENTRIES
+            MAXIMA::ERECIP MAXIMA::VISIBLEP MAXIMA::$NUMBERP
+            MAXIMA::DOUBLE-FACTORIAL MAXIMA::ZN-DISTRIB-LISTS
+            MAXIMA::FORM-MEXPT MAXIMA::BKPT-FUNCTION
+            MAXIMA::SORTED-REMOVE-DUPLICATES MAXIMA::FLOAT-OR-LOSE
+            MAXIMA::GETLIMVAL MAXIMA::CONSTACL MAXIMA::GF-FIELD?
+            MAXIMA::TRACE-FSYMEVAL MAXIMA::SANDMAP BIGFLOAT::FP2SINGLE
+            MAXIMA::MAPCAR-EVAL MAXIMA::EVOD-MPLUS MAXIMA::$CARG
+            MAXIMA::FIXEDMATCHP MAXIMA::PRODNUMDEN MAXIMA::OSCIP
+            MAXIMA::READLIST MAXIMA::INFINITYP MAXIMA::NUD-CALL
+            MAXIMA::TRIANG MAXIMA::$GF_TRACE MAXIMA::SIGN-MPLUS
+            MAXIMA::MAPATOM MAXIMA::SPC1 MAXIMA::MAKE-SWITCH-LIST
+            MAXIMA::POISPZERO MAXIMA::TR-NOSIMPP
+            MAXIMA::AIRY-BI-COMPLEX MAXIMA::TESTP MAXIMA::ONEARGCHECK
+            MAXIMA::$RANDOM_PERMUTATION MAXIMA::$DEL MAXIMA::TSEXP-COMB
+            COMMAND-LINE::CL-OPTION-HELP-STRING MAXIMA::$MATRIXP
+            MAXIMA::NMR MAXIMA::NEWSYM MAXIMA::NOTERMS MAXIMA::PDISREP
+            MAXIMA::$LISTARRAY MAXIMA::FACSUM-EXPONENT MAXIMA::P11
+            MAXIMA::MAXCOEF1 MAXIMA::TR-CLASS MAXIMA::KILLC
+            MAXIMA::COMPE MAXIMA::MPGET MAXIMA::GF-P2X-RAW MAXIMA::UP
+            MAXIMA::SEMANTICS MAXIMA::LI3SIMP MAXIMA::LEADOP
+            MAXIMA::SNUMDEN MAXIMA::ALGSYS MAXIMA::NO-SING-ERR
+            MAXIMA::NORM1 MAXIMA::EVOD-MTIMES MAXIMA::COMPLEXNUMP
+            MAXIMA::PSEXPT-FN MAXIMA::TAYCHK2RAT MAXIMA::GF-MOD
+            MAXIMA::ORD-VECTOR MAXIMA::PROCESS-ERROR-ARGL
+            MAXIMA::GF-DATA-FS-ORD MAXIMA::RATF MAXIMA::$ZN_ADD_TABLE
+            MAXIMA::EXPINTEGRAL-CI MAXIMA::EF-DATA-CARD MAXIMA::MMINUSP
+            MAXIMA::REALPOSITIVEP MAXIMA::BF-FXSHFT-SL MAXIMA::MCX
+            MAXIMA::CHECK-OPTION-PALETTE MAXIMA::RATREP* MAXIMA::DCON
+            MAXIMA::UNTRUE MAXIMA::CHECK-OPTION-BOOLE
+            MAXIMA::M2-LOG-EXP-2 MAXIMA::M2-EXP-TYPE-6
+            GETOPT::IS-LONG-OPTION MAXIMA::VARP MAXIMA::LINOUT
+            MAXIMA::FUNCTION-MODE-@ MAXIMA::CHUDNOVSKY-SERIES
+            MAXIMA::TEX-STRING MAXIMA::FACMGCD
+            MAXIMA::FINDSIGNOFTHEIRPRODUCT MAXIMA::ROUNDRHS
+            MAXIMA::$SUBVARP MAXIMA::POLYGON-DUMMY MAXIMA::$ADJOINT
+            MAXIMA::POISSUBST1S MAXIMA::LI2NUMER MAXIMA::PDEGREER
+            MAXIMA::$EF_NORMAL_BASIS MAXIMA::FPEXP MAXIMA::PUREPROD
+            MAXIMA::SIMPLE-TRIG-ARG MAXIMA::RALGP INTL::GETENV
+            MAXIMA::GF-MINUS MAXIMA::WTPTIMES3 MAXIMA::$CABS
+            MAXIMA::MARK+3 MAXIMA::PIP MAXIMA::POISSINE MAXIMA::UNIVAR
+            MAXIMA::LBP MAXIMA::MARRAY-CHECK
+            MAXIMA::SEND-GNUPLOT-COMMAND MAXIMA::CHANGESIGN
+            MAXIMA::M2-EXP-TYPE-4 MAXIMA::PGET MAXIMA::MDEFLISTP
+            MAXIMA::CHEBYLI3 MAXIMA::RESTORE-FACTS MAXIMA::ALPHABETP
+            MAXIMA::2PISTRIP MAXIMA::INLIST3 MAXIMA::ELEM
+            MAXIMA::MUNFORMAT MAXIMA::OPTIMIZE-PRINT-INST
+            MAXIMA::FLOAT-INF-P MAXIMA::KNOWN-PS MAXIMA::REMOPR
+            MAXIMA::PUTONLOGLIST MAXIMA::$TEXINIT
+            MAXIMA::GET-LARGE-FACTORS MAXIMA::PARP MAXIMA::MQUOTEP
+            MAXIMA::$GF_NORMAL_P MAXIMA::FACTORLOGS MAXIMA::EZEROP
+            MAXIMA::FIND-FIRST-TRIGARG MAXIMA::RATLIM
+            MAXIMA::EQUAL-FACTS-SIMP MAXIMA::ADUSUM
+            MAXIMA::RISPLIT-BESSEL-K-OR-Y MAXIMA::ARRAY-MODE
+            MAXIMA::PRINC* MAXIMA::CLEAR-LOBJS MAXIMA::SOLVECUBIC
+            MAXIMA::$EF_PRIMITIVE_P MAXIMA::MARRAY-TYPE-UNKNOWN
+            MAXIMA::$EF_NORM MAXIMA::MSTRINGP MAXIMA::SERIESPASS1
+            MAXIMA::LINEARCONST MAXIMA::DOWN MAXIMA::CHECK-LIST-PLOT3D
+            MAXIMA::POISINT4 MAXIMA::LENGTH-ONE MAXIMA::POISSUBST1C
+            MAXIMA::$EF_SET_AGAIN MAXIMA::$SYMBOLP MAXIMA::SRBINEXPND
+            MAXIMA::PZEROP MAXIMA::DEFS MAXIMA::GF-PRIM-P
+            MAXIMA::CFNROOT MT19937:RANDOM-STATE-P MAXIMA::SOME-FLOATP
+            MAXIMA::FUMCHECK MAXIMA::M2-EXP-TYPE-10-1 MAXIMA::ARRAYDIMS
+            MAXIMA::$NEXT_PRIME MAXIMA::TWOARGCHECK
+            MAXIMA::ON-NEGATIVE-REAL-AXISP MAXIMA::ONEVARP
+            MAXIMA::PUNIVARP MAXIMA::FLSORT
+            MAXIMA::$GET_TEX_ENVIRONMENT MAXIMA::OF-FORM-A*F<X>^N+B
+            MAXIMA::TSTACK-SLOT-MODE MAXIMA::PDISREP*CHK MAXIMA::ETF
+            MAXIMA::SAV&DEL MAXIMA::SUM-C*LOGS MAXIMA::PRINT-MODULE
+            MAXIMA::GENPOLY MAXIMA::SUBGEN MAXIMA::SUBFUNNAME
+            MAXIMA::SOLVELIN MAXIMA::$FACTORSUM MAXIMA::GENSYM-READABLE
+            INTL::FIND-ENCODING MAXIMA::ORDHACK MAXIMA::STRING*
+            MAXIMA::ADSUM MAXIMA::SIGN-MEXPT MAXIMA::ASKINVER
+            MAXIMA::CHECKFIT MAXIMA::MSEEMINGLY-UNBOUND
+            MAXIMA::ZERO-LIM MAXIMA::$EF_PRIMITIVE_POLY MAXIMA::CNTP
+            MAXIMA::PKRONECK MAXIMA::GF-NS2PMOD-FACTORS MAXIMA::RFORM
+            MAXIMA::REMRULE MAXIMA::SIMPNCT-ONEP MAXIMA::GCDL
+            MAXIMA::RFLOT MAXIMA::SP1UNTREP MAXIMA::MATRIXHELPER
+            MAXIMA::ALGORD MAXIMA::NON0RAND MAXIMA::$DISPTERMS
+            MAXIMA::GOODFORM MAXIMA::TBOUNDP MAXIMA::$PERMUTATIONS
+            MAXIMA::DOUTERN MAXIMA::$COPYMATRIX MAXIMA::RED-MONO-LOG
+            MAXIMA::LIMUNKNOWN1 MAXIMA::APPARENTLY-INTEGER
+            MAXIMA::GF-NMINUS MAXIMA::DB-MNUMP MAXIMA::MAKE-LONG-LIST
+            MAXIMA::GF-MAYBE-NORMAL-BASIS MAXIMA::LISTOVARSL
+            MAXIMA::MRING-ABS MAXIMA::MIDOUT MAXIMA::NISINNERNULL
+            MAXIMA::TRIG-NOT-SUBST-P MAXIMA::FPABS
+            MAXIMA::ASKSIGN-P-OR-N MAXIMA::DECODE MAXIMA::SQCONT
+            MAXIMA::FPEXP1 MAXIMA::FACTOR-LIST MAXIMA::ADJOIN-TVAR
+            MAXIMA::$PATHNAME_DIRECTORY MAXIMA::MRING-MAXIMA-TO-MRING
+            MAXIMA::RAT-NO-RATFAC MAXIMA::DBZS-ERR MAXIMA::TAYLOR3
+            MAXIMA::INTFACTOR MAXIMA::TUNBIND MAXIMA::$CONSTANTP
+            MAXIMA::MPARAMS MAXIMA::CYCLOTOMIC MAXIMA::UNKNOWN-ATOMS
+            MAXIMA::MARKS MAXIMA::PROCLAIM-PROPERTY MAXIMA::DISREPLIST1
+            MAXIMA::$EF_IRREDUCIBLE_P)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (*) *) MAXIMA::$JACOBI_SD MAXIMA::$JACOBI_SN
+            MAXIMA::$INVERSE_JACOBI_SD MAXIMA::$ROOM
+            MAXIMA::$INVERSE_JACOBI_CD MAXIMA::$JACOBI_NC
+            MAXIMA::$JACOBI_CD MAXIMA::TRACE-MPRINT
+            MAXIMA::$INVERSE_JACOBI_ND MAXIMA::$QUAD_QAWO
+            MAXIMA::$INVERSE_JACOBI_SC MAXIMA::$QUAD_QAG MAXIMA::MUL*
+            MAXIMA::SAVE-LINENUMBERS MAXIMA::$INVERSE_JACOBI_CN
+            MAXIMA::$JACOBI_CS MAXIMA::$JACOBI_ND MAXIMA::$QUAD_QAGS
+            MAXIMA::MERRBREAK MAXIMA::GF-POWER-TABLE-ARGS MAXIMA::$READ
+            MAXIMA::OUTERMAP2 MAXIMA::$INVERSE_JACOBI_DS
+            MAXIMA::$INVERSE_JACOBI_SN MAXIMA::$DIFF MAXIMA::$QUAD_QAWF
+            MT19937:MAKE-RANDOM-STATE MAXIMA::ADD* MAXIMA::$EZGCD
+            MAXIMA::OUTERMAP1 MAXIMA::$INVERSE_JACOBI_CS
+            MAXIMA::$INVERSE_JACOBI_DC MAXIMA::$JACOBI_DC
+            MAXIMA::$JACOBI_CN MAXIMA::$INVERSE_JACOBI_NS
+            MAXIMA::$KRON_DELTA MAXIMA::$DEMO MAXIMA::BARFO
+            MAXIMA::MACSYMA-TOP-LEVEL MAXIMA::$JACOBI_DS
+            MAXIMA::$INVERSE_JACOBI_DN MAXIMA::$QUAD_QAWC
+            MAXIMA::$JACOBI_NS MAXIMA::$QUAD_QAWS MAXIMA::$SYSTEM
+            MAXIMA::$JACOBI_DN BIGFLOAT::BFERRTOL MAXIMA::BREAK-FRAME
+            MAXIMA::MUL MAXIMA::$QUAD_QAGI MAXIMA::$JACOBI_SC
+            MAXIMA::$INVERSE_JACOBI_NC MAXIMA::MAP1 MAXIMA::CONTINUE
+            MAXIMA::$QUAD_QAGP)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (FIXNUM) T) MAXIMA::FFIB MAXIMA::STYOTBSP
+            MAXIMA::EF-CMINUS-BY-TABLE MAXIMA::INDEX* MAXIMA::RCPLYGAM
+            MAXIMA::EF-CINV-BY-TABLE MAXIMA::CMNULLF)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T) FIXNUM) MAXIMA::FLATC MAXIMA::FLATSIZE
+            INTL::READ-BELONG MAXIMA::GNUPLOT-POINTTYPE
+            INTL::READ-LELONG MAXIMA::$EF_DEGREE MAXIMA::SIGNUM1
+            MAXIMA::SIGN-GJC MAXIMA::SIGNUM MAXIMA::$POLYSIGN
+            MAXIMA::$GF_DEGREE MAXIMA::NUMBER-OF-DIGITS
+            MAXIMA::PRMUSIGN MAXIMA::COMPLM)) 
+(PROCLAIM '(FTYPE (FUNCTION (STRING) T) SLATEC::XERHLT)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
                 (T LONG-FLOAT LONG-FLOAT FIXNUM (VECTOR LONG-FLOAT)
@@ -6811,6 +2019,45 @@
             SLATEC:DQAGS)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
+                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
+                   FIXNUM LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR FIXNUM) FIXNUM)
+                *)
+            SLATEC::DQAGE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT
+                   LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
+                   FIXNUM FIXNUM FIXNUM FIXNUM (VECTOR FIXNUM)
+                   (VECTOR LONG-FLOAT))
+                *)
+            SLATEC:DQAWO)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                (T LONG-FLOAT LONG-FLOAT FIXNUM (VECTOR LONG-FLOAT)
+                   LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT
+                   FIXNUM FIXNUM (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR FIXNUM) (VECTOR FIXNUM) (VECTOR FIXNUM)
+                   FIXNUM)
+                *)
+            SLATEC::DQAGPE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION ((VECTOR FIXNUM) *) T)
+            MT19937::VEC-INIT-RANDOM-STATE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
+                   LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
+                   FIXNUM FIXNUM FIXNUM FIXNUM (VECTOR FIXNUM)
+                   (VECTOR LONG-FLOAT))
+                *)
+            SLATEC:DQAWS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
                 (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
                    LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
                    FIXNUM FIXNUM FIXNUM (VECTOR FIXNUM)
@@ -6826,36 +2073,924 @@
             SLATEC:DQAWF)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT
-                   LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
-                   FIXNUM FIXNUM FIXNUM FIXNUM (VECTOR FIXNUM)
-                   (VECTOR LONG-FLOAT))
+                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
+                   LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM FIXNUM FIXNUM
+                   FIXNUM (VECTOR FIXNUM) (VECTOR LONG-FLOAT))
                 *)
-            SLATEC:DQAWO)) 
+            SLATEC:DQAG)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
                 (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
-                   LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
-                   FIXNUM FIXNUM FIXNUM FIXNUM (VECTOR FIXNUM)
-                   (VECTOR LONG-FLOAT))
+                   LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT
+                   FIXNUM FIXNUM (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR FIXNUM) FIXNUM)
                 *)
-            SLATEC:DQAWS)) 
+            SLATEC::DQAWSE)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
-                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM
-                    FIXNUM)
+                (T LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT FIXNUM
+                   LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR FIXNUM) FIXNUM)
                 *)
-            SLATEC:ZBESK)) 
+            SLATEC::DQAGIE)) 
 (PROCLAIM
     '(FTYPE (FUNCTION
-                (LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
-                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM
-                    (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT) FIXNUM)
+                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM
+                   LONG-FLOAT LONG-FLOAT FIXNUM FIXNUM
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR FIXNUM) FIXNUM)
                 *)
-            SLATEC:ZBESY)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) SYSTEM::SHORT-NAME)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) SYSTEM:CDIFFERENCE)) 
-(PROCLAIM '(FTYPE (FUNCTION (T) T) SYSTEM:CMOD)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) SYSTEM:CPLUS)) 
-(PROCLAIM '(FTYPE (FUNCTION (T T) T) SYSTEM:CTIMES)) 
\ No newline at end of file
+            SLATEC::DQAGSE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT LONG-FLOAT
+                   LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT FIXNUM
+                   FIXNUM (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR FIXNUM) FIXNUM)
+                *)
+            SLATEC::DQAWCE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                (T LONG-FLOAT LONG-FLOAT LONG-FLOAT FIXNUM LONG-FLOAT
+                   LONG-FLOAT FIXNUM FIXNUM FIXNUM LONG-FLOAT
+                   LONG-FLOAT FIXNUM FIXNUM FIXNUM (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                   (VECTOR LONG-FLOAT) (VECTOR FIXNUM) (VECTOR FIXNUM)
+                   FIXNUM (VECTOR LONG-FLOAT))
+                *)
+            SLATEC::DQAWOE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                (T LONG-FLOAT FIXNUM LONG-FLOAT LONG-FLOAT LONG-FLOAT
+                   LONG-FLOAT FIXNUM FIXNUM FIXNUM FIXNUM FIXNUM
+                   (VECTOR FIXNUM) (VECTOR LONG-FLOAT))
+                *)
+            SLATEC:DQAGI)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (INTEGER) *) MAXIMA::EF-CMOD MAXIMA::EF-CINV)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION ((VECTOR FIXNUM) FIXNUM) *) SLATEC::XGETUA)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION NIL FIXNUM) MAXIMA::$EF_EXPONENT
+            MAXIMA::BF-REALIT-SL MAXIMA::REALIT-SL MAXIMA::$GF_EXPONENT
+            MAXIMA::STERPRI)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T) (VALUES T T)) MAXIMA::CREATENAME
+            MAXIMA::NXTBINCOEF)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION NIL T) MAXIMA::PARSE-TYIPEEK MAXIMA::PRINTNET
+            MAXIMA::BACKWARD MAXIMA::$GNUPLOT_RESTART
+            MT19937::GENERATE-SEED MAXIMA::COMPPI MAXIMA::$EF_NORMAL
+            MAXIMA::NEXT-COSET MAXIMA::BF-QUADIT-SL
+            MAXIMA::RESTORE-BINDINGS MAXIMA::EF-PRIM
+            MAXIMA::PEEK-ONE-TOKEN
+            MAXIMA::FIND-LISP-READTABLE-FOR-MACSYMA MAXIMA::RESTORE1
+            MAXIMA::$CLEAR_RULES MAXIMA::$EF_PRIMITIVE
+            MAXIMA::CLEARSIGN MAXIMA::GF-CLEAR-TABLES MAXIMA::DQ-
+            MAXIMA::NOR-ERR MAXIMA::KILLALLCONTEXTS MAXIMA::QUADSD-SL
+            MAXIMA::BF-NEXTH-SL MAXIMA::NEXTK-SL MAXIMA::CAUCHY-SL
+            MAXIMA::FPGAMMA1 MAXIMA::$GF_RANDOM_NORMAL
+            MAXIMA::ESSEN-SING-ERR MAXIMA::QUADIT-SL
+            MAXIMA::DCHECK-TABLES MAXIMA::GOBBLE-WHITESPACE
+            MAXIMA::$EF_CARDINALITY
+            MAXIMA::REPLACE-COSET-IN-MULTIPLY-TABLE
+            MAXIMA::TAY-DEPTH-ERR MAXIMA::FORGET-GLOBAL-ASSUMPTIONS
+            MAXIMA::PROPG MAXIMA::DQ+ MAXIMA::NEXTH-SL MAXIMA::KINDP34
+            MAXIMA::$EF_INFOLIST MAXIMA::$GF_CHARACTERISTIC
+            MAXIMA::MATCHERR MAXIMA::MAXIMA-BANNER
+            MAXIMA::SCAN-LISP-TOKEN MAXIMA::GF-MATADD2-ERROR
+            MAXIMA::SPC0 INTL::INSTALL MAXIMA::SCAN-LISP-STRING
+            MAXIMA::$BT MAXIMA::GF-RANDOM-NORMAL
+            MAXIMA::$GF_MAKE_ARRAYS MAXIMA::$TR_WARNINGS_GET
+            MAXIMA::DBZ-ERR MAXIMA::RESTORE MAXIMA::RECOVERORDER1
+            MAXIMA::CLEAR MAXIMA::BF-CALCT-SL MAXIMA::$GF_NORMAL
+            MAXIMA::BF-SCALE-SL MAXIMA::THROW-MACSYMA-TOP
+            MAXIMA::RECOVERORDER2 MAXIMA::$EF_REDUCTION
+            MAXIMA::$GNUPLOT_RESET MAXIMA::SCAN-MACSYMA-STRING
+            MAXIMA::EF-RANDOM-NORMAL MAXIMA::COMP-LOG2
+            MAXIMA::DPRINT-STATE MAXIMA::RESTORE2
+            MAXIMA::STOP-GNUPLOT-PROCESS MAXIMA::$GF_MAKE_LOGS
+            MAXIMA::GETOPTIMVAR MAXIMA::INIT-BREAK-POINTS
+            MAXIMA::EXP-PT-ERR MAXIMA::TMSORT1 MAXIMA::TERPRI*
+            MAXIMA::PRINTLABEL MAXIMA::$EF_ADD_TABLE MAXIMA::$CLOSEFILE
+            MAXIMA::BF-NEXTK-SL MAXIMA::PRINCIPAL MAXIMA::CALCSC-SL
+            MAXIMA::$BUILD_INFO MAXIMA::BF-POLYEV-SL MAXIMA::GCCON
+            MAXIMA::$BUG_REPORT MAXIMA::BF-CAUCHY-SL
+            MAXIMA::GOBBLE-COMMENT MAXIMA::INFIN-ORD-ERR
+            MAXIMA::NEW-COMMENT-LINE MAXIMA::MAKE-PARAM
+            MAXIMA::$GF_UNSET MAXIMA::MSUBLIS-SETUP MAXIMA::GETRISCHVAR
+            MAXIMA::CURRENT-STEP-FUN MAXIMA::SCAN-KEYWORD-TOKEN
+            MAXIMA::TR-GENSYM MAXIMA::$GNUPLOT_START MAXIMA::FPPI1
+            MAXIMA::$EF_GET_DATA MAXIMA::BF-CALCSC-SL MAXIMA::$UNORDER
+            MAXIMA::TYI* MAXIMA::GF-PRIM MAXIMA::GF-PRECOMP
+            MAXIMA::$GF_PRIMITIVE MAXIMA::FUU MAXIMA::BF-NEWEST-SL
+            MAXIMA::DIVERG MAXIMA::CHECK-GNUPLOT-PROCESS MAXIMA::FPE1
+            MAXIMA::CHRCT* MAXIMA::NEW-ALG MAXIMA::$GF_ADD_TABLE
+            MAXIMA::GF-SET-RAT-HEADER MAXIMA::CONTEXTMARK
+            MAXIMA::NEWEST-SL MAXIMA::$EF_RANDOM_NORMAL
+            MAXIMA::MSUBLIS-UNSETUP MAXIMA::SCALE-SL
+            MAXIMA::FILL-IN-INVERSES MAXIMA::SCAN-MACSYMA-TOKEN
+            MAXIMA::CLOSE-CLIENT MAXIMA::$GF_INFOLIST MAXIMA::MUNLOCAL
+            MAXIMA::EF-PRECOMP MAXIMA::RESTORE-ASSUMPTIONS
+            MAXIMA::BF-QUADSD-SL MAXIMA::PARSE-ERR
+            MAXIMA::$PRINTVARLIST MAXIMA::[MAX-TRUNC] MAXIMA::PARSE-TYI
+            MAXIMA::$GF_CARDINALITY MAXIMA::BYE
+            MAXIMA::POP-LOOP-CONTEXT MAXIMA::OPT-ERR MAXIMA::GCCON1
+            MAXIMA::GENREF MAXIMA::$GET_TEX_ENVIRONMENT_DEFAULT
+            MAXIMA::MTERPRI MAXIMA::TMINITIALFLAG
+            MAXIMA::$GNUPLOT_CLOSE MAXIMA::SET-READTABLE-FOR-MACSYMA
+            MAXIMA::$EF_UNSET MAXIMA::UNFAM-SING-ERR
+            MAXIMA::$GF_REDUCTION MAXIMA::POLYEV-SL MAXIMA::$ERRORMSG
+            MAXIMA::GF-MAKE-LOGS MAXIMA::CALCT-SL
+            MAXIMA::MAKE-GLOBAL-ASSUMPTIONS MAXIMA::$GF_GET_DATA)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION
+                ((VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT)
+                 (VECTOR LONG-FLOAT) (VECTOR LONG-FLOAT))
+                *)
+            SLATEC::DQCHEB)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION ((VECTOR UNSIGNED-CHAR) T T) *)
+            INTL::SEARCH-DOMAIN)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION ((VECTOR LONG-FLOAT) FIXNUM LONG-FLOAT) *)
+            SLATEC::INITDS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T T) (VALUES T T))
+            BIGFLOAT::|(PCL::FAST-METHOD ROUND (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD CEILING (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD FLOOR (NUMBER))|
+            BIGFLOAT::|(PCL::FAST-METHOD TRUNCATE (NUMBER))|)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T T) (VALUES T T T))
+            BIGFLOAT::|(PCL::FAST-METHOD DECODE-FLOAT (LISP:FLOAT))|
+            BIGFLOAT::|(PCL::FAST-METHOD INTEGER-DECODE-FLOAT (LISP:FLOAT))|)) 
+(MAPC (LAMBDA (COMPILER::X)
+        (SETF (GET COMPILER::X 'SYSTEM::PROCLAIMED-CLOSURE) T))
+      '(SLATEC::ZUNHJ SLATEC::XERPRN MAXIMA::MAXIMA-SUBSTITUTE
+           SLATEC::DBSK1E SLATEC:DBSI1E MAXIMA::$ABSOLUTE_REAL_TIME
+           SLATEC::ZUNI1 SLATEC:ZBESJ MAXIMA::CLEAR_FPE_TABLE
+           MAXIMA::BACKSLASH-CHECK SLATEC:DBESK SLATEC::DQNG SLATEC:DBI
+           SLATEC::ZUNK1 SLATEC::ZUNK2 SLATEC::ZBKNU
+           MAXIMA::CLEAR_FPGAMMA_TABLE MAXIMA::FPLOG2 SLATEC:DERFC
+           SLATEC::ZSQRT$ MAXIMA::$ELAPSED_REAL_TIME SLATEC::DASYIK
+           SLATEC:DE1 SLATEC::DBSKNU MAXIMA::FPPI-TABLE SLATEC::DQC25C
+           SLATEC:DSPENC SLATEC::DQAWFE SLATEC::DQK61 SLATEC::DQK31
+           MAXIMA::$RHS SLATEC:DERF SLATEC:J4SAVE SLATEC:DBESI0
+           MAXIMA::$MAKE_TRANSFORM SLATEC::DASYJY SLATEC::ZACAI
+           SLATEC:ZBESI SLATEC::DQC25F MAXIMA::CHECKPOW MAXIMA::FSET
+           SLATEC::ZUOIK MAXIMA::SUPEREXPT SLATEC::DQC25S
+           MAXIMA::MAKE-MAXIMA-TEX-GLUE SLATEC:DBSI0E SLATEC::DQK15
+           SLATEC::DQK21 SLATEC:ZBIRY SLATEC:DYAIRY MAXIMA::MYPRINC
+           SLATEC::ZBINU SLATEC:DBESY0 SLATEC:DBESY
+           MAXIMA::DEFINE-MACRO SLATEC:DBESJ1 SLATEC::DQK41
+           SLATEC::ZS1S2 MAXIMA::FPGAMMA SLATEC::DBSYNU SLATEC::ZRATI
+           SLATEC::ZMLRI MAXIMA::DERIVDEG1 SLATEC:DAI SLATEC:ZBESH
+           SLATEC:DBESK0 MAXIMA::EAT-CONTINUATIONS SLATEC::ZLOG
+           MAXIMA::$HIPOW MAXIMA::$LHS MAXIMA::FINDPOWERS1
+           SLATEC::DQK15I SLATEC:DBESY1 SLATEC:DBESI1 SLATEC::DLNGAM
+           SLATEC:DBESJ0 MAXIMA::RESET-CCOL MAXIMA::$ELAPSED_RUN_TIME
+           SLATEC::D9B0MP MAXIMA::$DERIVDEGREE
+           MAXIMA::INITIALIZE-REAL-AND-RUN-TIME MAXIMA::SUBST4
+           MAXIMA::TRACE-FSHADOW SLATEC::DGAMMA MAXIMA::FPLOG2-TABLE
+           MAXIMA::FPGAMMA-TABLE MAXIMA::SUBST41 SLATEC::ZACON
+           SLATEC::DQK51 SLATEC::DBSK0E SLATEC::ZUNIK SLATEC::D9LGMC
+           SLATEC::DCSEVL SLATEC:DJAIRY SLATEC::ZKSCL SLATEC::DBIE
+           MAXIMA::ELEMXPT SLATEC::DGAMLN SLATEC::DAIE SLATEC::XERSVE
+           SLATEC::ZSERI SLATEC:DBESJ SLATEC::D9B1MP MAXIMA::FPE
+           SLATEC::D9AIMP MAXIMA::FPPI SLATEC:ZAIRY MAXIMA::FPE-TABLE
+           MAXIMA::CLEAR_FPLOG2_TABLE MAXIMA::TRACE-UNFSHADOW
+           SLATEC:DBESK1 MAXIMA::FINDPOWERS MAXIMA::CRF SLATEC::ZUNI2
+           MAXIMA::CLEAR_FPPI_TABLE SLATEC::ZASYI SLATEC::DQK15W
+           SLATEC:DBESI MAXIMA::$LOPOW)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION ((VECTOR UNSIGNED-CHAR) (VECTOR UNSIGNED-CHAR) *)
+                T)
+            INTL::OCTETS=)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T) (OR NULL FUNCTION))
+            INTL::DOMAIN-ENTRY-PLURALS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T) *) MAXIMA::SIMPG MAXIMA::DIFFINT
+            MAXIMA::MULTL MAXIMA::SIMPNCT-MERGE-PRODUCT
+            BIGFLOAT::JACOBI-AGM MAXIMA::DIFFLAPLACE MAXIMA::RTCON
+            MAXIMA::%GAMMA-INCOMPLETE MAXIMA::TRANSFORM-TVAR
+            MAXIMA::POISCO* MAXIMA::LOAD-FUNCTION MAXIMA::REMBOX1
+            MAXIMA::BIG-FLOAT-EVAL MAXIMA::LT1E MAXIMA::LT1KELLIPTIC
+            MAXIMA::OUTATIVE MAXIMA::DINTLOG MAXIMA::COMMUTATIVE1
+            MAXIMA::ANTISYM BIGFLOAT::BF-INVERSE-JACOBI-SN
+            MAXIMA::SDIFFGRAD MAXIMA::COMPLEX-ASIN MAXIMA::LT1LOG
+            MAXIMA::POWERX MAXIMA::DINTRAD0 MAXIMA::$HANKEL_1
+            MAXIMA::STRONGER-VARS? INTL::READ-COMMENT MAXIMA::RISCHINT
+            MAXIMA::$ARRAYAPPLY MAXIMA::COMPLEX-BFLOAT-GAMMA-INCOMPLETE
+            MAXIMA::DIV* MAXIMA::SP1EXPT MAXIMA::NCMULN
+            MAXIMA::SET-NOT-EQP MAXIMA::SIMPLIM%ERF-%TANH
+            MAXIMA::SET-SUBSETP BIGFLOAT::BFLOAT-INIT-LAMBERT-W-K
+            MAXIMA::INTIR-REF MAXIMA::ADD2* MAXIMA::EXPTA
+            MAXIMA::$GAMMA_INCOMPLETE MAXIMA::SCMP MAXIMA::TIMESK
+            MAXIMA::SPANGSIDE MAXIMA::2F0POLYS MAXIMA::LAPTIMES
+            MAXIMA::TRIG-LOG MAXIMA::SINH^N MAXIMA::$ELEMENTP
+            MAXIMA::RATFACT MAXIMA::INTBYTERM MAXIMA::ROOT MAXIMA::DTW
+            MAXIMA::ADDMX BIGFLOAT::CN MAXIMA::$EXPINTEGRAL_E
+            MAXIMA::BYGAMMA MAXIMA::MXPLUSC MAXIMA::EXPTHACK
+            MAXIMA::COMPLEX-TANH MAXIMA::NRTHK1 MAXIMA::LIM-POWER
+            MAXIMA::GAMMAINCOMPLETETW MAXIMA::RTIMES MAXIMA::ISO2
+            MAXIMA::GCPOWER MAXIMA::HALFANGLEAUX-FACTOR
+            MAXIMA::EF-CPLUS-B MAXIMA::BATCH-INTERNAL MAXIMA::FPOLY1
+            MAXIMA::SUMTIMES MAXIMA::|''MAKE-FUN| MAXIMA::SIMP2F1
+            MAXIMA::TRIG-LOG-1 MAXIMA::$STRUVE_H MAXIMA::LEGENPOL
+            MAXIMA::GF-CTIMES MAXIMA::UTPJAC MAXIMA::LOGARC
+            MAXIMA::$GENERALIZED_LAMBERT_W MAXIMA::SIMPLIM%ASIN-%ACOS
+            MAXIMA::SDIFF MAXIMA::RTC-FIXITUP MAXIMA::F-FUN
+            MAXIMA::RESM1 MAXIMA::SP2SUB MAXIMA::TRIG-3
+            MAXIMA::TAYLORIZE MAXIMA::SIMPCHECK MAXIMA::$ELLIPTIC_F
+            MAXIMA::MAYBE-SIMPLIFYA MAXIMA::$DISJOINTP MAXIMA::ATSCAN
+            MAXIMA::CHEBYF MAXIMA::EF-CPOW MAXIMA::$BINOMIAL
+            MAXIMA::SHEUR0 MAXIMA::PATAN MAXIMA::INTEGRATE-MEXPT-1
+            MAXIMA::LT1ERF MAXIMA::COMPLEX-LOG MAXIMA::SP1ATRIG2
+            BIGFLOAT::BF-ELLIPTIC-E MAXIMA::GF-CPLUS-B
+            MAXIMA::$CARLSON_RC MAXIMA::LEARN MAXIMA::APPEARS-IN
+            MAXIMA::F37P147 MAXIMA::INTEGRATE5
+            MAXIMA::HERMITE-TO-HYPERGEOMETRIC MAXIMA::SINSP
+            MAXIMA::DIM-MTEXT MAXIMA::BYLOG MAXIMA::$LINSOLVE
+            MAXIMA::*F-DETERMINANT-BY-LU MAXIMA::SP1ATRIG
+            BIGFLOAT::BF-ELLIPTIC-F MAXIMA::$PARTFRAC MAXIMA::MORP
+            MAXIMA::SIMPNCT-MERGE-FACTORS MAXIMA::DIFFDIV
+            MAXIMA::GAMMA_INCOMPLETE-TO-GAMMAGREEK MAXIMA::$DESOLVE
+            MAXIMA::RHEUR MAXIMA::CGCD MAXIMA::LIMITSIMP-EXPT
+            MAXIMA::BESSEL-NUMERICAL-EVAL-P MAXIMA::SHOW-OPEN-PLOT
+            MAXIMA::SIMPLIFYA MAXIMA::DIM-BIGFLOAT MAXIMA::INTIR3
+            GETOPT::DECOMPOSE-ARG MAXIMA::CONSTMX MAXIMA::LIMROOT
+            MAXIMA::ADDITIVE MAXIMA::TRIG-LOG-1-POS MAXIMA::HYPREDINCGM
+            MAXIMA::FANCYDIS MAXIMA::OPER-APPLY MAXIMA::RDDEG
+            MAXIMA::EF-CTIMES MAXIMA::$HANKEL_2 MAXIMA::LT-LOG
+            MAXIMA::MAPPLY-TR MAXIMA::WLINEARPOLY
+            MAXIMA::EVEN-FUNCTION-REFLECT MAXIMA::NRTHK
+            MAXIMA::POISCOINTEG BIGFLOAT::DN MAXIMA::FPEXPT
+            MAXIMA::POWERLIST MAXIMA::GF-DIVIDE MAXIMA::ASSIGN-CHECK
+            BIGFLOAT::DESCENDING-TRANSFORM MAXIMA::ODD-FUNCTION-REFLECT
+            MAXIMA::MULTIPLICATIVE MAXIMA::LINEARIZE1
+            BIGFLOAT::ASCENDING-TRANSFORM MAXIMA::LINEARIZE2
+            MAXIMA::COMPLEX-ATANH MAXIMA::BESTRIG BIGFLOAT::SN
+            MAXIMA::LIMITSIMP MAXIMA::STIMEX MAXIMA::PFET1
+            MAXIMA::$EULERPOLY MAXIMA::LT-BESSEL_K0
+            INTL:READ-TRANSLATABLE-STRING MAXIMA::SIMPNRT
+            MAXIMA::SHEUR1 MAXIMA::*F-INVERT-BY-LU MAXIMA::TRIG-LOG-3
+            MAXIMA::DIFFSUMPROD MAXIMA::PRINT-ONE-FRAME
+            MAXIMA::COMDENOM BIGFLOAT::BF-RC MAXIMA::FLONUM-EVAL
+            MAXIMA::SIN^N MAXIMA::SIMPLIM%ATANH
+            MAXIMA::BESSEL-I-HYPERGEOMETRIC MAXIMA::$ALGSYS
+            MAXIMA::SCAN-ONE-TOKEN-G MAXIMA::SCH-REPLACE
+            MAXIMA::SIMPG-EXEC MAXIMA::MULN MAXIMA::POISCO+
+            MAXIMA::RECUR-APPLY MAXIMA::1F1POLYS MAXIMA::MARRAYREF1$
+            MAXIMA::INTIRFACTOROOT MAXIMA::TRIG-LOG-3-EXEC
+            MAXIMA::SIMPLIMSCH MAXIMA::INTEGRATOR MAXIMA::RGCD
+            MAXIMA::$BESSEL_Y MAXIMA::DIFF-%AT MAXIMA::$ELLIPTIC_EU
+            MAXIMA::EVENFUN MAXIMA::MAYBE-SIMPLIFYA-PROTECTED
+            MAXIMA::GF-GCD-COFACTORS MAXIMA::DISPATCH-SPEC-SIMP
+            MAXIMA::COMPLEX-ASINH MAXIMA::$ERF_GENERALIZED
+            MAXIMA::DIFFEXPT MAXIMA::TEX-FORMS MAXIMA::NUMERSET
+            MAXIMA::NCPOWER MAXIMA::PORM MAXIMA::$EF_AT MAXIMA::ERFARG
+            MAXIMA::$ISOLATE MAXIMA::SININT MAXIMA::XMAXIMA-PALETTES
+            MAXIMA::NRTHK2 MAXIMA::%$ETEST MAXIMA::INIT-LAMBERT-W-K
+            MAXIMA::$BESSEL_J MAXIMA::DIMENSION-ARRAY-OBJECT
+            MAXIMA::LPR MAXIMA::SIMPNCT-ANTISYM-CHECK MAXIMA::YTJ
+            MAXIMA::$ZN_INVERT_BY_LU MAXIMA::ISO1 MAXIMA::GF-CPOW
+            MAXIMA::COMPLEX-SQRT MAXIMA::RATEXAND1 MAXIMA::RPLUS
+            MAXIMA::F36P147 MAXIMA::TRIGINT MAXIMA::SHEUR MAXIMA::NARY1
+            MAXIMA::$ELLIPTIC_E MAXIMA::CHAINRULE MAXIMA::KTFORK
+            MAXIMA::ERFARG2 MAXIMA::TCHEBYPOL MAXIMA::GGR
+            MAXIMA::DIMENSION-ATOM MAXIMA::MAXIMIN MAXIMA::MUL2*
+            MAXIMA::GENATAN MAXIMA::BESSEL-Y-INTEGRAL-2 MAXIMA::ODDFUN
+            MAXIMA::TRACE-OPTION-P MAXIMA::ZTO%PI2 MAXIMA::SUBSUM
+            MAXIMA::GF-AT MAXIMA::SUB* MAXIMA::$BESSEL_K MAXIMA::INTIR
+            MAXIMA::$BESSEL_I MAXIMA::INTIR1 MAXIMA::TRACE-APPLY
+            MAXIMA::NCMUL2 MAXIMA::SIMPR2F1
+            MAXIMA::BFLOAT-GAMMA-INCOMPLETE MAXIMA::INTERSECT-INFO
+            MAXIMA::TTPJAC MAXIMA::PLSK MAXIMA::VARINVERT
+            MAXIMA::SIMPKTF BIGFLOAT::ELLIPTIC-SN-DESCENDING
+            MAXIMA::EXPTRL MAXIMA::$GF_AT MAXIMA::FPSIN MAXIMA::MTOINF
+            MAXIMA::SUBIN MAXIMA::$AT MAXIMA::MULT MAXIMA::MSET
+            MAXIMA::$CHARPOLY MAXIMA::RDIFFERENCE MAXIMA::SRATEXPND
+            BIGFLOAT::BF-INVERSE-JACOBI-DN MAXIMA::SUMULTIN
+            MAXIMA::KC-ARG MAXIMA::TIMEX MAXIMA::INTIR2
+            MAXIMA::GAMMAGREEK MAXIMA::$SUBSETP MAXIMA::TRY-EXPANSION
+            MAXIMA::DISPLAF MAXIMA::SUB MAXIMA::$STRUVE_L
+            MAXIMA::POISCODIF MAXIMA::KTI MAXIMA::COS^N MAXIMA::INTE
+            MAXIMA::INTSUM MAXIMA::GET-CONST-OR-INT-TERMS
+            MAXIMA::$GAMMA_INCOMPLETE_REGULARIZED MAXIMA::POWER*
+            MAXIMA::INTEGRATE-EXP-SPECIAL MAXIMA::TRACE-HANDLER
+            MAXIMA::$APPLY MAXIMA::FUNCER MAXIMA::SET-DISJOINTP
+            MAXIMA::DIFFNCEXPT MAXIMA::BESSEL-J-HYPERGEOMETRIC
+            MAXIMA::TRIGIN1 MAXIMA::$JACOBI_AM MAXIMA::BINCOMP
+            MAXIMA::ADDK BIGFLOAT-IMPL:COERCE MAXIMA::TRIGEXPAND
+            MAXIMA::BESSEL-K-INTEGRAL-2 MAXIMA::COSH^N MAXIMA::ZTOINF
+            MAXIMA::$EQUIV_CLASSES MAXIMA::UNITCIR MAXIMA::DTFORD
+            MAXIMA::COMPLEX-ACOS BIGFLOAT:LENTZ MAXIMA::EXPAND-TRIGS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T *) T) MAXIMA::FORTRAN-PRINT
+            MAXIMA::GET-FREE-INDEX MAXIMA::BIG-FLOAT-SINH
+            MAXIMA::$TAYLOR BIGFLOAT-IMPL:< MAXIMA::$INTERSECTION
+            MAXIMA::OUTPUT-POINTS MAXIMA::*F-MATMULT MAXIMA::HEXPAND
+            BIGFLOAT-IMPL:TO MAXIMA::$TMNEWDET MAXIMA::BATCH
+            MAXIMA::WARN-UNDECLARED MAXIMA::LIST-VARIABLE-BINDINGS
+            MAXIMA::FPMIN MAXIMA::FMAPL1 MAXIMA::$REALROOTS
+            MAXIMA::$COMPILE_FILE MAXIMA::COERCE-BFLOAT-FUN
+            MAXIMA::$DISPFORM MAXIMA::BIG-FLOAT-ASINH
+            MAXIMA::$INTERSECT MAXIMA::$GF_N2P MAXIMA::TR-LOCAL-EXP
+            MAXIMA::$EVERY MAXIMA::$EF_P2L MAXIMA::GF-MERROR
+            MAXIMA::$CONTOUR_PLOT BIGFLOAT-IMPL:>= BIGFLOAT-IMPL:/=
+            MAXIMA::LIMIT-LIST MAXIMA::$POSTFIX MAXIMA::$GF_LOG
+            MAXIMA::$INTEGER_PARTITIONS BIGFLOAT-IMPL:<=
+            MAXIMA::$MULTTHRU MAXIMA::$NARY MAXIMA::$REST
+            MAXIMA::BREAK-STEP-NEXT MAXIMA::ENSURE-SIGN
+            MAXIMA::$FULLRATSIMP MAXIMA::$PLOT3D MAXIMA::$SOME
+            MAXIMA::$GF_SET_DATA MAXIMA::LISPIFY-MAXIMA-KEYWORD-OPTIONS
+            MAXIMA::$SCSIMP MAXIMA::$SETUP_AUTOLOAD
+            MAXIMA::BREAK-FUNCTION MAXIMA::CHECK-INTEGER-FACTS
+            MAXIMA::$ZN_PRIMROOT MAXIMA::FPMAX MAXIMA::$RAT
+            MAXIMA::$FILE_SEARCH MAXIMA::$TODD_COXETER
+            MAXIMA-NREGEX:REGEX-COMPILE MAXIMA::$INFIX
+            MAXIMA::$SET_PARTITIONS MAXIMA::$GF_MINIMAL_SET
+            MAXIMA::$GF_FACTOR MAXIMA::COERCE-FLOAT-FUN MAXIMA::$EF_LOG
+            MAXIMA::$RATSIMP MAXIMA::TEX1 MAXIMA::BIG-FLOAT-LOG
+            MAXIMA::CF-CONVERGENTS-P-Q MAXIMA::$MAKE_ARRAY
+            MAXIMA::HREDUCE BIGFLOAT-IMPL:MAX MAXIMA::BIG-FLOAT-TANH
+            MAXIMA::$ADDROW MAXIMA::$SOLVE MAXIMA::BREAK-STEP-INTO
+            BIGFLOAT-IMPL:MAYBE-TO MAXIMA::REMALIAS
+            MAXIMA::ALTER-PATHNAME MAXIMA::$SORT MAXIMA::$FACTOROUT
+            MAXIMA::TR-LAMBDA MAXIMA::QUAD-CONTROL MAXIMA::$ASKINTEGER
+            MAXIMA::$NOFIX MAXIMA::$GF_SET MAXIMA::$NROOTS
+            BIGFLOAT-IMPL:> MAXIMA::$GF_P2L MAXIMA::WARN-MEVAL
+            MAXIMA::MERROR MAXIMA::$ZN_MULT_TABLE
+            MAXIMA::BIG-FLOAT-ATANH MAXIMA::$PREFIX
+            MAXIMA::GET-PLOT-OPTION-STRING MAXIMA::CREATE-LIST1
+            MAXIMA::RISCHNOUN MAXIMA::$BOX MAXIMA::$GF_P2N
+            MAXIMA::$ALGFAC MAXIMA::$GF_PRIMITIVE_POLY_P
+            MAXIMA::GF-DISREP MAXIMA::OP-EQUALP MAXIMA::$ADDCOL
+            MAXIMA::MILLER-RABIN MAXIMA::$NUM_DISTINCT_PARTITIONS
+            MAXIMA::BIG-FLOAT-SQRT MAXIMA::ABSARG MAXIMA::MREAD-RAW
+            MAXIMA::TR-FORMAT BIGFLOAT-IMPL:MIN MAXIMA::LISPM-REARRAY
+            MAXIMA::POLYLOGP MAXIMA::$PLOT2D MAXIMA::$LPART
+            MAXIMA::$QUAD_CONTROL MAXIMA::$POWERSET
+            MAXIMA::TR-NARGS-CHECK MAXIMA::ASK-CHOICEP
+            MAXIMA::$NUM_PARTITIONS MAXIMA::$FACTOR
+            MAXIMA::$TRANSLATE_FILE MAXIMA::$DIVSUM MT19937:RANDOM
+            MAXIMA::FACTOR MAXIMA::$GF_IRREDUCIBLE_P BIGFLOAT-IMPL:=
+            MAXIMA::MREAD-SYNERR)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT) *) SLATEC::ZABS
+            SLATEC::DGAMLM)) 
+(PROCLAIM '(FTYPE (FUNCTION (T) HASH-TABLE) INTL::DOMAIN-ENTRY-HASH)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (INTEGER T) T) MAXIMA::EXPINTEGRAL-E
+            MT19937::%RANDOM-INTEGER MAXIMA::K-FUN)) 
+(PROCLAIM '(FTYPE (FUNCTION (INTEGER *) *) MAXIMA::GET-ONE-FACTOR-P-1)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (INTEGER FIXNUM) T) MAXIMA::GF-N2L-TWOARGS)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (*) (VALUES T T)) MAXIMA::CONCAT
+            MAXIMA::SYMBOLCONC)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (INTEGER *) T) MAXIMA::$EF_N2L MAXIMA::$GF_N2L)) 
+(PROCLAIM '(FTYPE (FUNCTION (INTEGER T) *) MAXIMA::G-FUN)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION ((VECTOR FIXNUM)) *)
+            MT19937::RANDOM-MT19937-UPDATE)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T (VECTOR T)) T) MAXIMA::WALK-GET-LINEINFO)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T) (VALUES T T)) MAXIMA::DEFINE-SYMBOL
+            MAXIMA::INTERN-INVERT-CASE MAXIMA::IMPLODE MAXIMA::ASCII
+            MAXIMA::$MKEY MAXIMA::MAKEALIAS MAXIMA::GF-ORD-BY-TABLE)) 
+(PROCLAIM '(FTYPE (FUNCTION NIL (VALUES T T)) MAXIMA::GENSUMINDEX)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T) FIXNUM) MAXIMA::RELATIVE-LINE MAXIMA::REVAL
+            MAXIMA::FORCEBREAK MAXIMA::GNUPLOT-POINTTYPES
+            MAXIMA::$ARRAY_DIMENSION_N)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T FIXNUM) T) MAXIMA::NZL MAXIMA::GF-X2L
+            MAXIMA::SPRDET MAXIMA::TDBU MAXIMA::CPBQ1
+            MAXIMA::EXPANDEXPT MAXIMA::P2CPOL MAXIMA::GF-POW-BY-TABLE
+            MAXIMA::POWRS MAXIMA::DIAGP MAXIMA::EXPONENTIATE-SUM
+            MAXIMA::GF-X2ARRAY MAXIMA::GF-PRIMPOLY)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (FIXNUM T) T) MAXIMA::RAND MAXIMA::MTYOTBSP)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T T) T) MAXIMA::RESET-DO-THE-WORK
+            MAXIMA::M2-ONE-LAGUERRE MAXIMA::TMCOMBI MAXIMA::RATDX
+            MAXIMA::SININTP MAXIMA::EXCHANGECOL
+            MAXIMA::BATCH-EQUAL-CHECK MAXIMA::SPECIAL-CONVERGENT-FORMP
+            MAXIMA::$SUBSET MAXIMA::TMKILL MAXIMA::TIMESROW
+            MAXIMA::DECLFUN MAXIMA::DOPGCDCOFACTS MAXIMA::FACTQSNT
+            MAXIMA::M2 MAXIMA::EDIFF MAXIMA::$GF_PRIMITIVE_POLY
+            MAXIMA::DIMENSION-STRING MAXIMA::FDEL MAXIMA::FSEL
+            MAXIMA::FIXVL MAXIMA::BEG MAXIMA::ZL-INTERSECTION
+            MAXIMA::NARY2 MAXIMA::PINTERPOLATE2 MAXIMA::PINTERPOLATE
+            MAXIMA::FREEOFL MAXIMA::FLGREAT MAXIMA::DIFF-EXPAND
+            MAXIMA::$INTERVAL MAXIMA::JACOBI MAXIMA::RGRP
+            MAXIMA::PDIFROWS MAXIMA::HALFANGLE
+            MAXIMA::BESSEL-I-HALF-ORDER MAXIMA::INTEGRATE-MEXPT-2
+            MAXIMA::TAYLOR* MAXIMA::PSINHA+B MAXIMA::HANKEL-1
+            MAXIMA::RTC-DIVIDE-BY-GCD MAXIMA::MEMQ MAXIMA::SENDEXEC
+            MAXIMA::M2-SUM-WITH-EXP-CASE1 MAXIMA::M1 MAXIMA::PCONTENT1
+            MAXIMA::M2-ASSOC_LEGENDRE_Q MAXIMA::FPTIMES*
+            MAXIMA::FPDIFFERENCE MAXIMA::RATREP MAXIMA::EXPANDTERMS
+            MAXIMA::APPLY2HACK MAXIMA::$REVEAL MAXIMA::$ADJOIN
+            MAXIMA::CALCULATE-SERIES MAXIMA::MREMPROP
+            MAXIMA::QUOTE-CHARS MAXIMA::MMACRO-DISPLACE MAXIMA::INTDIFF
+            MAXIMA::GF-IRR MAXIMA::COEFF-CONTAINS-POWERS MAXIMA::REDGCD
+            MAXIMA::BIGLSH MAXIMA::END- MAXIMA::ZEROCOEFL
+            MAXIMA::CMOD-SL MAXIMA::SUBST2S MAXIMA::RE-SOLVE-FULL
+            MAXIMA::FREEL MAXIMA::EXPTB MAXIMA::EXPONENT-OF
+            MAXIMA::ATOMGRAD MAXIMA::NEXT-PRIME-DET MAXIMA::$SUBLIS
+            MAXIMA::RATCF MAXIMA::DBA MAXIMA::GCTIME1 MAXIMA::GETL
+            MAXIMA::M2-HANKEL_1 MAXIMA::EVENFN MAXIMA::ATRANSPOSE
+            MAXIMA::RATSETUP1 MAXIMA::TMFACTORIAL MAXIMA::GCTIMEP
+            MAXIMA::END MAXIMA::KC-ARG2 MAXIMA::AP1 MAXIMA::MBUILDQ
+            MAXIMA::TRUNC-VECT1 COMMAND-LINE:PROCESS-ARGS
+            MAXIMA::PTIMESCHK MAXIMA::GF-NXCPLUS MAXIMA::PGCD1
+            MAXIMA::DELETEROW MAXIMA::M2-ONEPJAC MAXIMA::ALPHALESSP
+            MAXIMA::MPRINT MAXIMA::ASSOO MAXIMA::DEFEXEC MAXIMA::NPQUO
+            MAXIMA::C-$PN MAXIMA::PINTERPOLATE1 MAXIMA::GAMMAGREEKTF
+            MAXIMA::MAX-NUMERIC-RATIO-P MAXIMA::TIMER-HANDLER
+            MAXIMA::$GET MAXIMA::EXPFACTORP MAXIMA::$SETDIFFERENCE
+            MAXIMA::EBAKSUBST MAXIMA::MATRIX-MATRIX-PRODUCTP
+            MAXIMA::$GF_EXP MAXIMA::INSIDE MAXIMA::OLDGET
+            MAXIMA::PMODREM MAXIMA::GET-THETA-FOR-VERTICAL-Z
+            MAXIMA::M2-LEGENDRE_P MAXIMA::RATPLUS MAXIMA::CPROG
+            MAXIMA::SIMPLIMSUBST MAXIMA::PDISREP!
+            MAXIMA::EXPAND-DISTINCT-ROOTS MAXIMA::M2-ONEEXPINTEGRAL_E
+            MAXIMA::M2-SUM-WITH-EXP-CASE5 MAXIMA::DCOMP MAXIMA::DGQ
+            MAXIMA::$POISEXPT MAXIMA::$POISINT MAXIMA::GETCHAR
+            MAXIMA::PTIMES1 MAXIMA::CONST1 MAXIMA::OLDCONTENT1
+            MAXIMA::GF-SQ MAXIMA::DETPIVOT MAXIMA::M2-ONEL
+            MAXIMA::PDIVIDE MAXIMA::HSIMP
+            MAXIMA::SIMPLIM%INVERSE_JACOBI_NS MAXIMA::REDRESULT
+            MAXIMA::GET-NOT-CONST-OR-INT-TERMS MAXIMA::TRIG-SUBST
+            MAXIMA::RCPLUS! MAXIMA::SCRAT MAXIMA::DIMENSION-LIST
+            MAXIMA::EREDUCE MAXIMA::OLDGCDL MAXIMA::SIGNNP
+            MAXIMA::RCDIFF! MAXIMA::PQUOCOF MAXIMA::$DISJOIN
+            MAXIMA::GF-FACTOR MAXIMA::BESSEL-Y
+            MAXIMA::HAS-CONST-OR-INT-TERM MAXIMA::$ORDERMAGNITUDEP
+            MAXIMA::ISUM MAXIMA::GGR1 MAXIMA::$MEMBER MAXIMA::M2-ONEW
+            MAXIMA::SPC3 MAXIMA::GPPLUS MT19937:%RANDOM-SINGLE-FLOAT
+            MAXIMA::$SSTATUS-AUX MAXIMA::RIB MAXIMA::STRONGER-VAR?
+            MAXIMA::$POISTIMES MAXIMA::DIMENSION-POSTFIX
+            MAXIMA::INCREASELIST MAXIMA::SELECTOR MAXIMA::DISTRFACTOR
+            MAXIMA::FPSHIFT MAXIMA::CONF7 MAXIMA::BBSORT
+            MAXIMA::SAFE-MGET MAXIMA::FPROOT MAXIMA::MGET MAXIMA::ADD2
+            MAXIMA::EVERY-TRIGARG-ALIKE MAXIMA::DIM-MNCEXPT
+            MAXIMA::DIFFERENCE-VAR-SETS MAXIMA::GREAT MAXIMA::DIAGINV
+            MAXIMA::SRATP MAXIMA::SET-PARTITIONS MAXIMA::$EF_COMPOSE
+            MAXIMA::ALGTRACE* MAXIMA::DIM-%LIMIT MAXIMA::$GF_REDUCE
+            MAXIMA::PARSE MAXIMA::POWERS
+            MAXIMA::OPERATOR-FREQUENCY-TABLE MAXIMA::SET-UNION
+            MAXIMA::DEPENDS1 MAXIMA::MXTIMESC
+            MAXIMA::SIMPLIM%INVERSE_JACOBI_NC MAXIMA::M2-ONEKONEY
+            MAXIMA::EXCISE-EXTRA-VARIABLES MAXIMA::EXPANDSUMS
+            MAXIMA::REMOV0 MAXIMA::ALIAS MAXIMA::$@-FUNCTION
+            MAXIMA::ADD2CSTR1 MAXIMA::J1TF MAXIMA::$GF_IRREDUCIBLE
+            MAXIMA::BAKSUBST1 MAXIMA::BEZOUT MAXIMA::ERREV-SL
+            MAXIMA::ILT2 MAXIMA::ADDF MAXIMA::EXPTBIGFLOAT
+            MAXIMA::M-SUBSET MAXIMA::RATQU CL-INFO::SOME-INEXACT
+            MAXIMA::PSTERM MAXIMA::VGREAT MAXIMA::SUMCOMBINE2
+            MAXIMA::DECLARRAY MAXIMA::EXPAND MAXIMA::PREVCONSTEXPAN
+            MAXIMA::HSTF MAXIMA::PCDIFCONC MAXIMA::M2-HANKEL_2^2
+            MAXIMA::PSUMSQ1 MAXIMA::ARRAYINFO-AUX MAXIMA::CONSTERM
+            MT19937:%RANDOM-DOUBLE-FLOAT MAXIMA::EQUO
+            MAXIMA::M2-ARBPOW2 MAXIMA::M2-E^-T MAXIMA::POWER
+            MAXIMA::YUK-SU-META-PROP MAXIMA::RISPLIT-EXPT-FIXNUM-POW
+            MAXIMA::BINOCOMP MAXIMA::ONP MAXIMA::LISP-FCN-TYPEP
+            MAXIMA::CPOWER MAXIMA::EGCD MAXIMA::XTORTERM
+            MAXIMA::M2-TWO-HANKEL_1 MAXIMA::MUL2 MAXIMA::M2-TWOJ
+            MAXIMA::QUOT MAXIMA::LSTF MAXIMA::PNTHROOTP MAXIMA::FIXMULT
+            MAXIMA::XPTIMES MAXIMA::PDISREP*EXPAND MAXIMA::PSINA+B
+            MAXIMA::$EF_GCDEX MAXIMA::P*LOGNXP MAXIMA::RAISEUP
+            MAXIMA::STURMSEQ MAXIMA::COMPILEMATCH MAXIMA::RATSETUP
+            MAXIMA::PDERIVATIVE MAXIMA::ODDS MAXIMA::GCEXPT
+            MAXIMA::MRV-SIGN MAXIMA::RULE-APPLY MAXIMA::GETGOODVALS
+            MAXIMA::GCFACTOR MAXIMA::ANDMAPCAR MAXIMA::PAR
+            MAXIMA::SUMCOEF MAXIMA::M2-ONEI MAXIMA::RATPL MAXIMA::PMON1
+            MAXIMA::ADDMATRIX1 MAXIMA::M2-ELLIPTIC_KC
+            MAXIMA::$ROTATE_PTS MAXIMA::SCHATCHEN MAXIMA::SOLVE3
+            MAXIMA::PSCPLUS1 MAXIMA::KCNTXT MAXIMA::PGCDCOFACTS
+            MAXIMA::FACTPLUS2 MAXIMA::PINTERPOLATE3 MAXIMA::CFPLUS
+            MAXIMA::DCONV MAXIMA::DUP MAXIMA::RATINT
+            MAXIMA::HAS-DISTINCT-NONZERO-ROOTS-P MAXIMA::POLY-IN-VAR
+            MAXIMA::*F-IRR MAXIMA::SIGN-MINMAX
+            CL-INFO::SELECT-INFO-ITEMS MAXIMA::OUTPUT MAXIMA::ISGEO
+            MAXIMA::SET-MEQP MAXIMA::DINTEXP MAXIMA::ELLIPTIC-EU
+            MAXIMA::GENFIND MAXIMA::TRACEMOD0 MAXIMA::TOTAL-SIGN
+            MAXIMA::MY-PRINT MAXIMA::CDIV MAXIMA::PSTIMES
+            MAXIMA::STURM1 MAXIMA::TCONS MAXIMA::NONSYMCHK
+            MAXIMA::M2-ONEJ^2 MAXIMA::PAQUO MAXIMA::SINDIF
+            MAXIMA::EF-DLOGB MAXIMA::KTERMS MAXIMA::EVFUNMAKE
+            MAXIMA::M2-BESSEL_I*HANKEL_2 MAXIMA::PEEK-ONE-TOKEN-G
+            MAXIMA::DBV MAXIMA::FSPLIT MAXIMA::M2-BESSEL_Y*HANKEL_2
+            MAXIMA::Z-FUNCTION MAXIMA::MID MAXIMA::RATCOEF1
+            MAXIMA::DIM-MDO MAXIMA::LGCD1 MAXIMA::ZFREE MAXIMA::$FACOUT
+            MAXIMA::M2-ARBPOW1 CL-INFO::INEXACT-TOPIC-MATCH-1
+            MAXIMA::INTERSECT MAXIMA::M2-ONEU MAXIMA::GETL-LM-FCN-PROP
+            MAXIMA::NTHCOL MAXIMA::$EF_NTH_ROOT MAXIMA::PMODQUO
+            MAXIMA::DIVL MAXIMA::PTIMESROW
+            MAXIMA::SIMPLIM%INVERSE_JACOBI_DC
+            MAXIMA::SIMPLIM%INVERSE_JACOBI_DS MAXIMA::LAPLOG
+            MAXIMA::RATDERIVATIVE MAXIMA::MFREEL MAXIMA::CYCLP
+            MAXIMA::MBUILDQ-SUBST MAXIMA::LSAFIX MAXIMA::RAT3
+            MAXIMA::FPATAN2 MAXIMA::ALGTESTD MAXIMA::$REM
+            MAXIMA::M2-T^-1 MAXIMA::NTHCOL1
+            MAXIMA::SCALAR-OR-CONSTANT-P MAXIMA::STARDISP
+            MAXIMA::LINDEP MAXIMA::ITERATE-OVER-BKPTS MAXIMA::APPEARS
+            MAXIMA::PARSER-ASSOC MAXIMA::TESTDIVIDE MAXIMA::LINPOWER
+            MAXIMA::MAKPROD MAXIMA::BESSEL-I MAXIMA::M2-ONEC
+            MAXIMA::$ELIMINATE MAXIMA::SET-SYMMETRIC-DIFFERENCE
+            MAXIMA::MDEFINE1 MAXIMA::M2-SUM-WITH-EXP-CASE3
+            MAXIMA::DADDEQ MAXIMA::FILLARRAY MAXIMA::M2-ONESLOMMEL
+            MAXIMA::$FUNMAKE MAXIMA::ALIKE MAXIMA::MRV MAXIMA::RADSUBST
+            MAXIMA::PDECPOW MAXIMA::TMSTORE MAXIMA::PSIMP
+            MAXIMA::RATDIVIDE MAXIMA::POSINTEGERSET MAXIMA::MAKORDER
+            MAXIMA::FINDFLIST MAXIMA::ODDFN MAXIMA::ADDARGLIST
+            MAXIMA::$CONCAT_POLYGONS MAXIMA::IND1 MAXIMA::SCEP
+            MAXIMA::PTCDIFFER MAXIMA::$ROTATION1
+            MAXIMA::DECMODE-ARRAYFUN MAXIMA::PGCD
+            MAXIMA::MAXIMA-DECLARED-ARRAY-ALIKE1 MAXIMA::ELLIPTIC-F
+            MAXIMA::$POISDIFF MAXIMA::APPLY1HACK
+            MAXIMA::BESSEL-Y-HALF-ORDER SYSTEM:CPLUS MAXIMA::M2-ONEM
+            MAXIMA::ADDMATRIX MAXIMA::PTIMES MAXIMA::EMAX MAXIMA::PGCDM
+            MAXIMA::MAXMINL MAXIMA::LIMITINF MAXIMA::PSCOSHA+B
+            MAXIMA::FREE MAXIMA::M2-WHITTAKER_W MAXIMA::AFIXSIGN
+            MAXIMA::PDEGREE MAXIMA::M2-ONEEXPINTEGRAL_EI
+            MAXIMA::MEMALIKE MAXIMA::INTSETUP MAXIMA::MLIST-ASSIGN
+            MAXIMA::GPDIFFERENCE MAXIMA::M2-ONEEXPINTEGRAL_SI
+            MAXIMA::SAFE-MGETL MAXIMA::M2-SUM-WITH-EXP-CASE4
+            MAXIMA::RETFACTOR1 MAXIMA::ORDERLESSP MAXIMA::ZL-GET
+            MAXIMA::MRV-MOVEUP MAXIMA::FIXVL1 MAXIMA::ASK-DECLARE
+            MAXIMA::$EF_GCD MAXIMA::RATDIF MAXIMA::ALIKE1
+            MAXIMA::$EF_REDUCE MAXIMA::SININT* MAXIMA::PSCTIMES*
+            MAXIMA::FACTPLUSDEP MAXIMA::PSTRUNC1 MAXIMA::POISMERGE2
+            MAXIMA::ORDERVAR MAXIMA::M2-C*T^V MAXIMA::SIMPDTF
+            MAXIMA::MREAD-PROMPTER MAXIMA::TIMEX1 SYSTEM:CDIFFERENCE
+            CL-INFO::SOME-EXACT MAXIMA::FFACTOR
+            MAXIMA::BESSEL-K-HYPERGEOMETRIC MAXIMA::PSQFRP
+            MAXIMA::BF-ERREV-SL MAXIMA::STRIP-ZEROES
+            MAXIMA::PDISREP2EXPAND MAXIMA::$ZEROMATRIX
+            MAXIMA::HEURTRIAL MAXIMA::HAND-SIDE MAXIMA::$COMPARE
+            MAXIMA::EACHP MAXIMA::TIMEX0 MAXIMA::CTIMEMT
+            MAXIMA::$ENDCONS MAXIMA::SDIFFTIMES MAXIMA::CALL-BATCH1
+            MAXIMA::CPOL2P MAXIMA::LIMFACT MAXIMA::INTEXT MAXIMA::CONF4
+            MAXIMA::BETA-EXPAND-INTEGER MAXIMA::TMSORT-LATTICE
+            INTL:DGETTEXT MAXIMA::ORDE MAXIMA::UNION*
+            MAXIMA::ASK-GREATEQ MAXIMA::DOMAIN-ERROR MAXIMA::MKIND
+            MAXIMA::INTGREAT MAXIMA::NEWSYM2 MAXIMA::FPGREATERP
+            MAXIMA::$FILLARRAY MAXIMA::%PIARGS MAXIMA::PLS
+            MAXIMA::COMBIN MAXIMA::NOTINVOLVE MAXIMA::GF-NREM
+            MAXIMA::DIVSUM MAXIMA::GET! MAXIMA::MRECORD-ASSIGN
+            MAXIMA::MULTIPLYMATRICES MAXIMA::M2-HANKEL_1^2 MAXIMA::MEQP
+            MAXIMA::APPEARS1 MAXIMA::LET-RULE-SETTER MAXIMA::AMONG
+            MAXIMA::REMOVERULE MAXIMA::CFDIFF MAXIMA::MMACRO-APPLY
+            MAXIMA::REMARRELEM MAXIMA::GF-GCD MAXIMA::SIMPMAP
+            MAXIMA::SOLVE-A*F<X>^N+B MAXIMA::TRDISP1
+            MAXIMA::ATTEMPT-TRANSLATE-RANDOM-SPECIAL-OP MAXIMA::SCS
+            MAXIMA::E+ MAXIMA::NSUBSTRING MAXIMA::M2-ONEK
+            MAXIMA::HIDELIM MAXIMA::RESTOROOT MAXIMA::TAY-ERROR
+            MAXIMA::MAP2C MAXIMA::DEL MAXIMA::ZN-TABLE-ERRCHK
+            MAXIMA::M2-ONEEXPINTEGRAL_CHI MAXIMA::LINEAR-TERM-P
+            MAXIMA::GETFNCOEFF MAXIMA::PPLUSCHK MAXIMA::GF-DLOGB
+            MAXIMA::APPROX-ALIKE MAXIMA::SPSIMPCASES
+            MAXIMA::TR-LISP-FUNCTION-CALL MAXIMA::MXCOMP MAXIMA::M2-T^2
+            MAXIMA::MLSP MAXIMA::RPLUS* MAXIMA::REAL-ROOTS
+            MAXIMA::MAXIMA-LISP-DEBUGGER MAXIMA::MFUNCTION-CALL-WARN
+            MAXIMA::DIM-%PRODUCT MAXIMA::EXCLUDE MAXIMA::FINDSES
+            MAXIMA::GETD0 MAXIMA::MGRP MAXIMA::JMAUG MAXIMA::BESSEL-K
+            MAXIMA::GREATERRATP MAXIMA::M2-ONEIONEJ MAXIMA::KLIM
+            MAXIMA::GF-NONCONST-RANDOM MAXIMA::GF-NS2PMOD-FACTOR
+            MAXIMA::QUEUE+P MAXIMA::DEFINTEGRATE
+            MAXIMA::$POLY_DISCRIMINANT MAXIMA::MSETERR MAXIMA::PTPTPLUS
+            MAXIMA::HORN+ MAXIMA::UNKIND MAXIMA::DGR MAXIMA::KINDP
+            MAXIMA::TSEXPT MAXIMA::DIMENSION-PREFIX MAXIMA::UNION1
+            MAXIMA::INTCV2 MAXIMA::EQTEST MAXIMA::MCONS
+            MAXIMA::PLOT-OPTIONS-PARSER MAXIMA::RT-SEPAR
+            MAXIMA::TMPATHP MAXIMA::FINDTHEM MAXIMA::PQUOTIENTCHK-SAFE
+            MAXIMA::ROOT+ANYTHING MAXIMA::%MAKE-POLYGON
+            INTL::STRING-TO-OCTETS MAXIMA::HAS-NOT-ALIKE1-P
+            MAXIMA::ERB-ERR MAXIMA::POLY? MAXIMA::MMOD MAXIMA::AVLINIT
+            MAXIMA::DIMENSION-NARY MAXIMA::$SET_TEX_ENVIRONMENT_DEFAULT
+            MAXIMA::E> MAXIMA::$AUGCOEFMATRIX
+            MAXIMA::M2-SUM-WITH-EXP-CASE2 MAXIMA::MERGE-SOL-LIN
+            MAXIMA::RATDIFFERENCE MAXIMA::RCEXPT1 MAXIMA::NISSWCAR
+            MAXIMA::FLGREAT1 MAXIMA::LED-CALL MAXIMA::STRING<$
+            MAXIMA::$JACOBI MAXIMA::DIM-RAT MAXIMA::FACRPLUS
+            MAXIMA::CHECKBREAK MAXIMA::REMOV3 MAXIMA::DECLSETUP
+            MAXIMA::ASK-EVOD MAXIMA::|/#ALIKE| MAXIMA::ADD-INVERSEP
+            MAXIMA::TRUNC-VECTOR MAXIMA::FIRST-ORDER-P MAXIMA::MATCHSUM
+            MAXIMA::FPPLUS MAXIMA::HIPART MAXIMA::M2-ASSOC_LEGENDRE_P
+            MAXIMA::GF-GROUP-ORDER MAXIMA::INTERVAL MAXIMA::CONTODR
+            MAXIMA::GF-INV MAXIMA::INTDIFFL1L2 MAXIMA::FLRED
+            MAXIMA::PLCMCOFACTS MAXIMA::FASPRINT MAXIMA::HAIPART
+            MAXIMA::EXTOPCHK MAXIMA::M2-ONES MAXIMA::MONOMGCD
+            MAXIMA::CEIL MAXIMA::M2-HANKEL_1*BESSEL_J MAXIMA::EVMAP
+            MAXIMA::PSDISREP*EXPAND MAXIMA::M2-WHITTAKER_M
+            MAXIMA::M2-BESSEL_K*HANKEL_1 MAXIMA::ADFACTL MAXIMA::CONF6
+            MAXIMA::BOTHPRODCOEF MAXIMA::FINDPR MAXIMA::TIMESKL
+            MAXIMA::POLYSUBST MAXIMA::EXCHANGEROW MAXIMA::CONVERT
+            MAXIMA::TMDET MAXIMA::POINTERGP MAXIMA::DMDERIVLONG
+            INTL::PARSE-EXPR MAXIMA::$EF_EXP MAXIMA::ALGTRACE
+            MAXIMA::SIMPLIM%INVERSE_JACOBI_SC MAXIMA::M2-ONERF
+            MAXIMA::BESSEL-K-HALF-ORDER MAXIMA::PRNET MAXIMA::HERMPOL
+            MAXIMA::DIM-MDEFINE MAXIMA::NMT MAXIMA::NISBUILD
+            MAXIMA::GF-MATMULT2 MAXIMA::COMMUTATIVE-PRODUCTP
+            MAXIMA::M2-STRUVE_H MAXIMA::LAMBDA-MEQP
+            MAXIMA::ASSIGN-MODE-CHECK MAXIMA::EXPANDS MAXIMA::DIM-MDOIN
+            MAXIMA::DECLAREKIND MAXIMA::INTCV1 MAXIMA::INTCV3
+            MAXIMA::ZGCD MAXIMA::NALGFAC MAXIMA::PARTNUM MAXIMA::*FPSIN
+            MAXIMA::CEXPT MAXIMA::MULTMAT MAXIMA::TR-MAREF
+            MAXIMA::EXPAND-AND-DISREP MAXIMA::SIMP-ROOTS
+            MAXIMA::PRIMEP-SMALL MAXIMA::AMONGL MAXIMA::SUBRESULT
+            MAXIMA::DIM-%SUM MAXIMA::FACTORIAL-TRANS MAXIMA::LMAKE
+            MAXIMA::DADDNQ MAXIMA::MRV-MOVEDOWN MAXIMA::PSCSUBST1
+            MAXIMA::M2-HANKEL_1*HANKEL_2 MAXIMA::$INRT
+            MAXIMA::APPROX-ALIKE-LIST MAXIMA::RQUOTIENT MAXIMA::PRESIGN
+            MAXIMA::ASSOLIKE MAXIMA::NPCTIMES MAXIMA::MAKE-LI
+            MAXIMA::ATRIGH MAXIMA::$OPERATORP MAXIMA::*UNION-MODE
+            MAXIMA::SOLVENTHP MAXIMA::USOLVE MAXIMA::SQFRP
+            MAXIMA::M2-ONEEXPINTEGRAL_E1 MAXIMA::PARTIAL-INTEGRATION
+            MAXIMA::BESSEL-J-INTEGRAL-2 MAXIMA::APDL MAXIMA::HSIMP1
+            MAXIMA::PREM MAXIMA::*MREAD-PROMPT* MAXIMA::PRADD2LNC
+            MAXIMA::QUEUE-P MAXIMA::MEVAL2 MAXIMA::DISTRINPLUSPREV
+            MAXIMA::$CONS MAXIMA::SSET-DIFFERENCE MAXIMA::KIND
+            MAXIMA::MID- MAXIMA::PLCM MAXIMA::GF-NXCTIMES MAXIMA::IVAR
+            MAXIMA::SAFE-ASSOC MAXIMA::DLQ MAXIMA::TIMESLOOP
+            MAXIMA::GF-P2X-RED MAXIMA::REMALIAS1 MAXIMA::GPTIMES
+            MAXIMA::DCOMPARE MAXIMA::DLF-MUMBLIFY MAXIMA::PUSH-DEFVAR
+            MAXIMA::MNQP MAXIMA::$GF_NORMAL_BASIS_REP MAXIMA::LODEG
+            MAXIMA::CHEBY-PRIME MAXIMA::DELETECOL MAXIMA::$ZEROEQUIV
+            MAXIMA::NEVERSET MAXIMA::NEWVARMAT MAXIMA::PADE1
+            MAXIMA::LSFT MAXIMA::PSPLUS1 MAXIMA::DIM-MMINUS
+            MAXIMA::NISTREELISTER MAXIMA::DEQ
+            MAXIMA::BFLOAT-EXPINTEGRAL-E MAXIMA::MARK-
+            MAXIMA::ARRAYSIZE MAXIMA::SIMPINF-EXPT
+            MAXIMA::TYI-PARSE-INT MAXIMA::$ZN_DETERMINANT
+            MAXIMA::BF-CMOD-SL MAXIMA::ALGORDSET MAXIMA::$ORDERGREATP
+            MAXIMA::M2-HANKEL_2 MAXIMA::FIND-CF
+            MAXIMA::$SCALED_BESSEL_I CL-INFO::EXACT-TOPIC-MATCH-1
+            MAXIMA::ALGII MAXIMA::HANKEL-2 MAXIMA::SRRAT3
+            MAXIMA::REM-TRACE-INFO MAXIMA::SIGNDIFF-MINMAX
+            MAXIMA::ADDPARAM MAXIMA::DIMENSION-FUNCTION MAXIMA::GF-NRED
+            MAXIMA::PTIMES%E MAXIMA::REAL-BRANCH
+            MAXIMA::EQUAL-TIMES-MINUS-ONE MAXIMA::PTIMESMERGE
+            MAXIMA::SOLVENTH MAXIMA::ALLPRODS MAXIMA::MGQP
+            MAXIMA::MAKE-DECLARES MAXIMA::SP1TLIN MAXIMA::CPBG0
+            MAXIMA::SCH-LOOP MAXIMA::DOT--RI MAXIMA::E=
+            MAXIMA::TCL-OUTPUT-LIST MAXIMA::INFSIMP1 MAXIMA::FPCOFRAT1
+            MAXIMA::PSDISREP* MAXIMA::META-FSET
+            MAXIMA::M2-HYPERGEOMETRIC MAXIMA::$ORDERLESSP
+            MAXIMA::PDISREP* MAXIMA::GPCTIMES MAXIMA::$SPLITFIELD
+            MAXIMA::KBATEMANTW MAXIMA::M2-ONEI^2 MAXIMA::C-$ZERO
+            MAXIMA::TSTIMES-GET-PW MAXIMA::PSCPLUS MAXIMA::+MSET
+            MAXIMA::ASK-INTEGER MAXIMA::COMPUMD MAXIMA::ATRIG-TRANS
+            MAXIMA::PTIMES* MAXIMA::M2-ONE-HERMITE MAXIMA::M2-ONEKONEJ
+            MAXIMA::NTHKDR MAXIMA::FRAC-BFLOAT-EXPINTEGRAL-E
+            MAXIMA::$FASTTIMES MAXIMA::DIM-%INTEGRATE
+            MAXIMA::DIM-MLABEL MAXIMA::EXPAND-SING-TRIG?
+            MAXIMA::TRIG-SIN MAXIMA::DIMENSION-DEFSTRUCT
+            MAXIMA::EVERYSUBST2 MAXIMA::PUTLIMVAL
+            MAXIMA::MAXIMA-DECLARED-ARRAY-MEQP MAXIMA::DLS
+            MAXIMA::PARSE-POINTS-X-Y MAXIMA::$NTHROOT
+            MAXIMA::MAXIMA-UNDECLARED-ARRAY-ALIKE1 MAXIMA::$COL
+            MAXIMA::SCALAR-MATRIX-PRODUCTP MAXIMA::EPS-COEF-SIGN
+            MAXIMA::NISFIX MAXIMA::INTIRA MAXIMA::MGETL
+            MAXIMA::NONSQFRCASE MAXIMA::ASY MAXIMA::GF-LOG-ERRCHK1
+            MAXIMA::SUBST-DIFF-MATCH MAXIMA::PNTHROOT
+            MAXIMA::PSDERIVATIVE MAXIMA::EXECF19 MAXIMA::NEW-SKEL
+            MAXIMA::*F-LU-FACTOR MAXIMA::BF-SCALE-FLOAT
+            MAXIMA::$SUBLIST_INDICES MAXIMA::ZFACTSPLIT MAXIMA::RESPROG
+            MAXIMA::PDECOMP MAXIMA::RREDUCE MAXIMA::GF-COEFF-CHECK
+            MAXIMA::INTERSECT* MAXIMA::MSUBLIS-SUBST MAXIMA::REMOV4
+            MAXIMA::FPTIMES1 MAXIMA::IPOLY1 MAXIMA::PSTANA+B
+            MAXIMA::ITH MAXIMA::BESSEL-Y-HYPERGEOMETRIC
+            MAXIMA::DIM-%LSUM MAXIMA::EXCHANGEVAR MAXIMA::DIM-MBOX
+            MAXIMA::DPMODREM MAXIMA::PSTANHA+B MAXIMA::SET-INTERSECT
+            MAXIMA::SPEXP MAXIMA::M2-PARABOLIC_CYLINDER_D
+            MAXIMA::PSEXPT MAXIMA::PQUOTIENT MAXIMA::ISGREATERP
+            MAXIMA::KUMMER MAXIMA::REMOVE-SINGULARITIES
+            MAXIMA::PTDERIVATIVE-COEFFS MAXIMA::DYPHEYED
+            MAXIMA::SOLVE1A MAXIMA::M2-ONEY MAXIMA::$SETEQUALP
+            MAXIMA::BOX MAXIMA::M2-F+C MAXIMA::PUTOPR
+            MAXIMA::M2-STRUVE_L MAXIMA::CAR> MAXIMA::RE-ERAT
+            MAXIMA::M2-ONET MAXIMA::ISUM1 MAXIMA::DPGCD
+            MAXIMA::SP1TPLUS MAXIMA::REMVALUE MAXIMA::MEMBERCAR
+            MAXIMA::DMDERIVABBREV MAXIMA::GF-XCTIMES MAXIMA::PRENUMBER
+            MAXIMA::FPLESSP MAXIMA::M2-TWOK MAXIMA::BESSEL-I-INTEGRAL-2
+            MAXIMA::ORDFN MAXIMA::PTCDIFFER-MINUS MAXIMA::POISXCOEF
+            MAXIMA::CTIMESX MAXIMA::ZN-PE> MAXIMA::TMSYMETRICP
+            CL-INFO::FLATTEN-MATCHES MAXIMA::INFSIMP2 MAXIMA::M2-ONEJ
+            MAXIMA::CROSS-PRODUCT MAXIMA::CPA1 MAXIMA::$JOIN
+            MAXIMA::EXPGAM-FUN MAXIMA::LINPOWER0 MAXIMA::MSUBLIS
+            MAXIMA::PSDISREP2EXPAND MAXIMA::RADFUNP MAXIMA::DO%SUM
+            MAXIMA::NEW-FILE-SEARCH MAXIMA::INV-MOD MAXIMA::$-READ-AUX
+            MAXIMA::NEXTLEVEL MAXIMA::POISCTIMES1 MAXIMA::BXM
+            MAXIMA::MAYBPC MAXIMA::DIM-%AT MAXIMA::PSTIMES*1
+            MAXIMA::GET-ONE-FACTOR-POLLARD MAXIMA::PEXPTSQ MAXIMA::FR1
+            MAXIMA::PTTERM MAXIMA::CHINESE MAXIMA::ROOTSP
+            MAXIMA::CPBER3 MAXIMA::P-DELETE-ZEROS MAXIMA::M2-ONEIONEY
+            MAXIMA::HAS MAXIMA::BRANCH1 MAXIMA::SPANG1 MAXIMA::SUMPLS
+            MAXIMA::LASSOCIATIVE MAXIMA::M2-ONEKELLIPTIC
+            MAXIMA::LIST-MEQP MAXIMA::RESTORE-DEFINT-ASSUMPTIONS
+            MAXIMA::SIGNDIFF-SPECIAL MAXIMA::DISTRINTIMESPREV
+            MAXIMA::BEG- MAXIMA::$LFREEOF MAXIMA::DISPLACE
+            MAXIMA::C-$PZ MAXIMA::WHITTINDTEST MAXIMA::CQUOTIENT
+            MAXIMA::LT-ARBPOW MAXIMA::EXPANINTEXPT MAXIMA::$RISCH
+            MAXIMA::EMIN MAXIMA::$BERNPOLY MAXIMA::LIM-TIMES
+            MAXIMA::CDRAS MAXIMA::DIM-MCOND MAXIMA::MCONS-OP-ARGS
+            MAXIMA::FREE-NOT-ZERO-P MAXIMA::MBUILDQ-ASSOCIATE
+            MAXIMA::PDECOMP1 MAXIMA::BEHAVIOR-EXPT MAXIMA::OFFP
+            MAXIMA::DELETE-WITH-SIDE-EFFECTS-IF MAXIMA::DIM-$MATRIX
+            MAXIMA::RADBYTERM MAXIMA::MBUILDQ-SPLICE-ASSOCIATE
+            MAXIMA::TMERGE MAXIMA::RATSETUP2 MAXIMA::GF-L2P-ERRCHK
+            MAXIMA::RISCHADD MAXIMA::IGNORE-ERRORS-MFUNCALL
+            MAXIMA::M2-A*T MAXIMA::CONST MAXIMA::M2-ELLIPTIC_EC
+            MAXIMA::DIM-MPLUS MAXIMA::M2-E^T MAXIMA::GF-RANDOM
+            MAXIMA::GNUPLOT-PRINT-HEADER MAXIMA::LOCOEF
+            MAXIMA::PTPTDIFFER MAXIMA::ZL-REMPROP MAXIMA::ADD2LNC
+            MAXIMA::M2-ONEEXPINTEGRAL_SHI MAXIMA::SUBLISS
+            MAXIMA::TRYRISCH MAXIMA::SUMCOMBINE1 MAXIMA::PAIROFF
+            MAXIMA::MAXIMA-RATIONALP MAXIMA::M2-ONEFRESNEL_C
+            MAXIMA::DOT-SP-RI MAXIMA::DIMENSION-INFIX
+            MAXIMA::M2-BESSEL_I*HANKEL_1 MAXIMA::M2-ONEK^2
+            MAXIMA::ARRAY-MEQP MAXIMA::CHEBY MAXIMA::NZEROS
+            MAXIMA::LAPDEFINT MAXIMA::TR-ARRAYSETQ MAXIMA::ORDMEXPT
+            MAXIMA::GF-REM MAXIMA::REDUCE-VAR-SET&OP
+            MAXIMA::XMAXIMA-PRINT-HEADER MAXIMA::LINEAR* MAXIMA::ATAN
+            MAXIMA::PGATH2 MAXIMA::MERGESOLN MAXIMA::MCONS-EXP-ARGS
+            MAXIMA::$BOTHCOEF MAXIMA::NARG1 MAXIMA::EXTRACT
+            MAXIMA::SMONO MAXIMA::M2-ONEFRESNEL_S MAXIMA::COMPILEPLUS
+            MAXIMA::FRAC-EXPINTEGRAL-E MAXIMA::RATQUOTIENT
+            MAXIMA::EVAL-MON MAXIMA::ZN-GCDEX1 MAXIMA::M2-JACOBI_P
+            MAXIMA::FREEARGS MAXIMA::PQUOTIENTCHK MAXIMA::FCTRL
+            MAXIMA::LISTIFY1 MAXIMA::DPMODQUO MAXIMA::GEREDNO1
+            MAXIMA::RATDX1 MAXIMA::$INV_MOD MAXIMA::RAT
+            MAXIMA::RADICALP MAXIMA::POISLIM1 MAXIMA::MSETCHK
+            MAXIMA::PDIFFERENCE MAXIMA::GF-DISTINCT-DEGREE-FACTORS
+            MAXIMA::PCTIMES1 MAXIMA::MAXIMA-UNDECLARED-ARRAY-MEQP
+            MAXIMA::PCTIMES MAXIMA::$GF_NTH_ROOT MAXIMA::XEXPONGET
+            MAXIMA::RATDP1 MAXIMA::DNQ MAXIMA::CNTXT MAXIMA::M2-A*X^M+C
+            MAXIMA::WRAP-AN-IS MAXIMA::DEPENDSALL MAXIMA::MERGE-SKEL
+            MAXIMA::IVAR2 MAXIMA::DEBUGMODE1 MAXIMA::MFUNCTION-DELETE
+            MAXIMA::FACTOROOT MAXIMA::ADDN MAXIMA::GATHER
+            MAXIMA::DEFINE-MODE MAXIMA::DISTRINT MAXIMA::FLATTENL-OP
+            MAXIMA::M2-ATAN MAXIMA::M2-ONEE MAXIMA::IMPROPER-ARG-ERR
+            MAXIMA::M2-ONEIONEK MAXIMA::PARSE-NARY MAXIMA::DADDGR
+            MAXIMA::SIMPNCT-ALIKE MAXIMA::PRINT-SPACES
+            MAXIMA::EZTESTDIVIDE MAXIMA::M2-BESSEL_K*HANKEL_2
+            MAXIMA::SC-CONVERG-FORM MAXIMA::EXP-CONVERG-FORM
+            MAXIMA::$FEATUREP MAXIMA-NREGEX::REGEX MAXIMA::LOGEQUIV
+            MAXIMA::INVOLVE MAXIMA::M2-HYP-ONEP MAXIMA::$POLYDECOMP
+            MAXIMA::FPGCDCO MAXIMA::CONF5 MAXIMA::DEFMATCH1
+            MAXIMA::CFTIMES MAXIMA::M2-ONELOG MAXIMA::DIVCARCDR
+            MAXIMA::$ASKEQUAL MAXIMA::HDOT MAXIMA::PNEXT SYSTEM:CTIMES
+            MAXIMA::MAPFR1 MAXIMA::ISINOP MAXIMA::PCSUBSTZ
+            MAXIMA::PPLUS MAXIMA::ORDFNA MAXIMA::NO-ERR-SUB
+            BIGFLOAT::EXPT-EXTRA-BITS MAXIMA::FPR-DIF
+            MAXIMA::GF-N2P-ERRCHK MAXIMA::OLDGCD MAXIMA::CMUL
+            MAXIMA::DISTRDEFEXECINIT MAXIMA::BRANCH MAXIMA::M2-SQROOTT
+            MAXIMA::ONEDIFF MAXIMA::SSOLVE MAXIMA::PDISREP2
+            MAXIMA::RDIFFERENCE* MAXIMA::ELLIPTQUAD MAXIMA::NONVARCHECK
+            MAXIMA::DPDIF MAXIMA::TRYRISCH1 MAXIMA::UPDATE-HEIGHTS
+            MAXIMA::LOOPP MAXIMA::$SUBLIST MAXIMA::REQUIRE-LIST-OR-SET
+            MAXIMA::RESTORELC MAXIMA::STRONGER-DATUM?
+            MAXIMA::$ARRAYMAKE MAXIMA::BAKSUBST MAXIMA::M2-ONEY^2
+            MAXIMA::RLESSP MAXIMA::COMPILETIMES MAXIMA::INSERT-IT
+            MAXIMA::ZPDEGREEVECTOR MAXIMA::$GF_JACOBI MAXIMA::ESHIFT
+            MAXIMA::RATCOEF MAXIMA::GF-PLUS MAXIMA::NEWGCDCALL
+            MAXIMA::MAXIMA-REMF MAXIMA::CNV MAXIMA::SDIFFMAP
+            MAXIMA::PRINT-ABORT-MSG MAXIMA::FIRSTN MAXIMA::SIMPARGS
+            MAXIMA::NEXT-PRIME MAXIMA::$POISPLUS MAXIMA::PSTERM1
+            MAXIMA::E* MAXIMA::ZERO-PRODUCTP MAXIMA::SUBEXP
+            MAXIMA::SUBSETL MAXIMA::FINDROOTS MAXIMA::LAPDIFF
+            MAXIMA::M2-ONEF MAXIMA::LABEQ MAXIMA::REQUIRE-LIST
+            MAXIMA::BDISCR MAXIMA::ISQUADRATICP MAXIMA::PPPROG
+            MAXIMA::$GF_COMPOSE MAXIMA::TAYLOR1 MAXIMA::CANCEL
+            MAXIMA::DIMENSION-BUILD-INFO MAXIMA::PUSH-AUTOLOAD-DEF
+            MAXIMA::PSDISREP^ BIGFLOAT:SUM-POWER-SERIES MAXIMA::LAPERF
+            MAXIMA::RATP MAXIMA::MAXIMA-REDUCE MAXIMA::MULTIPLEP
+            MAXIMA::LMAKE2 COMMAND-LINE::CL-OPTION-DESCRIPTION
+            MAXIMA::HETD MAXIMA::RREMAINDER MAXIMA::FPQUOTIENT
+            MAXIMA::SIMPLE-EQUAL-P MAXIMA::COVERS MAXIMA::FPSINCOS1
+            MAXIMA::DSFUNC1 MAXIMA::PATIMES MAXIMA::$COEFMATRIX
+            MAXIMA::TERM* MAXIMA::COSDIF MAXIMA::$ENTERMATRIX
+            MAXIMA::ARGSFREEOF MAXIMA::CFEXPT MAXIMA::LISP-ARRAY-ALIKE1
+            MAXIMA::PCQUOTIENT MAXIMA::LAPLUS MAXIMA::FACTORSUM0
+            MAXIMA::IS-A-POLE MAXIMA::ADDROW MAXIMA::*FPATAN
+            MAXIMA::$GF_GCDEX MAXIMA::$PRIMES MAXIMA::M2-ONEKBATEMAN
+            MAXIMA::$SPECINT MAXIMA::GF-NZX+CX MAXIMA::M2-ONEGAMMAGREEK
+            MAXIMA::$RATDIFF MAXIMA::STRING1 MAXIMA::NC-ERR
+            MAXIMA::RETRIEVE MAXIMA::RISCHEXPPOLY
+            MAXIMA::DIMENSION-PAREN MAXIMA::PSDIFF1 MAXIMA::SMONOP
+            MAXIMA::LHOP-NUMDEN MAXIMA::ZERORES MAXIMA::NISREPLACE
+            MAXIMA::GNUPLOT-COLOR MAXIMA::LEARN-NUMER MAXIMA::PSANS-ADD
+            MAXIMA::PTPTQUOTIENT MAXIMA::IROOT MAXIMA::PCPLUS
+            MAXIMA::PGCDU MAXIMA::POLCOEF MAXIMA::ISLINEAR
+            MAXIMA::TEX-D MAXIMA::MAKPRODG MAXIMA::READ-ONLY-ASSIGN
+            MAXIMA::SP2DIFF MAXIMA::ASSCONTEXT MAXIMA::RESULTANT
+            MAXIMA::SP3FORM MAXIMA::FACTPOW MAXIMA::LESSTHAN
+            MAXIMA::NISTREETRIMMER MAXIMA::DIM-MABS MAXIMA::IPOLYSUM
+            MAXIMA::INTEGER-STIRLING2 MAXIMA::GF-NPLUS MAXIMA::$ROW
+            MAXIMA::ONPU MAXIMA::BROKEN-FREEOF MAXIMA::EXPONENTIALIZE
+            MAXIMA::REQUIRE-SET MAXIMA::BINCOMP1 MAXIMA::EQUAL-DIV-TWO
+            MAXIMA::RPOWERSET MAXIMA::M2-BESSEL_Y*HANKEL_1
+            MAXIMA::FACTOROUT1 MAXIMA::SOLVE-BY-DECOMPOSITION
+            MAXIMA::PINTERPOLATE4 MAXIMA::SQ-SUMSQ MAXIMA::RATREDUCE
+            MAXIMA::PSTRIM-TERMS MAXIMA::NISADDON
+            MAXIMA::BESSEL-J-HALF-ORDER MAXIMA::M2-TWOY
+            MAXIMA::GETLABELS* MAXIMA::DIV MAXIMA::DEPENDSL
+            MAXIMA::MMACROEXPANSION-CHECK MAXIMA::NTHELEM
+            MAXIMA::M2-DEFLTEP MAXIMA::SUMCONTRACT2 MAXIMA::INTCV
+            MAXIMA::MDEFMACRO1 MAXIMA::ZGCD1
+            MAXIMA::COUNT-ATOMS-MATCHING MAXIMA::CNTHROOT
+            MAXIMA::M2-SUM MAXIMA::P-DESCENDING-POWERS MAXIMA::$CHINESE
+            MAXIMA::ASET-BY-CURSOR MAXIMA::C-$POS MAXIMA::$POISCTIMES
+            MAXIMA::FACTF MAXIMA::XMAXIMA-COLOR MAXIMA::RATGREATERP
+            MAXIMA::INTEGER-STIRLING1 MAXIMA::NEXT-PRIME-PROB
+            MAXIMA::DIMENSION-NOFIX MAXIMA::SUBEXPRESSION-MATCHES-P
+            MAXIMA::M2-UNIT_STEP MAXIMA::ALGPCHK MAXIMA::PARSE-INFIX
+            MAXIMA::UPOLY+ MAXIMA::LISIMP-NEGATIVE-INTEGER
+            MAXIMA::WTPCTIMES MAXIMA::MFREE MAXIMA::POISMERGE22
+            MAXIMA::ASSOL MAXIMA::DISTRESTOREX MAXIMA::POLYDECOMP
+            MAXIMA::LIKE MAXIMA::M2-ONEQ MAXIMA::$EF_JACOBI
+            MAXIMA::OUTPUT-LINEAR MAXIMA::$PICKAPART MAXIMA::PLUSIN
+            MAXIMA::SIDE-EFFECT-FREE-CHECK MAXIMA::HALFSPLIT
+            MAXIMA::PSCOSA+B MAXIMA::DEPENDS MAXIMA::LEARN-ABS
+            MAXIMA::MGRIND MAXIMA::HEURTRIAL1 MAXIMA::PUSH-PW
+            MAXIMA::PEXPT MAXIMA::PSPLUS MAXIMA::BESSEL-J
+            MAXIMA::EZGCD2 MAXIMA::FILTER MAXIMA::M2-HANKEL_2*BESSEL_J
+            MAXIMA::FPPREC1 MAXIMA::CFQUOT MAXIMA::M2-TWOI
+            MAXIMA::$FLOAT_APPROX_EQUAL MAXIMA::ALGTRACE1
+            MAXIMA::DISTRDEFEXEC MAXIMA::COSINT* MAXIMA::NISSWCDR
+            MAXIMA::DEGODR MAXIMA::DIM-MLABOX MAXIMA::LINSORT
+            MAXIMA::CAREFULFACTOR MAXIMA::ARRSTORE MAXIMA::CPRES1
+            MAXIMA::RESTOREX MAXIMA::HALFANGLEAUX MAXIMA::RATEXPT
+            MAXIMA::M2-ONEP0 MAXIMA::SP1GREAT MAXIMA::DIMENSION-ARRAY
+            MAXIMA::STRONGP MAXIMA::RISPLIT-EXPT-REAL^RAT
+            MAXIMA::GETCHARN CL-INFO::READ-INFO-TEXT MAXIMA::FPTIMES
+            MAXIMA::FREEOF MAXIMA::ALGNORM MAXIMA::MAKEPREDS
+            MAXIMA::PQUO MAXIMA::DIM-MQUOTIENT MAXIMA::OLDCONTENT2
+            MAXIMA::WTPEXPT CL-INFO::FIND-REGEX-MATCHES
+            MAXIMA::GF-AT-ERRCHK MAXIMA::RCEXPT
+            MAXIMA::SIMPLIM%INVERSE_JACOBI_CS MAXIMA::PARSE-POSTFIX
+            MAXIMA::K MAXIMA::TRIG-LOG-3A-EXEC MAXIMA::PRODCOEF
+            MAXIMA::$BFLOAT_APPROX_EQUAL MAXIMA::TSEXPT1
+            MAXIMA::PCDIFFER MAXIMA::M2-ONERFC MAXIMA::COMPILEATOM
+            MAXIMA::MYADD2LNC MAXIMA::DMARK MAXIMA::SQDTC
+            MAXIMA::PADE-MONIZE MAXIMA::NPCTIMES1
+            MAXIMA::$EF_NORMAL_BASIS_REP MAXIMA::M2-ONEYONEJ
+            MAXIMA::ADDROWS MAXIMA::$FILE_SEARCH1
+            MAXIMA::FIRST-FORM-LINE MAXIMA::PRINT-PT1 MAXIMA::LINEARP
+            MAXIMA::DIMENSION-MATCH MAXIMA::IMODP1 MAXIMA::SUBRESGCD
+            MAXIMA::SPDERIVATIVE MAXIMA::DIM-%DERIVATIVE
+            MAXIMA::GF-UNIT-P MAXIMA::$DIAGMATRIX MAXIMA::$PARTITION
+            MAXIMA::GETDEC MAXIMA::TAY-EXPONENTIALIZE MAXIMA::CPTIMESXA
+            MAXIMA::SUBST0 MAXIMA::SP1SINCOS MAXIMA::NEGTEST
+            MAXIMA::MZFREE MAXIMA::PTCPLUS INTL::OCTETS-TO-STRING
+            MAXIMA::PSDISREP+ MAXIMA::PSDIFF
+            MAXIMA::DIMENSION-SUPERSCRIPT MAXIMA::M2-ONEGAMMAINCOMPLETE
+            MAXIMA::BPROG MAXIMA::COMPILEEACH MAXIMA::XOR
+            MAXIMA::$ZERO_FUN MAXIMA::RASSOCIATIVE
+            MAXIMA::QUICK-SQFR-CHECK MAXIMA::$PARTITION_SET
+            MAXIMA::LET-MACRO-GET-VARS MAXIMA::NOT-ZERO-FREE
+            MAXIMA::MICRO-PER-CALL-TO-SEC MAXIMA::M2-ONEEXPINTEGRAL_CI
+            MAXIMA::PRODCOEF1 MAXIMA::M2-ASIN MAXIMA::PSISIMP1
+            MAXIMA::TR-DECLARE-VARMODE MAXIMA::*RED MAXIMA::PFACTOR2
+            MAXIMA::LOGCPI0 MAXIMA::DADDGQ MAXIMA::TRIG-RIGHT-PLACEP
+            MAXIMA::M2-ONE-GEN-LAGUERRE MAXIMA::EQUAL-TIMES-MINUS-TWO
+            MAXIMA::PFACTORLIN MAXIMA::$REMRULE MAXIMA::PRSMATCH
+            MAXIMA::M2-TWO-HANKEL_2
+            MAXIMA::ATTEMPT-TRANSLATE-RANDOM-MACRO-OP MAXIMA::MARK+
+            MAXIMA::TMUNIFY-LOOP MAXIMA::SAFE-GET MAXIMA::META-ADD2LNC)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (T *) *) MAXIMA::APPLICATION-OPERATOR
+            MAXIMA::$REMBOX BIGFLOAT-IMPL:- MAXIMA::MAREF1
+            MAXIMA::ML-TYPEP BIGFLOAT-IMPL:/ BIGFLOAT-IMPL:BIGFLOAT
+            MAXIMA::$CONTENT MAXIMA::$BF_FIND_ROOT BIGFLOAT-IMPL:LOG
+            MAXIMA::MFUNCALL MAXIMA::$EXPAND MAXIMA::$FIND_ROOT
+            MAXIMA::$BATCH MAXIMA::$INVERT MAXIMA::$POLYMOD
+            MAXIMA::MCALL MAXIMA::SIMPINF-IC BIGFLOAT-IMPL:COMPLEX
+            BIGFLOAT::%TO MAXIMA::COMPLEX-NUMBER-P MAXIMA::$TRIGREDUCE
+            MAXIMA::$HORNER MAXIMA::BIG-FLOAT-ASIN MAXIMA::WARN-FEXPR
+            MAXIMA::MAXIMA-DISPLAY MAXIMA::GNUPLOT-PROCESS
+            MAXIMA-NREGEX::REGEX-QUOTED BIGFLOAT-IMPL:ATAN
+            MAXIMA::SETUP-CLIENT MAXIMA::BIG-FLOAT-ACOS
+            MAXIMA::$FIBTOPHI MAXIMA::START-CLIENT)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) MAXIMA::MAKE-GRID-VERTICES
+            MAXIMA::EF-CPOW-BY-TABLE MAXIMA::COMBINATION
+            MAXIMA::EF-CPLUS-BY-TABLE MAXIMA::EF-CTIMES-BY-TABLE)) 
+(PROCLAIM '(FTYPE (FUNCTION (INTEGER INTEGER) T) MAXIMA::PPEXPO)) 
+(PROCLAIM
+    '(FTYPE (FUNCTION (LONG-FLOAT LONG-FLOAT) T) MAXIMA::ELLIPTIC-E)) 
+(PROCLAIM '(FTYPE (FUNCTION (STRING T) T) INTL::DOMAIN-LOOKUP)) 
\ No newline at end of file
